@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -232,9 +232,7 @@ if [ -n "${CMAKE_COMMAND}" ]; then
 fi
 
 if [ -z "${CMAKE_COMMAND}" ] ||
-   [ "$CMAKE_MAJOR" -lt "$CMAKE_GLOBAL_MIN_VERSION_MAJOR" ] ||
-   [ "$CMAKE_MINOR" -lt "$CMAKE_GLOBAL_MIN_VERSION_MINOR" ] ||
-   [ "$CMAKE_REVISION" -lt "$CMAKE_GLOBAL_MIN_VERSION_REVISION" ]; then
+  version_is_less_than "$CMAKE_MAJOR" "$CMAKE_MINOR" "$CMAKE_REVISION" "$CMAKE_GLOBAL_MIN_VERSION_MAJOR" "$CMAKE_GLOBAL_MIN_VERSION_MINOR" "$CMAKE_GLOBAL_MIN_VERSION_REVISION"; then
   echo "CMake is not installed or too old, attempting to install it..."
   bootstrap_cmake
   if [ -x "$(command -v cmake3)" ]; then
@@ -246,9 +244,15 @@ if [ -z "${CMAKE_COMMAND}" ] ||
   get_cmake_version
 fi
 
-if [ "$CMAKE_MAJOR" -lt "$CMAKE_GLOBAL_MIN_VERSION_MAJOR" ] ||
-   [ "$CMAKE_MINOR" -lt "$CMAKE_GLOBAL_MIN_VERSION_MINOR" ] ||
-   [ "$CMAKE_REVISION" -lt "$CMAKE_GLOBAL_MIN_VERSION_REVISION" ]; then
+# RHEL8: If cmake3 is too old, try cmake
+if [ "$CMAKE_COMMAND" = "cmake3" ] &&
+   version_is_less_than "$CMAKE_MAJOR" "$CMAKE_MINOR" "$CMAKE_REVISION" "$CMAKE_GLOBAL_MIN_VERSION_MAJOR" "$CMAKE_GLOBAL_MIN_VERSION_MINOR" "$CMAKE_GLOBAL_MIN_VERSION_REVISION" &&
+   [ -x "$(command -v cmake)" ]; then
+  CMAKE_COMMAND="cmake"
+  get_cmake_version
+fi
+
+if version_is_less_than "$CMAKE_MAJOR" "$CMAKE_MINOR" "$CMAKE_REVISION" "$CMAKE_GLOBAL_MIN_VERSION_MAJOR" "$CMAKE_GLOBAL_MIN_VERSION_MINOR" "$CMAKE_GLOBAL_MIN_VERSION_REVISION"; then
   echo "Failed to install or update CMake, exiting..."
   exit
 fi
@@ -259,8 +263,6 @@ add_cmake_option DEBUG_SYMBOLS ${FALSE}
 add_cmake_option BUILD_ROCKSDB ${TRUE}
 ## uses the source from the third party directory
 add_option ROCKSDB_ENABLED ${TRUE} "ENABLE_ROCKSDB"
-## need libcurl installed
-add_option HTTP_CURL_ENABLED ${TRUE} "ENABLE_CURL"
 
 # third party directory
 add_option LIBARCHIVE_ENABLED ${TRUE} "ENABLE_LIBARCHIVE"
@@ -275,32 +277,14 @@ add_option EXPRESSION_LANGUAGE_ENABLED ${TRUE} "ENABLE_EXPRESSION_LANGUAGE"
 add_dependency EXPRESSION_LANGUAGE_ENABLED "bison"
 add_dependency EXPRESSION_LANGUAGE_ENABLED "flex"
 
-add_option PCAP_ENABLED ${FALSE} "ENABLE_PCAP"
-add_dependency PCAP_ENABLED "libpcap"
-
-add_option USB_ENABLED ${FALSE} "ENABLE_USB_CAMERA"
-add_dependency USB_ENABLED "libusb"
-add_dependency USB_ENABLED "libpng"
-
-add_option GPS_ENABLED ${FALSE} "ENABLE_GPS"
-add_dependency GPS_ENABLED "gpsd"
-
 add_option AWS_ENABLED ${TRUE} "ENABLE_AWS"
 
-add_option KAFKA_ENABLED ${TRUE} "ENABLE_LIBRDKAFKA"
+add_option KAFKA_ENABLED ${TRUE} "ENABLE_KAFKA"
 
 add_option KUBERNETES_ENABLED ${TRUE} "ENABLE_KUBERNETES"
 
 add_option MQTT_ENABLED ${TRUE} "ENABLE_MQTT"
 
-add_option COAP_ENABLED ${FALSE} "ENABLE_COAP"
-add_dependency COAP_ENABLED "automake"
-add_dependency COAP_ENABLED "autoconf"
-add_dependency COAP_ENABLED "libtool"
-
-add_option JNI_ENABLED ${FALSE} "ENABLE_JNI"
-add_dependency JNI_ENABLED "jnibuild"
-
 add_option OPENCV_ENABLED ${FALSE} "ENABLE_OPENCV"
 
 add_option SFTP_ENABLED ${FALSE} "ENABLE_SFTP"
@@ -308,8 +292,6 @@ add_dependency SFTP_ENABLED "libssh2"
 
 add_option SQL_ENABLED ${TRUE} "ENABLE_SQL"
 
-add_option OPENWSMAN_ENABLED ${FALSE} "ENABLE_OPENWSMAN"
-
 # Since the following extensions have limitations on
 add_option BUSTACHE_ENABLED ${FALSE} "ENABLE_BUSTACHE" "2.6" ${TRUE}
 
@@ -322,25 +304,19 @@ if $LINUX; then
   add_option SYSTEMD_ENABLED ${TRUE} "ENABLE_SYSTEMD"
 fi
 
-add_option NANOFI_ENABLED ${FALSE} "ENABLE_NANOFI"
-
 add_option SPLUNK_ENABLED ${TRUE} "ENABLE_SPLUNK"
-set_dependency SPLUNK_ENABLED HTTP_CURL_ENABLED
 
 add_option GCP_ENABLED ${TRUE} "ENABLE_GCP"
 
 add_option ELASTIC_ENABLED ${TRUE} "ENABLE_ELASTICSEARCH"
-set_dependency ELASTIC_ENABLED HTTP_CURL_ENABLED
 
 add_option GRAFANA_LOKI_ENABLED ${FALSE} "ENABLE_GRAFANA_LOKI"
-set_dependency GRAFANA_LOKI_ENABLED HTTP_CURL_ENABLED
 
 add_option PROCFS_ENABLED ${TRUE} "ENABLE_PROCFS"
 
 add_option PROMETHEUS_ENABLED ${TRUE} "ENABLE_PROMETHEUS"
 
-add_option OPENSSL_ENABLED ${TRUE} "MINIFI_OPENSSL"
-add_dependency OPENSSL_ENABLED "opensslbuild"
+add_option COUCHBASE_ENABLED ${FALSE} "ENABLE_COUCHBASE"
 
 USE_SHARED_LIBS=${TRUE}
 ASAN_ENABLED=${FALSE}
@@ -535,3 +511,5 @@ fi
 
 
 popd || exit 2
+
+# vim: shiftwidth=2 tabstop=2 expandtab
