@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -26,6 +26,24 @@ get_cmake_version(){
   CMAKE_REVISION=$(echo "$CMAKE_VERSION" | cut -d. -f3)
 }
 
+# Checks if a version is smaller than another
+version_is_less_than() {
+  # Parameters:
+  local lhs_major=$1
+  local lhs_minor=$2
+  local lhs_patch=$3
+  local rhs_major=$4
+  local rhs_minor=$5
+  local rhs_patch=$6
+  # Return: true (0) if left hand side (lhs) is smaller than right hand side (rhs), otherwise return false
+  if [ "$lhs_major" -lt "$rhs_major" ]; then return 0; fi
+  if [ "$lhs_minor" -lt "$rhs_minor" ]; then return 0; fi
+  if [ "$lhs_patch" -lt "$rhs_patch" ]; then return 0; fi
+
+  # otherwise return
+  false
+}
+
 add_cmake_option(){
   eval "$1=$2"
 }
@@ -360,29 +378,22 @@ show_supported_features() {
   echo " Select MiNiFi C++ Features to toggle."
   echo "****************************************"
   echo "A. Persistent Repositories .....$(print_feature_status ROCKSDB_ENABLED)"
-  echo "B. libcurl features ............$(print_feature_status HTTP_CURL_ENABLED)"
   echo "C. libarchive features .........$(print_feature_status LIBARCHIVE_ENABLED)"
   echo "D. Python Scripting support ....$(print_feature_status PYTHON_SCRIPTING_ENABLED)"
   echo "E. Expression Language support .$(print_feature_status EXPRESSION_LANGUAGE_ENABLED)"
   echo "F. Kafka support ...............$(print_feature_status KAFKA_ENABLED)"
-  echo "G. PCAP support ................$(print_feature_status PCAP_ENABLED)"
-  echo "H. USB Camera support ..........$(print_feature_status USB_ENABLED)"
-  echo "I. GPS support .................$(print_feature_status GPS_ENABLED)"
   echo "K. Bustache Support ............$(print_feature_status BUSTACHE_ENABLED)"
   echo "L. Lua Scripting Support .......$(print_feature_status LUA_SCRIPTING_ENABLED)"
   echo "M. MQTT Support ................$(print_feature_status MQTT_ENABLED)"
-  echo "N. COAP Support ................$(print_feature_status COAP_ENABLED)"
   echo "O. SFTP Support ................$(print_feature_status SFTP_ENABLED)"
   echo "S. AWS Support .................$(print_feature_status AWS_ENABLED)"
   echo "T. OpenCV Support ..............$(print_feature_status OPENCV_ENABLED)"
   echo "U. OPC-UA Support...............$(print_feature_status OPC_ENABLED)"
   echo "V. SQL Support..................$(print_feature_status SQL_ENABLED)"
-  echo "W. Openwsman Support ...........$(print_feature_status OPENWSMAN_ENABLED)"
   echo "X. Azure Support ...............$(print_feature_status AZURE_ENABLED)"
   if $LINUX; then
     echo "Y. Systemd Support .............$(print_feature_status SYSTEMD_ENABLED)"
   fi
-  echo "Z. NanoFi Support ..............$(print_feature_status NANOFI_ENABLED)"
   echo "AA. Splunk Support .............$(print_feature_status SPLUNK_ENABLED)"
   echo "AB. Kubernetes Support .........$(print_feature_status KUBERNETES_ENABLED)"
   echo "AC. Google Cloud Support .......$(print_feature_status GCP_ENABLED)"
@@ -390,17 +401,16 @@ show_supported_features() {
   echo "AE. Prometheus Support .........$(print_feature_status PROMETHEUS_ENABLED)"
   echo "AF. Elasticsearch Support ......$(print_feature_status ELASTIC_ENABLED)"
   echo "AG. Grafana Loki Support .......$(print_feature_status GRAFANA_LOKI_ENABLED)"
+  echo "AH. Couchbase Support ..........$(print_feature_status COUCHBASE_ENABLED)"
   echo "****************************************"
   echo "            Build Options."
   echo "****************************************"
   echo "1. Enable Tests ................$(print_feature_status TESTS_ENABLED)"
   echo "2. Enable all extensions"
-  echo "3. Enable JNI Support ..........$(print_feature_status JNI_ENABLED)"
   echo "4. Use Shared Dependency Links .$(print_feature_status USE_SHARED_LIBS)"
   echo "5. Build Profile ...............$(print_multi_option_status BUILD_PROFILE)"
   echo "6. Create ASAN build ...........$(print_feature_status ASAN_ENABLED)"
   echo "7. Treat warnings as errors.....$(print_feature_status MINIFI_FAIL_ON_WARNINGS)"
-  echo "8. Enable OpenSSL...............$(print_feature_status OPENSSL_ENABLED)"
   echo "P. Continue with these options"
   if [ "$GUIDED_INSTALL" = "${TRUE}" ]; then
     echo "R. Return to Main Menu"
@@ -418,27 +428,20 @@ read_feature_options(){
   choice=$(echo "${choice}" | tr '[:upper:]' '[:lower:]')
   case $choice in
     a) ToggleFeature ROCKSDB_ENABLED ;;
-    b) ToggleFeature HTTP_CURL_ENABLED ;;
     c) ToggleFeature LIBARCHIVE_ENABLED ;;
     d) ToggleFeature PYTHON_SCRIPTING_ENABLED ;;
     e) ToggleFeature EXPRESSION_LANGUAGE_ENABLED ;;
     f) ToggleFeature KAFKA_ENABLED ;;
-    g) ToggleFeature PCAP_ENABLED ;;
-    h) ToggleFeature USB_ENABLED ;;
-    i) ToggleFeature GPS_ENABLED ;;
     k) ToggleFeature BUSTACHE_ENABLED ;;
     l) ToggleFeature LUA_SCRIPTING_ENABLED ;;
     m) ToggleFeature MQTT_ENABLED ;;
-    n) ToggleFeature COAP_ENABLED ;;
     o) ToggleFeature SFTP_ENABLED ;;
     s) ToggleFeature AWS_ENABLED ;;
     t) ToggleFeature OPENCV_ENABLED ;;
     u) ToggleFeature OPC_ENABLED ;;
     v) ToggleFeature SQL_ENABLED ;;
-    w) ToggleFeature OPENWSMAN_ENABLED ;;
     x) ToggleFeature AZURE_ENABLED ;;
     y) if $LINUX; then ToggleFeature SYSTEMD_ENABLED; fi ;;
-    z) ToggleFeature NANOFI_ENABLED ;;
     aa) ToggleFeature SPLUNK_ENABLED ;;
     ab) ToggleFeature KUBERNETES_ENABLED ;;
     ac) ToggleFeature GCP_ENABLED ;;
@@ -446,14 +449,13 @@ read_feature_options(){
     ae) ToggleFeature PROMETHEUS_ENABLED ;;
     af) ToggleFeature ELASTIC_ENABLED ;;
     ag) ToggleFeature GRAFANA_LOKI_ENABLED ;;
+    ah) ToggleFeature COUCHBASE_ENABLED ;;
     1) ToggleFeature TESTS_ENABLED ;;
     2) EnableAllFeatures ;;
-    3) ToggleFeature JNI_ENABLED;;
     4) ToggleFeature USE_SHARED_LIBS;;
     5) ToggleMultiOption BUILD_PROFILE;;
     6) ToggleFeature ASAN_ENABLED;;
     7) ToggleFeature MINIFI_FAIL_ON_WARNINGS;;
-    8) ToggleFeature OPENSSL_ENABLED;;
     p) export FEATURES_SELECTED="true" ;;
     r) if [ "$GUIDED_INSTALL" = "${TRUE}" ]; then
         export MENU="main"
@@ -463,3 +465,5 @@ read_feature_options(){
     *) echo -e "${RED}Please enter an option A-Z or AA-AF or 1-7...${NO_COLOR}" && sleep 2
   esac
 }
+
+# vim: shiftwidth=2 tabstop=2 expandtab
