@@ -23,12 +23,12 @@
 #include <fstream>
 #include "range/v3/algorithm/find.hpp"
 
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "core/Processor.h"
 #include "Controller.h"
 #include "c2/ControllerSocketProtocol.h"
-#include "utils/IntegrationTestUtils.h"
+#include "unit/TestUtils.h"
 #include "c2/ControllerSocketMetricsPublisher.h"
 #include "core/controller/ControllerServiceProvider.h"
 #include "controllers/SSLContextService.h"
@@ -164,14 +164,10 @@ class TestUpdateSink : public minifi::state::StateMonitor {
     return {};
   }
 
-  int16_t applyUpdate(const std::string& /*source*/, const std::string& /*configuration*/, bool /*persist*/ = false, const std::optional<std::string>& /*flow_id*/ = std::nullopt) override {
+  nonstd::expected<void, std::string> applyUpdate(const std::string& /*source*/, const std::string& /*configuration*/, bool /*persist*/ = false,
+                                                  const std::optional<std::string>& /*flow_id*/ = std::nullopt) override {
     update_calls++;
-    return 0;
-  }
-
-  int16_t applyUpdate(const std::string& /*source*/, const std::shared_ptr<minifi::state::Update>& /*updateController*/) override {
-    update_calls++;
-    return 0;
+    return {};
   }
 
   uint64_t getUptime() override {
@@ -308,7 +304,7 @@ TEST_CASE_METHOD(ControllerTestFixture, "Test listComponents", "[controllerTests
 
   minifi::controller::startComponent(controller_socket_data_, "TestStateController");
 
-  using org::apache::nifi::minifi::utils::verifyEventHappenedInPollTime;
+  using org::apache::nifi::minifi::test::utils::verifyEventHappenedInPollTime;
   REQUIRE(verifyEventHappenedInPollTime(5s, [&] { return controller_->isRunning(); }, 20ms));
 
   minifi::controller::stopComponent(controller_socket_data_, "TestStateController");
@@ -338,7 +334,7 @@ TEST_CASE_METHOD(ControllerTestFixture, "TestClear", "[controllerTests]") {
 
   minifi::controller::startComponent(controller_socket_data_, "TestStateController");
 
-  using org::apache::nifi::minifi::utils::verifyEventHappenedInPollTime;
+  using org::apache::nifi::minifi::test::utils::verifyEventHappenedInPollTime;
   REQUIRE(verifyEventHappenedInPollTime(5s, [&] { return controller_->isRunning(); }, 20ms));
 
   for (auto i = 0; i < 3; ++i) {
@@ -364,7 +360,7 @@ TEST_CASE_METHOD(ControllerTestFixture, "TestUpdate", "[controllerTests]") {
   initalizeControllerSocket();
   minifi::controller::startComponent(controller_socket_data_, "TestStateController");
 
-  using org::apache::nifi::minifi::utils::verifyEventHappenedInPollTime;
+  using org::apache::nifi::minifi::test::utils::verifyEventHappenedInPollTime;
   REQUIRE(verifyEventHappenedInPollTime(5s, [&] { return controller_->isRunning(); }, 20ms));
 
   std::stringstream ss;
