@@ -17,6 +17,7 @@ import shortuuid
 from .containers.MinifiContainer import MinifiOptions
 from .containers.MinifiContainer import MinifiContainer
 from .containers.NifiContainer import NifiContainer
+from .containers.NifiContainer import NiFiOptions
 from .containers.ZookeeperContainer import ZookeeperContainer
 from .containers.KafkaBrokerContainer import KafkaBrokerContainer
 from .containers.S3ServerContainer import S3ServerContainer
@@ -38,6 +39,8 @@ from .containers.MinifiC2ServerContainer import MinifiC2ServerContainer
 from .containers.GrafanaLokiContainer import GrafanaLokiContainer
 from .containers.GrafanaLokiContainer import GrafanaLokiOptions
 from .containers.ReverseProxyContainer import ReverseProxyContainer
+from .containers.DiagSlave import DiagSlave
+from .containers.CouchbaseServerContainer import CouchbaseServerContainer
 from .FeatureContext import FeatureContext
 
 
@@ -51,6 +54,7 @@ class ContainerStore:
         self.network = network
         self.image_store = image_store
         self.kubernetes_proxy = kubernetes_proxy
+        self.nifi_options = NiFiOptions()
 
     def get_container_name_with_postfix(self, container_name: str):
         if not container_name.endswith(self.feature_id):
@@ -82,13 +86,14 @@ class ContainerStore:
             logging.info('Container name was not provided; using generated name \'%s\'', container_name)
 
         feature_context = FeatureContext(feature_id=context.feature_id,
-                                         root_ca_cert=context.test.root_ca_cert,
-                                         root_ca_key=context.test.root_ca_key)
+                                         root_ca_cert=context.root_ca_cert,
+                                         root_ca_key=context.root_ca_key)
 
         if engine == 'nifi':
             return self.containers.setdefault(container_name,
                                               NifiContainer(feature_context=feature_context,
                                                             config_dir=self.data_directories["nifi_config_dir"],
+                                                            options=self.nifi_options,
                                                             name=container_name,
                                                             vols=self.vols,
                                                             network=self.network,
@@ -290,6 +295,22 @@ class ContainerStore:
                                                                     network=self.network,
                                                                     image_store=self.image_store,
                                                                     command=command))
+        elif engine == "diag-slave-tcp":
+            return self.containers.setdefault(container_name,
+                                              DiagSlave(feature_context=feature_context,
+                                                        name=container_name,
+                                                        vols=self.vols,
+                                                        network=self.network,
+                                                        image_store=self.image_store,
+                                                        command=command))
+        elif engine == "couchbase-server":
+            return self.containers.setdefault(container_name,
+                                              CouchbaseServerContainer(feature_context=feature_context,
+                                                                       name=container_name,
+                                                                       vols=self.vols,
+                                                                       network=self.network,
+                                                                       image_store=self.image_store,
+                                                                       command=command))
         else:
             raise Exception('invalid flow engine: \'%s\'' % engine)
 
@@ -364,6 +385,9 @@ class ContainerStore:
     def set_yaml_in_minifi(self):
         self.minifi_options.config_format = "yaml"
 
+    def set_json_in_minifi(self):
+        self.minifi_options.config_format = "json"
+
     def set_controller_socket_properties_in_minifi(self):
         self.minifi_options.enable_controller_socket = True
 
@@ -393,3 +417,10 @@ class ContainerStore:
 
     def enable_multi_tenancy_in_grafana_loki(self):
         self.grafana_loki_options.enable_multi_tenancy = True
+
+    def enable_ssl_in_nifi(self):
+        self.nifi_options.use_ssl = True
+
+    def run_post_startup_commands(self, container_name):
+        container_name = self.get_container_name_with_postfix(container_name)
+        return self.containers[container_name].run_post_startup_commands()
