@@ -34,6 +34,8 @@ from .checkers.PostgresChecker import PostgresChecker
 from .checkers.PrometheusChecker import PrometheusChecker
 from .checkers.SplunkChecker import SplunkChecker
 from .checkers.GrafanaLokiChecker import GrafanaLokiChecker
+from .checkers.ModbusChecker import ModbusChecker
+from .checkers.CouchbaseChecker import CouchbaseChecker
 from utils import get_peak_memory_usage, get_minifi_pid, get_memory_usage, retry_check
 
 
@@ -52,6 +54,8 @@ class DockerTestCluster:
         self.prometheus_checker = PrometheusChecker()
         self.grafana_loki_checker = GrafanaLokiChecker()
         self.minifi_controller_executor = MinifiControllerExecutor(self.container_communicator)
+        self.modbus_checker = ModbusChecker(self.container_communicator)
+        self.couchbase_checker = CouchbaseChecker()
 
     def cleanup(self):
         self.container_store.cleanup()
@@ -122,6 +126,9 @@ class DockerTestCluster:
     def set_yaml_in_minifi(self):
         self.container_store.set_yaml_in_minifi()
 
+    def set_json_in_minifi(self):
+        self.container_store.set_json_in_minifi()
+
     def set_controller_socket_properties_in_minifi(self):
         self.container_store.set_controller_socket_properties_in_minifi()
 
@@ -228,10 +235,6 @@ class DockerTestCluster:
         container_name = self.container_store.get_container_name_with_postfix(container_name)
         return self.splunk_checker.enable_splunk_hec_ssl(container_name, splunk_cert_pem, splunk_key_pem, root_ca_cert_pem)
 
-    def get_splunk_token(self, container_name, hec_name):
-        container_name = self.container_store.get_container_name_with_postfix(container_name)
-        return self.splunk_checker.get_splunk_token(container_name, hec_name)
-
     def check_google_cloud_storage(self, gcs_container_name, content):
         gcs_container_name = self.container_store.get_container_name_with_postfix(gcs_container_name)
         return self.gcs_checker.check_google_cloud_storage(gcs_container_name, content)
@@ -277,6 +280,9 @@ class DockerTestCluster:
     def wait_for_processor_metric_on_prometheus(self, metric_class, timeout_seconds, processor_name):
         return self.prometheus_checker.wait_for_processor_metric_on_prometheus(metric_class, timeout_seconds, processor_name)
 
+    def verify_all_metric_types_are_defined_once(self):
+        return self.prometheus_checker.verify_all_metric_types_are_defined_once()
+
     def check_minifi_log_matches_regex(self, regex, timeout_seconds=60, count=1):
         for container_name in self.container_store.get_container_names("minifi-cpp"):
             line_found = self.wait_for_app_logs_regex(container_name, regex, timeout_seconds, count)
@@ -304,8 +310,11 @@ class DockerTestCluster:
         startup_success = self.wait_for_startup_log(container_name, 300)
         if not startup_success:
             logging.error("Cluster startup failed for %s", container_name)
-            self.log_app_output()
-        return startup_success
+            return False
+        if not self.container_store.run_post_startup_commands(container_name):
+            logging.error("Failed to run post startup commands for container %s", container_name)
+            return False
+        return True
 
     def wait_for_all_containers_to_finish_startup(self):
         for container_name in self.container_store.get_container_names():
@@ -414,3 +423,12 @@ class DockerTestCluster:
 
     def wait_for_lines_on_grafana_loki(self, lines: List[str], timeout_seconds: int, ssl: bool, tenant_id: str):
         return self.grafana_loki_checker.wait_for_lines_on_grafana_loki(lines, timeout_seconds, ssl, tenant_id)
+
+    def set_value_on_plc_with_modbus(self, container_name, modbus_cmd):
+        return self.modbus_checker.set_value_on_plc_with_modbus(container_name, modbus_cmd)
+
+    def enable_ssl_in_nifi(self):
+        self.container_store.enable_ssl_in_nifi()
+
+    def is_data_present_in_couchbase(self, doc_id: str, bucket_name: str, expected_data: str, expected_data_type: str):
+        return self.couchbase_checker.is_data_present_in_couchbase(doc_id, bucket_name, expected_data, expected_data_type)
