@@ -66,6 +66,8 @@ class ImageStore:
             image = self.__build_splunk_image()
         elif container_engine == "reverse-proxy":
             image = self.__build_reverse_proxy_image()
+        elif container_engine == "diag-slave-tcp":
+            image = self.__build_diagslave_image()
         else:
             raise Exception("There is no associated image for " + container_engine)
 
@@ -73,13 +75,25 @@ class ImageStore:
         return image
 
     def __build_minifi_cpp_sql_image(self):
+        if "rocky" in MinifiContainer.MINIFI_TAG_PREFIX:
+            install_sql_cmd = "dnf -y install postgresql-odbc"
+            so_location = "psqlodbca.so"
+        elif "bullseye" in MinifiContainer.MINIFI_TAG_PREFIX or "bookworm" in MinifiContainer.MINIFI_TAG_PREFIX:
+            install_sql_cmd = "apt -y install odbc-postgresql"
+            so_location = "/usr/lib/$(gcc -dumpmachine)/odbc/psqlodbca.so"
+        elif "jammy" in MinifiContainer.MINIFI_TAG_PREFIX or "noble" in MinifiContainer.MINIFI_TAG_PREFIX:
+            install_sql_cmd = "apt -y install odbc-postgresql"
+            so_location = "/usr/lib/$(gcc -dumpmachine)/odbc/psqlodbca.so"
+        else:
+            install_sql_cmd = "apk --update --no-cache add psqlodbc"
+            so_location = "psqlodbca.so"
         dockerfile = dedent("""\
                 FROM {base_image}
                 USER root
-                RUN apk --update --no-cache add psqlodbc
+                RUN {install_sql_cmd}
                 RUN echo "[PostgreSQL ANSI]" > /odbcinst.ini.template && \
                     echo "Description=PostgreSQL ODBC driver (ANSI version)" >> /odbcinst.ini.template && \
-                    echo "Driver=psqlodbca.so" >> /odbcinst.ini.template && \
+                    echo "Driver={so_location}" >> /odbcinst.ini.template && \
                     echo "Setup=libodbcpsqlS.so" >> /odbcinst.ini.template && \
                     echo "Debug=0" >> /odbcinst.ini.template && \
                     echo "CommLog=1" >> /odbcinst.ini.template && \
@@ -103,7 +117,8 @@ class ImageStore:
                     echo "Password = password" >> /etc/odbc.ini && \
                     echo "Database = postgres" >> /etc/odbc.ini
                 USER minificpp
-                """.format(base_image='apacheminificpp:' + MinifiContainer.MINIFI_TAG_PREFIX + MinifiContainer.MINIFI_VERSION))
+                """.format(base_image='apacheminificpp:' + MinifiContainer.MINIFI_TAG_PREFIX + MinifiContainer.MINIFI_VERSION,
+                           install_sql_cmd=install_sql_cmd, so_location=so_location))
 
         return self.__build_image(dockerfile)
 
@@ -128,7 +143,10 @@ class ImageStore:
         parse_document_sed_cmd = 'sed -i "/class ProcessorDetails:/,/^$/{/^\\s*dependencies\\s*=/,/\\]\\s*$/d}" /opt/minifi/minifi-current/minifi-python/nifi_python_processors/ParseDocument.py && \\'
         chunk_document_sed_cmd = 'sed -i "/class ProcessorDetails:/,/^$/{/^\\s*dependencies\\s*=/,/\\]\\s*$/d}" /opt/minifi/minifi-current/minifi-python/nifi_python_processors/ChunkDocument.py && \\'
         if python_option == PythonOptions.SYSTEM_INSTALLED_PACKAGES:
-            additional_cmd = "RUN pip3 install --break-system-packages 'langchain<=0.17.0'"
+            if not MinifiContainer.MINIFI_TAG_PREFIX or "bookworm" in MinifiContainer.MINIFI_TAG_PREFIX or "noble" in MinifiContainer.MINIFI_TAG_PREFIX:
+                additional_cmd = "RUN pip3 install --break-system-packages 'langchain<=0.17.0'"
+            else:
+                additional_cmd = "RUN pip3 install 'langchain<=0.17.0'"
         elif python_option == PythonOptions.REQUIREMENTS_FILE:
             requirements_install_command = "echo 'langchain<=0.17.0' > /opt/minifi/minifi-current/minifi-python/nifi_python_processors/requirements.txt && \\"
         elif python_option == PythonOptions.INLINE_DEFINED_PACKAGES:
@@ -144,6 +162,16 @@ class ImageStore:
                 USER minificpp
                 COPY RotatingForwarder.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/RotatingForwarder.py
                 COPY SpecialPropertyTypeChecker.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/SpecialPropertyTypeChecker.py
+                COPY ProcessContextInterfaceChecker.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/ProcessContextInterfaceChecker.py
+                COPY CreateFlowFile.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/CreateFlowFile.py
+                COPY FailureWithAttributes.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/FailureWithAttributes.py
+                COPY subtractutils.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/compute/subtractutils.py
+                COPY RelativeImporterProcessor.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/compute/processors/RelativeImporterProcessor.py
+                COPY multiplierutils.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/compute/processors/multiplierutils.py
+                COPY CreateNothing.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/CreateNothing.py
+                COPY FailureWithContent.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/FailureWithContent.py
+                COPY TransferToOriginal.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/TransferToOriginal.py
+                COPY SetRecordField.py /opt/minifi/minifi-current/minifi-python/nifi_python_processors/SetRecordField.py
                 RUN wget {parse_document_url} --directory-prefix=/opt/minifi/minifi-current/minifi-python/nifi_python_processors && \\
                     wget {chunk_document_url} --directory-prefix=/opt/minifi/minifi-current/minifi-python/nifi_python_processors && \\
                     echo 'langchain<=0.17.0' > /opt/minifi/minifi-current/minifi-python/nifi_python_processors/requirements.txt && \\
@@ -163,8 +191,23 @@ class ImageStore:
                            parse_document_sed_cmd=parse_document_sed_cmd,
                            chunk_document_sed_cmd=chunk_document_sed_cmd))
 
-        return self.__build_image(dockerfile, [os.path.join(self.test_dir, "resources", "python", "RotatingForwarder.py"),
-                                               os.path.join(self.test_dir, "resources", "python", "SpecialPropertyTypeChecker.py")])
+        def build_full_python_resource_path(resource):
+            return os.path.join(self.test_dir, "resources", "python", resource)
+
+        return self.__build_image(dockerfile, [
+            build_full_python_resource_path("RotatingForwarder.py"),
+            build_full_python_resource_path("SpecialPropertyTypeChecker.py"),
+            build_full_python_resource_path("ProcessContextInterfaceChecker.py"),
+            build_full_python_resource_path("CreateFlowFile.py"),
+            build_full_python_resource_path("FailureWithAttributes.py"),
+            build_full_python_resource_path("RelativeImporterProcessor.py"),
+            build_full_python_resource_path("subtractutils.py"),
+            build_full_python_resource_path("multiplierutils.py"),
+            build_full_python_resource_path("CreateNothing.py"),
+            build_full_python_resource_path("FailureWithContent.py"),
+            build_full_python_resource_path("TransferToOriginal.py"),
+            build_full_python_resource_path("SetRecordField.py"),
+        ])
 
     def __build_http_proxy_image(self):
         dockerfile = dedent("""\
@@ -213,6 +256,9 @@ class ImageStore:
     def __build_reverse_proxy_image(self):
         return self.__build_image_by_path(self.test_dir + "/resources/reverse-proxy", 'reverse-proxy')
 
+    def __build_diagslave_image(self):
+        return self.__build_image_by_path(self.test_dir + "/resources/diagslave", 'diag-slave-tcp')
+
     def __build_image(self, dockerfile, context_files=[]):
         conf_dockerfile_buffer = BytesIO()
         docker_context_buffer = BytesIO()
