@@ -12,22 +12,14 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
-
 import logging
 import time
 import uuid
+
 from typing import List
-
-import OpenSSL.crypto
-
 from pydoc import locate
-
-from ssl_utils.SSL_cert_utils import make_self_signed_cert, make_cert_without_extended_usage, make_server_cert
 from minifi.core.InputPort import InputPort
-
 from cluster.DockerTestCluster import DockerTestCluster
-
 from minifi.validators.OutputValidator import OutputValidator
 from minifi.validators.EmptyFilesOutPutValidator import EmptyFilesOutPutValidator
 from minifi.validators.NoFileOutPutValidator import NoFileOutPutValidator
@@ -54,44 +46,7 @@ class MiNiFi_integration_test:
         self.test_file_hash = None
 
         self.docker_directory_bindings = context.directory_bindings
-        self.cluster.set_directory_bindings(self.docker_directory_bindings.get_directory_bindings(self.feature_id), self.docker_directory_bindings.get_data_directories(self.feature_id))
-        self.root_ca_cert, self.root_ca_key = make_self_signed_cert("root CA")
-
-        minifi_client_cert, minifi_client_key = make_cert_without_extended_usage(common_name=f"minifi-cpp-flow-{self.feature_id}",
-                                                                                 ca_cert=self.root_ca_cert,
-                                                                                 ca_key=self.root_ca_key)
-        minifi_server_cert, minifi_server_key = make_server_cert(common_name=f"server-{self.feature_id}",
-                                                                 ca_cert=self.root_ca_cert,
-                                                                 ca_key=self.root_ca_key)
-        self_signed_server_cert, self_signed_server_key = make_self_signed_cert(f"server-{self.feature_id}")
-
-        self.put_test_resource('root_ca.crt',
-                               OpenSSL.crypto.dump_certificate(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                               cert=self.root_ca_cert))
-        self.put_test_resource("system_certs_dir/ca-root-nss.crt",
-                               OpenSSL.crypto.dump_certificate(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                               cert=self.root_ca_cert))
-        self.put_test_resource('minifi_client.crt',
-                               OpenSSL.crypto.dump_certificate(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                               cert=minifi_client_cert))
-        self.put_test_resource('minifi_client.key',
-                               OpenSSL.crypto.dump_privatekey(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                              pkey=minifi_client_key))
-        self.put_test_resource('minifi_server.crt',
-                               OpenSSL.crypto.dump_certificate(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                               cert=minifi_server_cert)
-                               + OpenSSL.crypto.dump_privatekey(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                                pkey=minifi_server_key))
-        self.put_test_resource('self_signed_server.crt',
-                               OpenSSL.crypto.dump_certificate(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                               cert=self_signed_server_cert)
-                               + OpenSSL.crypto.dump_privatekey(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                                pkey=self_signed_server_key))
-        self.put_test_resource('minifi_merged_cert.crt',
-                               OpenSSL.crypto.dump_certificate(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                               cert=minifi_client_cert)
-                               + OpenSSL.crypto.dump_privatekey(type=OpenSSL.crypto.FILETYPE_PEM,
-                                                                pkey=minifi_client_key))
+        self.cluster.set_directory_bindings(self.docker_directory_bindings.get_directory_bindings(), self.docker_directory_bindings.get_data_directories())
 
     def get_container_name_with_postfix(self, container_name: str):
         return self.cluster.container_store.get_container_name_with_postfix(container_name)
@@ -108,44 +63,43 @@ class MiNiFi_integration_test:
         self.cluster.acquire_container(context=context, name='kafka-broker', engine='kafka-broker')
         self.cluster.deploy_container(name='zookeeper')
         self.cluster.deploy_container(name='kafka-broker')
-        assert self.cluster.wait_for_container_startup_to_finish('kafka-broker')
+        assert self.cluster.wait_for_container_startup_to_finish('kafka-broker') or self.cluster.log_app_output()
 
     def start_splunk(self, context):
         self.cluster.acquire_container(context=context, name='splunk', engine='splunk')
         self.cluster.deploy_container(name='splunk')
-        assert self.cluster.wait_for_container_startup_to_finish('splunk')
-        assert self.cluster.enable_splunk_hec_indexer('splunk', 'splunk_hec_token')
-
-    def get_splunk_token(self):
-        token = self.cluster.get_splunk_token('splunk', 'splunk_hec_token')
-        if token is None:
-            raise Exception("Failed to get Splunk token")
-        return token
+        assert self.cluster.wait_for_container_startup_to_finish('splunk') or self.cluster.log_app_output()
+        assert self.cluster.enable_splunk_hec_indexer('splunk', 'splunk_hec_token') or self.cluster.log_app_output()
 
     def start_elasticsearch(self, context):
         self.cluster.acquire_container(context=context, name='elasticsearch', engine='elasticsearch')
         self.cluster.deploy_container('elasticsearch')
-        assert self.cluster.wait_for_container_startup_to_finish('elasticsearch')
+        assert self.cluster.wait_for_container_startup_to_finish('elasticsearch') or self.cluster.log_app_output()
 
     def start_opensearch(self, context):
         self.cluster.acquire_container(context=context, name='opensearch', engine='opensearch')
         self.cluster.deploy_container('opensearch')
-        assert self.cluster.wait_for_container_startup_to_finish('opensearch')
+        assert self.cluster.wait_for_container_startup_to_finish('opensearch') or self.cluster.log_app_output()
 
     def start_minifi_c2_server(self, context):
         self.cluster.acquire_container(context=context, name="minifi-c2-server", engine="minifi-c2-server")
         self.cluster.deploy_container('minifi-c2-server')
-        assert self.cluster.wait_for_container_startup_to_finish('minifi-c2-server')
+        assert self.cluster.wait_for_container_startup_to_finish('minifi-c2-server') or self.cluster.log_app_output()
+
+    def start_couchbase_server(self, context):
+        self.cluster.acquire_container(context=context, name='couchbase-server', engine='couchbase-server')
+        self.cluster.deploy_container('couchbase-server')
+        assert self.cluster.wait_for_container_startup_to_finish('couchbase-server') or self.cluster.log_app_output()
 
     def start(self, container_name=None):
         if container_name is not None:
             logging.info("Starting container %s", container_name)
             self.cluster.deploy_container(container_name)
-            assert self.cluster.wait_for_container_startup_to_finish(container_name)
+            assert self.cluster.wait_for_container_startup_to_finish(container_name) or self.cluster.log_app_output()
             return
         logging.info("MiNiFi_integration_test start")
         self.cluster.deploy_all()
-        assert self.cluster.wait_for_all_containers_to_finish_startup()
+        assert self.cluster.wait_for_all_containers_to_finish_startup() or self.cluster.log_app_output()
 
     def stop(self, container_name):
         logging.info("Stopping container %s", container_name)
@@ -202,18 +156,18 @@ class MiNiFi_integration_test:
         if file_name is None:
             file_name = str(uuid.uuid4())
         test_data = decode_escaped_str(test_data)
-        self.docker_directory_bindings.put_file_to_docker_path(self.feature_id, path, file_name, test_data.encode('utf-8'))
+        self.docker_directory_bindings.put_file_to_docker_path(path, file_name, test_data.encode('utf-8'))
 
     def add_random_test_data(self, path: str, size: int, file_name: str = None):
         if file_name is None:
             file_name = str(uuid.uuid4())
-        self.test_file_hash = self.docker_directory_bindings.put_random_file_to_docker_path(self.feature_id, path, file_name, size)
+        self.test_file_hash = self.docker_directory_bindings.put_random_file_to_docker_path(path, file_name, size)
 
     def put_test_resource(self, file_name, contents):
-        self.docker_directory_bindings.put_test_resource(self.feature_id, file_name, contents)
+        self.docker_directory_bindings.put_test_resource(file_name, contents)
 
-    def rm_out_child(self):
-        self.docker_directory_bindings.rm_out_child(self.feature_id)
+    def get_test_resource_path(self, file_name):
+        return self.docker_directory_bindings.get_test_resource_path(file_name)
 
     def add_file_system_observer(self, file_system_observer):
         self.file_system_observer = file_system_observer
@@ -378,6 +332,9 @@ class MiNiFi_integration_test:
     def check_processor_metric_on_prometheus(self, metric_class, timeout_seconds, processor_name):
         assert self.cluster.wait_for_processor_metric_on_prometheus(metric_class, timeout_seconds, processor_name) or self.cluster.log_app_output()
 
+    def check_all_prometheus_metric_types_are_defined_once(self):
+        assert self.cluster.verify_all_metric_types_are_defined_once() or self.cluster.log_app_output()
+
     def check_if_peak_memory_usage_exceeded(self, minimum_peak_memory_usage: int, timeout_seconds: int) -> None:
         assert self.cluster.wait_for_peak_memory_usage_to_exceed(minimum_peak_memory_usage, timeout_seconds) or self.cluster.log_app_output()
 
@@ -438,6 +395,9 @@ class MiNiFi_integration_test:
     def set_yaml_in_minifi(self):
         self.cluster.set_yaml_in_minifi()
 
+    def set_json_in_minifi(self):
+        self.cluster.set_json_in_minifi()
+
     def set_controller_socket_properties_in_minifi(self):
         self.cluster.set_controller_socket_properties_in_minifi()
 
@@ -482,3 +442,12 @@ class MiNiFi_integration_test:
 
     def check_lines_on_grafana_loki(self, lines: List[str], timeout_seconds: int, ssl: bool, tenant_id=None):
         assert self.cluster.wait_for_lines_on_grafana_loki(lines, timeout_seconds, ssl, tenant_id) or self.cluster.log_app_output()
+
+    def set_value_on_plc_with_modbus(self, container_name, modbus_cmd):
+        assert self.cluster.set_value_on_plc_with_modbus(container_name, modbus_cmd)
+
+    def enable_ssl_in_nifi(self):
+        self.cluster.enable_ssl_in_nifi()
+
+    def check_is_data_present_on_couchbase(self, doc_id: str, bucket_name: str, expected_data: str, expected_data_type: str):
+        assert self.cluster.is_data_present_in_couchbase(doc_id, bucket_name, expected_data, expected_data_type)
