@@ -24,6 +24,9 @@ from minifi.controllers.GCPCredentialsControllerService import GCPCredentialsCon
 from minifi.controllers.ElasticsearchCredentialsService import ElasticsearchCredentialsService
 from minifi.controllers.ODBCService import ODBCService
 from minifi.controllers.KubernetesControllerService import KubernetesControllerService
+from minifi.controllers.JsonRecordSetWriter import JsonRecordSetWriter
+from minifi.controllers.JsonRecordSetReader import JsonRecordSetReader
+from minifi.controllers.CouchbaseClusterService import CouchbaseClusterService
 
 from behave import given, then, when
 from behave.model_describe import ModelDescriptor
@@ -46,7 +49,7 @@ import os
 # Background
 @given("the content of \"{directory}\" is monitored")
 def step_impl(context, directory):
-    context.test.add_file_system_observer(FileSystemObserver(context.directory_bindings.docker_path_to_local_path(context.feature_id, directory)))
+    context.test.add_file_system_observer(FileSystemObserver(context.directory_bindings.docker_path_to_local_path(directory)))
 
 
 def __create_processor(context, processor_type, processor_name, property_name, property_value, container_name, engine='minifi-cpp'):
@@ -270,6 +273,7 @@ def step_impl(context):
 
 
 @given("a file with the content \"{content}\" is present in \"{path}\"")
+@given("a file with the content '{content}' is present in '{path}'")
 @then("a file with the content \"{content}\" is placed in \"{path}\"")
 def step_impl(context, content, path):
     context.test.add_test_data(path, content)
@@ -317,7 +321,7 @@ def step_impl(context, processor_name):
 
 
 # NiFi setups
-@given("a NiFi flow receiving data from a RemoteProcessGroup \"{source_name}\" on port 8080")
+@given("a NiFi flow receiving data from a RemoteProcessGroup \"{source_name}\"")
 def step_impl(context, source_name):
     remote_process_group = context.test.get_remote_process_group_by_name("RemoteProcessGroup")
     source = context.test.generate_input_port_for_remote_process_group(remote_process_group, source_name)
@@ -334,6 +338,11 @@ def step_impl(context, flow_name):
     context.test.acquire_container(context=context, name=flow_name, engine='nifi')
 
 
+@given("SSL is enabled in NiFi flow")
+def step_impl(context):
+    context.test.enable_ssl_in_nifi()
+
+
 @given("a transient MiNiFi flow with the name \"{flow_name}\" is set up")
 def step_impl(context, flow_name):
     context.test.acquire_container(context=context, name=flow_name, command=["/bin/sh", "-c", "timeout 10s ./bin/minifi.sh run && sleep 100"])
@@ -395,6 +404,21 @@ def step_impl(context, processor_name):
     processor.set_property('SSL Context Service', ssl_context_service.name)
 
 
+# Record set reader and writer
+@given("a JsonRecordSetWriter controller service is set up with \"{}\" output grouping")
+def step_impl(context, output_grouping: str):
+    json_record_set_writer = JsonRecordSetWriter(name="JsonRecordSetWriter", output_grouping=output_grouping)
+    container = context.test.acquire_container(context=context, name="minifi-cpp-flow")
+    container.add_controller(json_record_set_writer)
+
+
+@given("a JsonRecordSetReader controller service is set up")
+def step_impl(context):
+    json_record_set_reader = JsonRecordSetReader("JsonRecordSetReader")
+    container = context.test.acquire_container(context=context, name="minifi-cpp-flow")
+    container.add_controller(json_record_set_reader)
+
+
 # Kubernetes
 def __set_up_the_kubernetes_controller_service(context, processor_name, service_property_name, properties):
     kubernetes_controller_service = KubernetesControllerService("Kubernetes Controller Service", properties)
@@ -485,9 +509,20 @@ def setUpSslContextServiceForProcessor(context, processor_name: str):
     minifi_key_file = '/tmp/resources/minifi_client.key'
     root_ca_crt_file = '/tmp/resources/root_ca.crt'
     ssl_context_service = SSLContextService(cert=minifi_crt_file, ca_cert=root_ca_crt_file, key=minifi_key_file)
-    post_elasticsearch_json = context.test.get_node_by_name(processor_name)
-    post_elasticsearch_json.controller_services.append(ssl_context_service)
-    post_elasticsearch_json.set_property("SSL Context Service", ssl_context_service.name)
+    processor = context.test.get_node_by_name(processor_name)
+    processor.controller_services.append(ssl_context_service)
+    processor.set_property("SSL Context Service", ssl_context_service.name)
+
+
+def setUpSslContextServiceForRPG(context, rpg_name: str):
+    minifi_crt_file = '/tmp/resources/minifi_client.crt'
+    minifi_key_file = '/tmp/resources/minifi_client.key'
+    root_ca_crt_file = '/tmp/resources/root_ca.crt'
+    ssl_context_service = SSLContextService(cert=minifi_crt_file, ca_cert=root_ca_crt_file, key=minifi_key_file)
+    container = context.test.acquire_container(context=context, name="minifi-cpp-flow")
+    container.add_controller(ssl_context_service)
+    rpg = context.test.get_remote_process_group_by_name(rpg_name)
+    rpg.add_property("SSL Context Service", ssl_context_service.name)
 
 
 @given(u'a SSL context service is set up for PostElasticsearch and Elasticsearch')
@@ -527,12 +562,6 @@ def step_impl(context):
     context.test.start_splunk(context)
 
 
-@given("the Splunk token property is set for the {processor_name} processor")
-def step_impl(context, processor_name):
-    token = context.test.get_splunk_token()
-    context.execute_steps(f"given the \"Token\" property of the {processor_name} processor is set to \"{token}\"")
-
-
 # TCP client
 @given('a TCP client is set up to send a test TCP message to minifi')
 def step_impl(context):
@@ -544,16 +573,16 @@ def step_impl(context):
     minifi_crt_file = '/tmp/resources/minifi_client.crt'
     minifi_key_file = '/tmp/resources/minifi_client.key'
     root_ca_crt_file = '/tmp/resources/root_ca.crt'
-    ssl_context_service = SSLContextService(cert=minifi_crt_file, ca_cert=root_ca_crt_file, key=minifi_key_file)
+    ssl_context_service = SSLContextService(name='SSLContextService', cert=minifi_crt_file, ca_cert=root_ca_crt_file, key=minifi_key_file)
 
-    splunk_cert, splunk_key = make_server_cert(context.test.get_container_name_with_postfix("splunk"), context.test.root_ca_cert, context.test.root_ca_key)
+    splunk_cert, splunk_key = make_server_cert(context.test.get_container_name_with_postfix("splunk"), context.root_ca_cert, context.root_ca_key)
     put_splunk_http = context.test.get_node_by_name("PutSplunkHTTP")
     put_splunk_http.controller_services.append(ssl_context_service)
     put_splunk_http.set_property("SSL Context Service", ssl_context_service.name)
     query_splunk_indexing_status = context.test.get_node_by_name("QuerySplunkIndexingStatus")
     query_splunk_indexing_status.controller_services.append(ssl_context_service)
     query_splunk_indexing_status.set_property("SSL Context Service", ssl_context_service.name)
-    context.test.enable_splunk_hec_ssl('splunk', OpenSSL.crypto.dump_certificate(OpenSSL.crypto.FILETYPE_PEM, splunk_cert), OpenSSL.crypto.dump_privatekey(OpenSSL.crypto.FILETYPE_PEM, splunk_key), OpenSSL.crypto.dump_certificate(OpenSSL.crypto.FILETYPE_PEM, context.test.root_ca_cert))
+    context.test.enable_splunk_hec_ssl('splunk', OpenSSL.crypto.dump_certificate(OpenSSL.crypto.FILETYPE_PEM, splunk_cert), OpenSSL.crypto.dump_privatekey(OpenSSL.crypto.FILETYPE_PEM, splunk_key), OpenSSL.crypto.dump_certificate(OpenSSL.crypto.FILETYPE_PEM, context.root_ca_cert))
 
 
 @given(u'the {processor_one} processor is set up with a GCPCredentialsControllerService to communicate with the Google Cloud storage server')
@@ -685,11 +714,11 @@ def step_impl(context, content, topic_name):
 @when("a message with content \"{content}\" is published to the \"{topic_name}\" topic using an ssl connection")
 def step_impl(context, content, topic_name):
     ca_cert_file = tempfile.NamedTemporaryFile(delete=False)
-    ca_cert_file.write(OpenSSL.crypto.dump_certificate(type=OpenSSL.crypto.FILETYPE_PEM, cert=context.test.root_ca_cert))
+    ca_cert_file.write(OpenSSL.crypto.dump_certificate(type=OpenSSL.crypto.FILETYPE_PEM, cert=context.root_ca_cert))
     ca_cert_file.close()
     os.chmod(ca_cert_file.name, 0o644)
 
-    client_cert, client_key = make_client_cert(socket.gethostname(), context.test.root_ca_cert, context.test.root_ca_key)
+    client_cert, client_key = make_client_cert(socket.gethostname(), context.root_ca_cert, context.root_ca_key)
     client_cert_file = tempfile.NamedTemporaryFile(delete=False)
     client_cert_file.write(OpenSSL.crypto.dump_certificate(OpenSSL.crypto.FILETYPE_PEM, client_cert))
     client_cert_file.close()
@@ -702,12 +731,13 @@ def step_impl(context, content, topic_name):
 
     producer = Producer({
         "bootstrap.servers": "localhost:29093",
-        "security.protocol": "ssl",
+        "security.protocol": "SSL",
         "ssl.ca.location": ca_cert_file.name,
         "ssl.certificate.location": client_cert_file.name,
         "ssl.key.location": client_key_file.name,
         "ssl.key.password": "",
-        "client.id": socket.gethostname()})
+        "client.id": socket.gethostname(),
+        "ssl.endpoint.identification.algorithm": "none"})
     producer.produce(topic_name, content.encode("utf-8"), callback=delivery_report)
     producer.flush(10)
 
@@ -1021,6 +1051,11 @@ def step_impl(context, metric_class, timeout_seconds, processor_name):
     context.test.check_processor_metric_on_prometheus(metric_class, timeout_seconds, processor_name)
 
 
+@then("all Prometheus metric types are only defined once")
+def step_impl(context):
+    context.test.check_all_prometheus_metric_types_are_defined_once()
+
+
 @then("Elasticsearch is empty")
 def step_impl(context):
     context.test.check_empty_elastic(context.test.get_container_name_with_postfix("elasticsearch"))
@@ -1060,6 +1095,11 @@ def step_impl(context):
     context.test.set_ssl_context_properties_in_minifi()
 
 
+@given("SSL properties are set in MiNiFi")
+def step_impl(context):
+    context.test.set_ssl_context_properties_in_minifi()
+
+
 @given(u'a MiNiFi C2 server is set up')
 def step_impl(context):
     context.test.acquire_container(context=context, name="minifi-c2-server", engine="minifi-c2-server")
@@ -1112,6 +1152,11 @@ def step_impl(context):
     context.test.set_yaml_in_minifi()
 
 
+@given(u'a MiNiFi CPP server with json config')
+def step_impl(context):
+    context.test.set_json_in_minifi()
+
+
 # MiNiFi controller
 @given(u'controller socket properties are set up')
 def step_impl(context):
@@ -1270,6 +1315,11 @@ def step_impl(context, processor_name: str):
     setUpSslContextServiceForProcessor(context, processor_name)
 
 
+@given(u'a SSL context service is set up for the following remote process group: \"{remote_process_group}\"')
+def step_impl(context, remote_process_group: str):
+    setUpSslContextServiceForRPG(context, remote_process_group)
+
+
 # Nginx reverse proxy
 @given(u'a reverse proxy is set up to forward requests to the Grafana Loki server')
 def step_impl(context):
@@ -1294,3 +1344,75 @@ def step_impl(context, install_mode):
 @given("the example MiNiFi python processors are present")
 def step_impl(context):
     context.test.enable_example_minifi_python_processors()
+
+
+@given("a non-sensitive parameter in the flow config called '{parameter_name}' with the value '{parameter_value}' in the parameter context '{parameter_context_name}'")
+def step_impl(context, parameter_context_name, parameter_name, parameter_value):
+    container = context.test.acquire_container(context=context, name='minifi-cpp-flow', engine='minifi-cpp')
+    container.add_parameter_to_flow_config(parameter_context_name, parameter_name, parameter_value)
+
+
+@given("parameter context name is set to '{parameter_context_name}'")
+def step_impl(context, parameter_context_name):
+    container = context.test.acquire_container(context=context, name='minifi-cpp-flow', engine='minifi-cpp')
+    container.set_parameter_context_name(parameter_context_name)
+
+
+# Modbus
+@given(u'there is an accessible PLC with modbus enabled')
+def step_impl(context):
+    context.test.acquire_container(context=context, name="diag-slave-tcp", engine="diag-slave-tcp")
+    context.test.start('diag-slave-tcp')
+
+
+@given(u'PLC register has been set with {modbus_cmd} command')
+def step_impl(context, modbus_cmd):
+    context.test.set_value_on_plc_with_modbus(context.test.get_container_name_with_postfix('diag-slave-tcp'), modbus_cmd)
+
+
+# Couchbase
+@when(u'a Couchbase server is started')
+def step_impl(context):
+    context.test.start_couchbase_server(context)
+
+
+@given("a CouchbaseClusterService is setup up with the name \"{service_name}\"")
+def step_impl(context, service_name):
+    couchbase_cluster_controller_service = CouchbaseClusterService(
+        name=service_name,
+        connection_string="couchbase://{server_hostname}".format(server_hostname=context.test.get_container_name_with_postfix("couchbase-server")))
+    container = context.test.acquire_container(context=context, name="minifi-cpp-flow")
+    container.add_controller(couchbase_cluster_controller_service)
+
+
+@given("a CouchbaseClusterService is set up up with SSL connection with the name \"{service_name}\"")
+def step_impl(context, service_name):
+    ssl_context_service = SSLContextService(name="SSLContextService",
+                                            ca_cert='/tmp/resources/root_ca.crt')
+    container = context.test.acquire_container(context=context, name="minifi-cpp-flow")
+    container.add_controller(ssl_context_service)
+    couchbase_cluster_controller_service = CouchbaseClusterService(
+        name=service_name,
+        connection_string="couchbases://{server_hostname}".format(server_hostname=context.test.get_container_name_with_postfix("couchbase-server")),
+        ssl_context_service=ssl_context_service)
+    container.add_controller(couchbase_cluster_controller_service)
+
+
+@then("a document with id \"{doc_id}\" in bucket \"{bucket_name}\" is present with data '{data}' of type \"{data_type}\" in Couchbase")
+def step_impl(context, doc_id: str, bucket_name: str, data: str, data_type: str):
+    context.test.check_is_data_present_on_couchbase(doc_id, bucket_name, data, data_type)
+
+
+@given("a CouchbaseClusterService is setup up using mTLS authentication with the name \"{service_name}\"")
+def step_impl(context, service_name):
+    ssl_context_service = SSLContextService(name="SSLContextService",
+                                            cert='/tmp/resources/clientuser.crt',
+                                            key='/tmp/resources/clientuser.key',
+                                            ca_cert='/tmp/resources/root_ca.crt')
+    container = context.test.acquire_container(context=context, name="minifi-cpp-flow")
+    container.add_controller(ssl_context_service)
+    couchbase_cluster_controller_service = CouchbaseClusterService(
+        name=service_name,
+        connection_string="couchbases://{server_hostname}".format(server_hostname=context.test.get_container_name_with_postfix("couchbase-server")),
+        ssl_context_service=ssl_context_service)
+    container.add_controller(couchbase_cluster_controller_service)
