@@ -18,8 +18,9 @@ from ..core.Processor import Processor
 
 
 class ExecuteSQL(Processor):
-    def __init__(self, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
+    def __init__(self, context, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
         super(ExecuteSQL, self).__init__(
-            'ExecuteSQL',
+            context=context,
+            clazz='ExecuteSQL',
             auto_terminate=['success'],
             schedule=schedule)
