@@ -18,9 +18,10 @@ from ..core.Processor import Processor
 
 
 class PutFile(Processor):
-    def __init__(self, output_dir="/tmp/output", schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
+    def __init__(self, context, output_dir="/tmp/output", schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
         super(PutFile, self).__init__(
-            'PutFile',
+            context=context,
+            clazz='PutFile',
             properties={'Directory': output_dir, 'Directory Permissions': '777', 'Permissions': '777'},
             auto_terminate=['success', 'failure'],
             schedule=schedule)
