@@ -18,8 +18,9 @@ from ..core.Processor import Processor
 
 
 class PutSQL(Processor):
-    def __init__(self, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
+    def __init__(self, context, schedule={'scheduling strategy': 'EVENT_DRIVEN'}):
         super(PutSQL, self).__init__(
-            'PutSQL',
+            context=context,
+            clazz='PutSQL',
             auto_terminate=['success'],
             schedule=schedule)
