@@ -33,7 +33,7 @@
 #include "utils/GeneralUtils.h"
 
 template<typename T>
-class S3TestsFixture;
+class FlowProcessorS3TestsFixture;
 
 namespace org::apache::nifi::minifi::aws::processors {
 
@@ -56,11 +56,11 @@ class FetchS3Object : public S3Processor {
       .withDescription("If true, indicates that the requester consents to pay any charges associated with retrieving "
           "objects from the S3 bucket. This sets the 'x-amz-request-payer' header to 'requester'.")
       .build();
-  EXTENSIONAPI static constexpr auto Properties = minifi::utils::array_cat(S3Processor::Properties, std::array<core::PropertyReference, 3>{
+  EXTENSIONAPI static constexpr auto Properties = minifi::utils::array_cat(S3Processor::Properties, std::to_array<core::PropertyReference>({
       ObjectKey,
       Version,
       RequesterPays
-  });
+  }));
 
 
   EXTENSIONAPI static constexpr auto Success = core::RelationshipDefinition{"success", "FlowFiles are routed to success relationship"};
@@ -85,7 +85,7 @@ class FetchS3Object : public S3Processor {
   void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
 
  private:
-  friend class ::S3TestsFixture<FetchS3Object>;
+  friend class ::FlowProcessorS3TestsFixture<FetchS3Object>;
 
   explicit FetchS3Object(const std::string& name, const minifi::utils::Identifier& uuid, std::unique_ptr<aws::s3::S3RequestSender> s3_request_sender)
     : S3Processor(name, uuid, core::logging::LoggerFactory<FetchS3Object>::getLogger(uuid), std::move(s3_request_sender)) {
