@@ -32,10 +32,10 @@ void ListS3::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void ListS3::onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory> &sessionFactory) {
-  S3Processor::onSchedule(context, sessionFactory);
+void ListS3::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) {
+  S3Processor::onSchedule(context, session_factory);
 
-  auto state_manager = context->getStateManager();
+  auto state_manager = context.getStateManager();
   if (state_manager == nullptr) {
     throw Exception(PROCESSOR_EXCEPTION, "Failed to get StateManager");
   }
@@ -51,36 +51,36 @@ void ListS3::onSchedule(const std::shared_ptr<core::ProcessContext> &context, co
   list_request_params_->setClientConfig(common_properties->proxy, common_properties->endpoint_override_url);
   list_request_params_->bucket = common_properties->bucket;
 
-  context->getProperty(Delimiter, list_request_params_->delimiter);
-  logger_->log_debug("ListS3: Delimiter [%s]", list_request_params_->delimiter);
+  context.getProperty(Delimiter, list_request_params_->delimiter);
+  logger_->log_debug("ListS3: Delimiter [{}]", list_request_params_->delimiter);
 
-  context->getProperty(Prefix, list_request_params_->prefix);
-  logger_->log_debug("ListS3: Prefix [%s]", list_request_params_->prefix);
+  context.getProperty(Prefix, list_request_params_->prefix);
+  logger_->log_debug("ListS3: Prefix [{}]", list_request_params_->prefix);
 
-  context->getProperty(UseVersions, list_request_params_->use_versions);
-  logger_->log_debug("ListS3: UseVersions [%s]", list_request_params_->use_versions ? "true" : "false");
+  context.getProperty(UseVersions, list_request_params_->use_versions);
+  logger_->log_debug("ListS3: UseVersions [{}]", list_request_params_->use_versions);
 
-  if (auto minimum_object_age = context->getProperty<core::TimePeriodValue>(MinimumObjectAge)) {
+  if (auto minimum_object_age = context.getProperty<core::TimePeriodValue>(MinimumObjectAge)) {
     list_request_params_->min_object_age = minimum_object_age->getMilliseconds().count();
   } else {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Minimum Object Age missing or invalid");
   }
-  logger_->log_debug("S3Processor: Minimum Object Age [%llud]", list_request_params_->min_object_age);
+  logger_->log_debug("S3Processor: Minimum Object Age [{}]", list_request_params_->min_object_age);
 
-  context->getProperty(WriteObjectTags, write_object_tags_);
-  logger_->log_debug("ListS3: WriteObjectTags [%s]", write_object_tags_ ? "true" : "false");
+  context.getProperty(WriteObjectTags, write_object_tags_);
+  logger_->log_debug("ListS3: WriteObjectTags [{}]", write_object_tags_);
 
-  context->getProperty(WriteUserMetadata, write_user_metadata_);
-  logger_->log_debug("ListS3: WriteUserMetadata [%s]", write_user_metadata_ ? "true" : "false");
+  context.getProperty(WriteUserMetadata, write_user_metadata_);
+  logger_->log_debug("ListS3: WriteUserMetadata [{}]", write_user_metadata_);
 
-  context->getProperty(RequesterPays, requester_pays_);
-  logger_->log_debug("ListS3: RequesterPays [%s]", requester_pays_ ? "true" : "false");
+  context.getProperty(RequesterPays, requester_pays_);
+  logger_->log_debug("ListS3: RequesterPays [{}]", requester_pays_);
 }
 
 void ListS3::writeObjectTags(
     const aws::s3::ListedObjectAttributes &object_attributes,
     core::ProcessSession &session,
-    const std::shared_ptr<core::FlowFile> &flow_file) {
+    core::FlowFile& flow_file) {
   if (!write_object_tags_) {
     return;
   }
@@ -95,14 +95,14 @@ void ListS3::writeObjectTags(
       session.putAttribute(flow_file, "s3.tag." + tag.first, tag.second);
     }
   } else {
-    logger_->log_warn("Failed to get object tags for object %s in bucket %s", object_attributes.filename, params.bucket);
+    logger_->log_warn("Failed to get object tags for object {} in bucket {}", object_attributes.filename, params.bucket);
   }
 }
 
 void ListS3::writeUserMetadata(
     const aws::s3::ListedObjectAttributes &object_attributes,
     core::ProcessSession &session,
-    const std::shared_ptr<core::FlowFile> &flow_file) {
+    core::FlowFile& flow_file) {
   if (!write_user_metadata_) {
     return;
   }
@@ -118,7 +118,7 @@ void ListS3::writeUserMetadata(
       session.putAttribute(flow_file, "s3.user.metadata." + metadata.first, metadata.second);
     }
   } else {
-    logger_->log_warn("Failed to get object metadata for object %s in bucket %s", params.object_key, params.bucket);
+    logger_->log_warn("Failed to get object metadata for object {} in bucket {}", params.object_key, params.bucket);
   }
 }
 
@@ -126,29 +126,29 @@ void ListS3::createNewFlowFile(
     core::ProcessSession &session,
     const aws::s3::ListedObjectAttributes &object_attributes) {
   auto flow_file = session.create();
-  session.putAttribute(flow_file, "s3.bucket", list_request_params_->bucket);
-  session.putAttribute(flow_file, core::SpecialFlowAttribute::FILENAME, object_attributes.filename);
-  session.putAttribute(flow_file, "s3.etag", object_attributes.etag);
-  session.putAttribute(flow_file, "s3.isLatest", object_attributes.is_latest ? "true" : "false");
-  session.putAttribute(flow_file, "s3.lastModified", std::to_string(object_attributes.last_modified.time_since_epoch() / std::chrono::milliseconds(1)));
-  session.putAttribute(flow_file, "s3.length", std::to_string(object_attributes.length));
-  session.putAttribute(flow_file, "s3.storeClass", object_attributes.store_class);
+  session.putAttribute(*flow_file, "s3.bucket", list_request_params_->bucket);
+  session.putAttribute(*flow_file, core::SpecialFlowAttribute::FILENAME, object_attributes.filename);
+  session.putAttribute(*flow_file, "s3.etag", object_attributes.etag);
+  session.putAttribute(*flow_file, "s3.isLatest", object_attributes.is_latest ? "true" : "false");
+  session.putAttribute(*flow_file, "s3.lastModified", std::to_string(object_attributes.last_modified.time_since_epoch() / std::chrono::milliseconds(1)));
+  session.putAttribute(*flow_file, "s3.length", std::to_string(object_attributes.length));
+  session.putAttribute(*flow_file, "s3.storeClass", object_attributes.store_class);
   if (!object_attributes.version.empty()) {
-    session.putAttribute(flow_file, "s3.version", object_attributes.version);
+    session.putAttribute(*flow_file, "s3.version", object_attributes.version);
   }
-  writeObjectTags(object_attributes, session, flow_file);
-  writeUserMetadata(object_attributes, session, flow_file);
+  writeObjectTags(object_attributes, session, *flow_file);
+  writeUserMetadata(object_attributes, session, *flow_file);
 
   session.transfer(flow_file, Success);
 }
 
-void ListS3::onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) {
+void ListS3::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
   logger_->log_trace("ListS3 onTrigger");
 
   auto aws_results = s3_wrapper_.listBucket(*list_request_params_);
   if (!aws_results) {
-    logger_->log_error("Failed to list S3 bucket %s", list_request_params_->bucket);
-    context->yield();
+    logger_->log_error("Failed to list S3 bucket {}", list_request_params_->bucket);
+    context.yield();
     return;
   }
 
@@ -161,17 +161,17 @@ void ListS3::onTrigger(const std::shared_ptr<core::ProcessContext> &context, con
       continue;
     }
 
-    createNewFlowFile(*session, object_attributes);
+    createNewFlowFile(session, object_attributes);
     ++files_transferred;
     latest_listing_state.updateState(object_attributes);
   }
 
-  logger_->log_debug("ListS3 transferred %zu flow files", files_transferred);
+  logger_->log_debug("ListS3 transferred {} flow files", files_transferred);
   state_manager_->storeState(latest_listing_state);
 
   if (files_transferred == 0) {
-    logger_->log_debug("No new S3 objects were found in bucket %s to list", list_request_params_->bucket);
-    context->yield();
+    logger_->log_debug("No new S3 objects were found in bucket {} to list", list_request_params_->bucket);
+    context.yield();
     return;
   }
 }
