@@ -18,11 +18,11 @@
 
 #include "S3TestsFixture.h"
 #include "processors/PutS3Object.h"
-#include "utils/IntegrationTestUtils.h"
+#include "unit/TestUtils.h"
 
 namespace {
 
-using org::apache::nifi::minifi::utils::verifyLogLinePresenceInPollTime;
+using org::apache::nifi::minifi::test::utils::verifyLogLinePresenceInPollTime;
 
 class PutS3ObjectTestsFixture : public FlowProcessorS3TestsFixture<minifi::aws::processors::PutS3Object> {
  public:
@@ -43,7 +43,7 @@ class PutS3ObjectTestsFixture : public FlowProcessorS3TestsFixture<minifi::aws::
 
 class PutS3ObjectLimitChanged : public minifi::aws::processors::PutS3Object {
  protected:
-  friend class ::S3TestsFixture<PutS3ObjectLimitChanged>;
+  friend class ::FlowProcessorS3TestsFixture<PutS3ObjectLimitChanged>;
 
   explicit PutS3ObjectLimitChanged(const std::string& name, const minifi::utils::Identifier& uuid, std::unique_ptr<minifi::aws::s3::S3RequestSender> s3_request_sender)
     : PutS3Object(name, uuid, std::move(s3_request_sender)) {
