@@ -29,13 +29,13 @@ namespace org::apache::nifi::minifi::azure::processors {
 namespace {
 std::shared_ptr<core::FlowFile> createNewFlowFile(core::ProcessSession &session, const storage::ListDataLakeStorageElement &element) {
   auto flow_file = session.create();
-  session.putAttribute(flow_file, "azure.filesystem", element.filesystem);
-  session.putAttribute(flow_file, "azure.filePath", element.file_path);
-  session.putAttribute(flow_file, "azure.directory", element.directory.generic_string());
-  session.putAttribute(flow_file, "azure.filename", element.filename.generic_string());
-  session.putAttribute(flow_file, "azure.length", std::to_string(element.length));
-  session.putAttribute(flow_file, "azure.lastModified", std::to_string(element.last_modified.time_since_epoch() / std::chrono::milliseconds(1)));
-  session.putAttribute(flow_file, "azure.etag", element.etag);
+  session.putAttribute(*flow_file, "azure.filesystem", element.filesystem);
+  session.putAttribute(*flow_file, "azure.filePath", element.file_path);
+  session.putAttribute(*flow_file, "azure.directory", element.directory.generic_string());
+  session.putAttribute(*flow_file, "azure.filename", element.filename.generic_string());
+  session.putAttribute(*flow_file, "azure.length", std::to_string(element.length));
+  session.putAttribute(*flow_file, "azure.lastModified", std::to_string(element.last_modified.time_since_epoch() / std::chrono::milliseconds(1)));
+  session.putAttribute(*flow_file, "azure.etag", element.etag);
   return flow_file;
 }
 }  // namespace
@@ -45,23 +45,22 @@ void ListAzureDataLakeStorage::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void ListAzureDataLakeStorage::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& sessionFactory) {
-  gsl_Expects(context && sessionFactory);
-  AzureDataLakeStorageProcessorBase::onSchedule(context, sessionFactory);
+void ListAzureDataLakeStorage::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) {
+  AzureDataLakeStorageProcessorBase::onSchedule(context, session_factory);
 
-  auto state_manager = context->getStateManager();
+  auto state_manager = context.getStateManager();
   if (state_manager == nullptr) {
     throw Exception(PROCESSOR_EXCEPTION, "Failed to get StateManager");
   }
   state_manager_ = std::make_unique<minifi::utils::ListingStateManager>(state_manager);
 
-  auto params = buildListParameters(*context);
+  auto params = buildListParameters(context);
   if (!params) {
     throw Exception(PROCESS_SCHEDULE_EXCEPTION, "Required parameters for ListAzureDataLakeStorage processor are missing or invalid");
   }
 
   list_parameters_ = *std::move(params);
-  tracking_strategy_ = utils::parseEnumProperty<azure::EntityTracking>(*context, ListingStrategy);
+  tracking_strategy_ = utils::parseEnumProperty<azure::EntityTracking>(context, ListingStrategy);
 }
 
 std::optional<storage::ListAzureDataLakeStorageParameters> ListAzureDataLakeStorage::buildListParameters(core::ProcessContext& context) {
@@ -95,13 +94,12 @@ std::optional<storage::ListAzureDataLakeStorageParameters> ListAzureDataLakeStor
   return params;
 }
 
-void ListAzureDataLakeStorage::onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) {
-  gsl_Expects(context && session);
+void ListAzureDataLakeStorage::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
   logger_->log_trace("ListAzureDataLakeStorage onTrigger");
 
   auto list_result = azure_data_lake_storage_.listDirectory(list_parameters_);
   if (!list_result || list_result->empty()) {
-    context->yield();
+    context.yield();
     return;
   }
 
@@ -114,19 +112,19 @@ void ListAzureDataLakeStorage::onTrigger(const std::shared_ptr<core::ProcessCont
       continue;
     }
 
-    auto flow_file = createNewFlowFile(*session, element);
-    session->transfer(flow_file, Success);
+    auto flow_file = createNewFlowFile(session, element);
+    session.transfer(flow_file, Success);
     ++files_transferred;
     latest_listing_state.updateState(element);
   }
 
   state_manager_->storeState(latest_listing_state);
 
-  logger_->log_debug("ListAzureDataLakeStorage transferred %zu flow files", files_transferred);
+  logger_->log_debug("ListAzureDataLakeStorage transferred {} flow files", files_transferred);
 
   if (files_transferred == 0) {
-    logger_->log_debug("No new Azure Data Lake Storage files were found in directory '%s' of filesystem '%s'", list_parameters_.directory_name, list_parameters_.file_system_name);
-    context->yield();
+    logger_->log_debug("No new Azure Data Lake Storage files were found in directory '{}' of filesystem '{}'", list_parameters_.directory_name, list_parameters_.file_system_name);
+    context.yield();
     return;
   }
 }
