@@ -52,7 +52,7 @@ class PutAzureBlobStorage final : public AzureBlobStorageSingleBlobProcessorBase
     .withPropertyType(core::StandardPropertyTypes::BOOLEAN_TYPE)
     .withDefaultValue("false")
     .build();
-  EXTENSIONAPI static constexpr auto Properties = utils::array_cat(AzureBlobStorageSingleBlobProcessorBase::Properties, std::array<core::PropertyReference, 1>{CreateContainer});
+  EXTENSIONAPI static constexpr auto Properties = utils::array_cat(AzureBlobStorageSingleBlobProcessorBase::Properties, std::to_array<core::PropertyReference>({CreateContainer}));
 
   EXTENSIONAPI static constexpr auto Success = core::RelationshipDefinition{"success", "All successfully processed FlowFiles are routed to this relationship"};
   EXTENSIONAPI static constexpr auto Failure = core::RelationshipDefinition{"failure", "Unsuccessful operations will be transferred to the failure relationship"};
