@@ -19,15 +19,14 @@
  */
 #include "ApplyTemplate.h"
 
-#include <filesystem>
-#include <fstream>
-#include <iostream>
+#include <unordered_map>
 #include <memory>
 #include <string>
 #include <utility>
 
 #include "core/Resource.h"
 #include "bustache/model.hpp"
+#include "bustache/render/string.hpp"
 
 namespace org::apache::nifi::minifi::processors {
 
@@ -36,17 +35,16 @@ void ApplyTemplate::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void ApplyTemplate::onTrigger(const std::shared_ptr<core::ProcessContext> &context,
-                              const std::shared_ptr<core::ProcessSession> &session) {
-  auto flow_file = session->get();
+void ApplyTemplate::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
+  auto flow_file = session.get();
   if (!flow_file) {
     return;
   }
 
   std::string template_file;
-  context->getProperty(Template, template_file, flow_file);
-  session->write(flow_file, [&template_file, &flow_file, this](const auto& output_stream) {
-    logger_->log_info("ApplyTemplate reading template file from %s", template_file);
+  context.getProperty(Template, template_file, flow_file.get());
+  session.write(flow_file, [&template_file, &flow_file, this](const auto& output_stream) {
+    logger_->log_info("ApplyTemplate reading template file from {}", template_file);
     // TODO(szaszm): we might want to return to memory-mapped input files when the next todo is done. Until then, the agents stores the whole result in memory anyway, so no point in not doing the same
     // with the template file itself
     const auto template_file_contents = [&] {
@@ -55,18 +53,18 @@ void ApplyTemplate::onTrigger(const std::shared_ptr<core::ProcessContext> &conte
     }();
 
     bustache::format format(template_file_contents);
-    bustache::object data;
+    std::unordered_map<std::string, std::string> data;
 
     for (const auto &attr : flow_file->getAttributes()) {
       data[attr.first] = attr.second;
     }
 
     // TODO(calebj) write ostream reciever for format() to prevent excessive copying
-    std::string ostring = to_string(format(data));
+    std::string ostring = bustache::to_string(format(data));
     output_stream->write(gsl::make_span(ostring).as_span<const std::byte>());
     return gsl::narrow<int64_t>(ostring.length());
   });
-  session->transfer(flow_file, Success);
+  session.transfer(flow_file, Success);
 }
 
 REGISTER_RESOURCE(ApplyTemplate, Processor);
