@@ -18,16 +18,15 @@
 #include "../PostElasticsearch.h"
 #include "../ElasticsearchCredentialsControllerService.h"
 #include "MockElastic.h"
-#include "SingleProcessorTestController.h"
-#include "Catch.h"
+#include "unit/SingleProcessorTestController.h"
+#include "unit/Catch.h"
 
 namespace org::apache::nifi::minifi::extensions::elasticsearch::test {
 
 TEST_CASE("PostElasticsearch", "[elastic]") {
   MockElastic mock_elastic("10433");
-
-  auto post_elasticsearch_json = std::make_shared<PostElasticsearch>("PostElasticsearch");
-  minifi::test::SingleProcessorTestController test_controller{post_elasticsearch_json};
+  minifi::test::SingleProcessorTestController test_controller{std::make_unique<PostElasticsearch>("PostElasticsearch")};
+  auto post_elasticsearch_json = test_controller.getProcessor();
   auto elasticsearch_credentials_controller_service = test_controller.plan->addController("ElasticsearchCredentialsControllerService", "elasticsearch_credentials_controller_service");
   CHECK(test_controller.plan->setProperty(post_elasticsearch_json,
                                      PostElasticsearch::ElasticCredentials,
