@@ -21,7 +21,7 @@
 
 namespace org::apache::nifi::minifi::core {
 
-bool ProcessContextExpr::getProperty(bool supports_expression_language, std::string_view property_name, std::string& value, const std::shared_ptr<FlowFile>& flow_file) {
+bool ProcessContextExpr::getProperty(bool supports_expression_language, std::string_view property_name, std::string& value, const FlowFile* const flow_file) {
   if (!supports_expression_language) {
     return ProcessContext::getProperty(property_name, value);
   }
@@ -31,26 +31,26 @@ bool ProcessContextExpr::getProperty(bool supports_expression_language, std::str
     if (!ProcessContext::getProperty(name, expression_str)) {
       return false;
     }
-    logger_->log_debug("Compiling expression for %s/%s: %s", getProcessorNode()->getName(), name, expression_str);
+    logger_->log_debug("Compiling expression for {}/{}: {}", getProcessorNode()->getName(), name, expression_str);
     expressions_.emplace(name, expression::compile(expression_str));
     expression_strs_.insert_or_assign(name, expression_str);
   }
 
   minifi::expression::Parameters p(shared_from_this(), flow_file);
   value = expressions_[name](p).asString();
-  logger_->log_debug(R"(expression "%s" of property "%s" evaluated to: %s)", expression_strs_[name], name, value);
+  logger_->log_debug(R"(expression "{}" of property "{}" evaluated to: {})", expression_strs_[name], name, value);
   return true;
 }
 
-bool ProcessContextExpr::getProperty(const Property& property, std::string& value, const std::shared_ptr<FlowFile>& flow_file) {
+bool ProcessContextExpr::getProperty(const Property& property, std::string& value, const FlowFile* const flow_file) {
   return getProperty(property.supportsExpressionLanguage(), property.getName(), value, flow_file);
 }
 
-bool ProcessContextExpr::getProperty(const PropertyReference& property, std::string& value, const std::shared_ptr<FlowFile>& flow_file) {
+bool ProcessContextExpr::getProperty(const PropertyReference& property, std::string& value, const FlowFile* const flow_file) {
   return getProperty(property.supports_expression_language, property.name, value, flow_file);
 }
 
-bool ProcessContextExpr::getDynamicProperty(const Property &property, std::string &value, const std::shared_ptr<FlowFile> &flow_file) {
+bool ProcessContextExpr::getDynamicProperty(const Property &property, std::string &value, const FlowFile* const flow_file) {
   if (!property.supportsExpressionLanguage()) {
     return ProcessContext::getDynamicProperty(property.getName(), value);
   }
@@ -58,13 +58,13 @@ bool ProcessContextExpr::getDynamicProperty(const Property &property, std::strin
   if (dynamic_property_expressions_.find(name) == dynamic_property_expressions_.end()) {
     std::string expression_str;
     ProcessContext::getDynamicProperty(name, expression_str);
-    logger_->log_debug("Compiling expression for %s/%s: %s", getProcessorNode()->getName(), name, expression_str);
+    logger_->log_debug("Compiling expression for {}/{}: {}", getProcessorNode()->getName(), name, expression_str);
     dynamic_property_expressions_.emplace(name, expression::compile(expression_str));
     expression_strs_.insert_or_assign(name, expression_str);
   }
   minifi::expression::Parameters p(shared_from_this(), flow_file);
   value = dynamic_property_expressions_[name](p).asString();
-  logger_->log_debug(R"(expression "%s" of dynamic property "%s" evaluated to: %s)", expression_strs_[name], name, value);
+  logger_->log_debug(R"(expression "{}" of dynamic property "{}" evaluated to: {})", expression_strs_[name], name, value);
   return true;
 }
 
