@@ -17,10 +17,10 @@
 
 #include "../PushGrafanaLokiREST.h"
 #include "MockGrafanaLokiREST.h"
-#include "SingleProcessorTestController.h"
-#include "Catch.h"
+#include "unit/SingleProcessorTestController.h"
+#include "unit/Catch.h"
 #include "utils/StringUtils.h"
-#include "utils/TestUtils.h"
+#include "unit/TestUtils.h"
 
 #ifdef WIN32
 #pragma push_macro("GetObject")
@@ -30,8 +30,9 @@
 namespace org::apache::nifi::minifi::extensions::grafana::loki::test {
 
 TEST_CASE("Url property is required", "[PushGrafanaLokiREST]") {
-  auto push_grafana_loki_rest = std::make_shared<PushGrafanaLokiREST>("PushGrafanaLokiREST");
-  minifi::test::SingleProcessorTestController test_controller(push_grafana_loki_rest);
+  minifi::test::SingleProcessorTestController test_controller(std::make_unique<PushGrafanaLokiREST>("PushGrafanaLokiREST"));
+  auto push_grafana_loki_rest = test_controller.getProcessor();
+
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::Url, "");
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::StreamLabels, "job=minifi,directory=/opt/minifi/logs/");
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::LogLineBatchSize, "1");
@@ -39,8 +40,8 @@ TEST_CASE("Url property is required", "[PushGrafanaLokiREST]") {
 }
 
 TEST_CASE("Valid stream labels need to be set", "[PushGrafanaLokiREST]") {
-  auto push_grafana_loki_rest = std::make_shared<PushGrafanaLokiREST>("PushGrafanaLokiREST");
-  minifi::test::SingleProcessorTestController test_controller(push_grafana_loki_rest);
+  minifi::test::SingleProcessorTestController test_controller(std::make_unique<PushGrafanaLokiREST>("PushGrafanaLokiREST"));
+  auto push_grafana_loki_rest = test_controller.getProcessor();
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::Url, "localhost:10990");
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::LogLineBatchSize, "1");
   SECTION("Stream labels cannot be empty") {
@@ -53,8 +54,8 @@ TEST_CASE("Valid stream labels need to be set", "[PushGrafanaLokiREST]") {
 }
 
 TEST_CASE("Log Line Batch Size cannot be 0", "[PushGrafanaLokiREST]") {
-  auto push_grafana_loki_rest = std::make_shared<PushGrafanaLokiREST>("PushGrafanaLokiREST");
-  minifi::test::SingleProcessorTestController test_controller(push_grafana_loki_rest);
+  minifi::test::SingleProcessorTestController test_controller(std::make_unique<PushGrafanaLokiREST>("PushGrafanaLokiREST"));
+  auto push_grafana_loki_rest = test_controller.getProcessor();
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::Url, "localhost:10990");
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::StreamLabels, "job=minifi,directory=/opt/minifi/logs/");
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::LogLineBatchSize, "0");
@@ -65,8 +66,8 @@ class PushGrafanaLokiRESTTestFixture {
  public:
   PushGrafanaLokiRESTTestFixture()
       : mock_loki_("10990"),
-        push_grafana_loki_rest_(std::make_shared<PushGrafanaLokiREST>("PushGrafanaLokiREST")),
-        test_controller_(push_grafana_loki_rest_) {
+        test_controller_(std::make_unique<PushGrafanaLokiREST>("PushGrafanaLokiREST")),
+        push_grafana_loki_rest_(test_controller_.getProcessor<PushGrafanaLokiREST>()) {
     LogTestController::getInstance().setDebug<TestPlan>();
     LogTestController::getInstance().setDebug<minifi::core::Processor>();
     LogTestController::getInstance().setTrace<minifi::core::ProcessSession>();
@@ -129,7 +130,7 @@ class PushGrafanaLokiRESTTestFixture {
     const auto& value_array = stream_array[0]["values"].GetArray();
     REQUIRE(value_array.Size() == expected_log_values.size());
     for (size_t i = 0; i < expected_log_values.size(); ++i) {
-      const auto& log_line_array = value_array[i].GetArray();
+      const auto& log_line_array = value_array[gsl::narrow<rapidjson::SizeType>(i)].GetArray();
       if (!expected_log_line_attribute_values.empty()) {
         REQUIRE(log_line_array.Size() == 3);
       } else {
@@ -159,8 +160,8 @@ class PushGrafanaLokiRESTTestFixture {
 
  protected:
   MockGrafanaLokiREST mock_loki_;
-  std::shared_ptr<PushGrafanaLokiREST> push_grafana_loki_rest_;
   minifi::test::SingleProcessorTestController test_controller_;
+  PushGrafanaLokiREST* push_grafana_loki_rest_;
 };
 
 TEST_CASE_METHOD(PushGrafanaLokiRESTTestFixture, "PushGrafanaLokiREST should send 1 log line to Grafana Loki in a trigger", "[PushGrafanaLokiREST]") {
@@ -272,8 +273,8 @@ TEST_CASE_METHOD(PushGrafanaLokiRESTTestFixture, "PushGrafanaLokiREST should wai
 }
 
 TEST_CASE("If username is set, password is also required to be set", "[PushGrafanaLokiREST]") {
-  auto push_grafana_loki_rest = std::make_shared<PushGrafanaLokiREST>("PushGrafanaLokiREST");
-  minifi::test::SingleProcessorTestController test_controller(push_grafana_loki_rest);
+  minifi::test::SingleProcessorTestController test_controller(std::make_unique<PushGrafanaLokiREST>("PushGrafanaLokiREST"));
+  auto push_grafana_loki_rest = test_controller.getProcessor();
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::Url, "localhost:10990");
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::StreamLabels, "job=minifi,directory=/opt/minifi/logs/");
   test_controller.plan->setProperty(push_grafana_loki_rest, PushGrafanaLokiREST::LogLineBatchSize, "1");
@@ -292,7 +293,7 @@ TEST_CASE_METHOD(PushGrafanaLokiRESTTestFixture, "Basic authentication is set in
 
 TEST_CASE_METHOD(PushGrafanaLokiRESTTestFixture, "Bearer token is set for authentication", "[PushGrafanaLokiREST]") {
   auto temp_dir = test_controller_.createTempDirectory();
-  auto test_file_path = minifi::utils::putFileToDir(temp_dir, "test1.txt", "mytoken\n");
+  auto test_file_path = minifi::test::utils::putFileToDir(temp_dir, "test1.txt", "mytoken\n");
   setProperty(PushGrafanaLokiREST::LogLineBatchSize, "1");
   setProperty(PushGrafanaLokiREST::BearerTokenFile, test_file_path.string());
   auto results = test_controller_.trigger({minifi::test::InputFlowFileData{"log line 1", {}}});
