@@ -28,15 +28,14 @@ namespace org::apache::nifi::minifi::extensions::lua {
 
 class LuaScriptProcessContext {
  public:
-  explicit LuaScriptProcessContext(std::shared_ptr<core::ProcessContext> context, sol::state& sol_state);
+  explicit LuaScriptProcessContext(core::ProcessContext& context, sol::state& sol_state);
 
   std::string getProperty(const std::string &name);
-  void releaseProcessContext();
 
   LuaScriptStateManager getStateManager();
 
  private:
-  std::shared_ptr<core::ProcessContext> context_;
+  core::ProcessContext& context_;
   sol::state& sol_state_;
 };
 
