@@ -20,9 +20,9 @@
 #include <memory>
 #include <string>
 
-#include "SingleProcessorTestController.h"
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/SingleProcessorTestController.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 
 #include "../../script/ExecuteScript.h"
 #include "utils/file/FileUtils.h"
@@ -30,6 +30,16 @@
 
 namespace org::apache::nifi::minifi::processors::test {
 
+TEST_CASE("Lua: hello world") {
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
+
+  execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
+  execute_script->setProperty(ExecuteScript::ScriptBody, R"(print("Hello world!"))");
+
+  CHECK_NOTHROW(controller.trigger());
+}
+
 TEST_CASE("Script engine is not set", "[executescriptMisconfiguration]") {
   TestController test_controller;
   auto plan = test_controller.createPlan();
@@ -71,9 +81,8 @@ end
 }
 
 TEST_CASE("Lua: Test session get should return None if there are no flowfiles in the incoming connections") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
@@ -94,9 +103,8 @@ end
 
 TEST_CASE("Lua: Test Log", "[executescriptLuaLog]") {
   LogTestController::getInstance().reset();
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
@@ -114,9 +122,8 @@ end
 }
 
 TEST_CASE("Lua: Test Read File", "[executescriptLuaRead]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
@@ -146,9 +153,8 @@ end
 }
 
 TEST_CASE("Lua: Test Write File", "[executescriptLuaWrite]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
@@ -180,9 +186,8 @@ TEST_CASE("Lua: Test Write File", "[executescriptLuaWrite]") {
 
 TEST_CASE("Lua: Test Create", "[executescriptLuaCreate]") {
   LogTestController::getInstance().reset();
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
@@ -206,9 +211,8 @@ end
 
 TEST_CASE("Lua: Test Update Attribute", "[executescriptLuaUpdateAttribute]") {
   LogTestController::getInstance().reset();
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
@@ -270,9 +274,8 @@ TEST_CASE("Lua: Test Require", "[executescriptLuaRequire]") {
 TEST_CASE("Lua: Test Module Directory property", "[executescriptLuaModuleDirectoryProperty]") {
   using org::apache::nifi::minifi::utils::file::get_executable_dir;
 
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   const auto script_files_directory =  minifi::utils::file::FileUtils::get_executable_dir() / "resources" / "test_lua_scripts";
@@ -289,9 +292,8 @@ TEST_CASE("Lua: Test Module Directory property", "[executescriptLuaModuleDirecto
 }
 
 TEST_CASE("Lua: Non existent script file should throw", "[executescriptLuaNonExistentScriptFile]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
@@ -301,9 +303,8 @@ TEST_CASE("Lua: Non existent script file should throw", "[executescriptLuaNonExi
 }
 
 TEST_CASE("Lua can remove flowfiles", "[ExecuteScript]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
   execute_script->setProperty(ExecuteScript::ScriptBody,
@@ -319,9 +320,8 @@ TEST_CASE("Lua can remove flowfiles", "[ExecuteScript]") {
 }
 
 TEST_CASE("Lua can store states in StateManager", "[ExecuteScript]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<minifi::processors::ExecuteScript>();
   execute_script->setProperty(ExecuteScript::ScriptEngine, "lua");
   execute_script->setProperty(ExecuteScript::ScriptBody,
