@@ -16,9 +16,9 @@
  * limitations under the License.
  */
 
-#include "Catch.h"
+#include "unit/Catch.h"
 #include "catch2/matchers/catch_matchers_string.hpp"
-#include "TestBase.h"
+#include "unit/TestBase.h"
 #include "../processors/ConsumeMQTT.h"
 
 namespace {
@@ -40,7 +40,7 @@ struct Fixture {
 
   TestController testController_;
   std::shared_ptr<TestPlan> plan_;
-  std::shared_ptr<core::Processor> consumeMqttProcessor_;
+  core::Processor* consumeMqttProcessor_ = nullptr;
 };
 }  // namespace
 
