@@ -18,9 +18,9 @@
 
 #include "range/v3/algorithm/find_if.hpp"
 
-#include "Catch.h"
+#include "unit/Catch.h"
 #include "catch2/matchers/catch_matchers_string.hpp"
-#include "TestBase.h"
+#include "unit/TestBase.h"
 #include "../processors/PublishMQTT.h"
 
 using namespace std::literals::chrono_literals;
@@ -44,7 +44,7 @@ struct Fixture {
 
   TestController testController_;
   std::shared_ptr<TestPlan> plan_;
-  std::shared_ptr<core::Processor> publishMqttProcessor_;
+  core::Processor* publishMqttProcessor_ = nullptr;
 };
 }  // namespace
 
