@@ -37,7 +37,7 @@ PerformanceDataMonitor::~PerformanceDataMonitor() {
   PdhCloseQuery(pdh_query_);
 }
 
-void PerformanceDataMonitor::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& sessionFactory) {
+void PerformanceDataMonitor::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
   setupMembersFromProperties(context);
 
   PdhOpenQueryA(nullptr, 0, &pdh_query_);
@@ -47,7 +47,7 @@ void PerformanceDataMonitor::onSchedule(const std::shared_ptr<core::ProcessConte
     if (pdh_counter != nullptr) {
       PDH_STATUS add_to_query_result = pdh_counter->addToQuery(pdh_query_);
       if (add_to_query_result != ERROR_SUCCESS) {
-        logger_->log_error("Error adding %s to query, error code: 0x%x", pdh_counter->getName(), add_to_query_result);
+        logger_->log_error("Error adding {} to query, error code: {:#x}", pdh_counter->getName(), add_to_query_result);
         it = resource_consumption_counters_.erase(it);
         continue;
       }
@@ -57,18 +57,18 @@ void PerformanceDataMonitor::onSchedule(const std::shared_ptr<core::ProcessConte
 
   PDH_STATUS collect_query_data_result = PdhCollectQueryData(pdh_query_);
   if (ERROR_SUCCESS != collect_query_data_result) {
-    logger_->log_error("Error during PdhCollectQueryData, error code: 0x%x", collect_query_data_result);
+    logger_->log_error("Error during PdhCollectQueryData, error code: {:#x}", collect_query_data_result);
   }
 }
 
-void PerformanceDataMonitor::onTrigger(core::ProcessContext* context, core::ProcessSession* session) {
+void PerformanceDataMonitor::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
   if (resource_consumption_counters_.empty()) {
     logger_->log_error("No valid counters for PerformanceDataMonitor");
     yield();
     return;
   }
 
-  std::shared_ptr<core::FlowFile> flowFile = session->create();
+  std::shared_ptr<core::FlowFile> flowFile = session.create();
   if (!flowFile) {
     logger_->log_error("Failed to create flowfile!");
     yield();
@@ -77,7 +77,7 @@ void PerformanceDataMonitor::onTrigger(core::ProcessContext* context, core::Proc
 
   PDH_STATUS collect_query_data_result = PdhCollectQueryData(pdh_query_);
   if (ERROR_SUCCESS != collect_query_data_result) {
-    logger_->log_error("Error during PdhCollectQueryData, error code: 0x%x", collect_query_data_result);
+    logger_->log_error("Error during PdhCollectQueryData, error code: {:#x}", collect_query_data_result);
     yield();
     return;
   }
@@ -91,12 +91,12 @@ void PerformanceDataMonitor::onTrigger(core::ProcessContext* context, core::Proc
   }
   if (pretty_output_) {
     utils::PrettyJsonOutputCallback callback(std::move(root), decimal_places_);
-    session->write(flowFile, std::ref(callback));
-    session->transfer(flowFile, Success);
+    session.write(flowFile, std::ref(callback));
+    session.transfer(flowFile, Success);
   } else {
     utils::JsonOutputCallback callback(std::move(root), decimal_places_);
-    session->write(flowFile, std::ref(callback));
-    session->transfer(flowFile, Success);
+    session.write(flowFile, std::ref(callback));
+    session.transfer(flowFile, Success);
   }
 }
 
@@ -210,7 +210,7 @@ void add_system_related_counters(std::vector<std::unique_ptr<PerformanceDataCoun
 }
 
 void PerformanceDataMonitor::addCountersFromPredefinedGroupsProperty(const std::string& predefined_groups) {
-  auto groups = utils::StringUtils::splitAndTrim(predefined_groups, ",");
+  auto groups = utils::string::splitAndTrim(predefined_groups, ",");
   for (const auto& group : groups) {
     if (group == "CPU") {
       add_cpu_related_counters(resource_consumption_counters_);
@@ -227,13 +227,13 @@ void PerformanceDataMonitor::addCountersFromPredefinedGroupsProperty(const std::
     } else if (group == "Process") {
       add_process_related_counters(resource_consumption_counters_);
     } else {
-      logger_->log_error((group + " is not a valid predefined group for PerformanceDataMonitor").c_str());
+      logger_->log_error("{} is not a valid predefined group for PerformanceDataMonitor", group);
     }
   }
 }
 
 void PerformanceDataMonitor::addCustomPDHCountersFromProperty(const std::string& custom_pdh_counters) {
-  const auto custom_counters = utils::StringUtils::splitAndTrim(custom_pdh_counters, ",");
+  const auto custom_counters = utils::string::splitAndTrim(custom_pdh_counters, ",");
   for (const auto& custom_counter : custom_counters) {
     auto counter = PDHCounter::createPDHCounter(custom_counter);
     if (counter != nullptr)
@@ -241,25 +241,25 @@ void PerformanceDataMonitor::addCustomPDHCountersFromProperty(const std::string&
   }
 }
 
-void PerformanceDataMonitor::setupCountersFromProperties(const std::shared_ptr<core::ProcessContext>& context) {
+void PerformanceDataMonitor::setupCountersFromProperties(core::ProcessContext& context) {
   std::string custom_pdh_counters;
-  if (context->getProperty(CustomPDHCounters, custom_pdh_counters)) {
-    logger_->log_trace("Custom PDH counters configured to be %s", custom_pdh_counters);
+  if (context.getProperty(CustomPDHCounters, custom_pdh_counters)) {
+    logger_->log_trace("Custom PDH counters configured to be {}", custom_pdh_counters);
     addCustomPDHCountersFromProperty(custom_pdh_counters);
   }
 }
 
-void PerformanceDataMonitor::setupPredefinedGroupsFromProperties(const std::shared_ptr<core::ProcessContext>& context) {
+void PerformanceDataMonitor::setupPredefinedGroupsFromProperties(core::ProcessContext& context) {
   std::string predefined_groups;
-  if (context->getProperty(PredefinedGroups, predefined_groups)) {
-    logger_->log_trace("Predefined group configured to be %s", predefined_groups);
+  if (context.getProperty(PredefinedGroups, predefined_groups)) {
+    logger_->log_trace("Predefined group configured to be {}", predefined_groups);
     addCountersFromPredefinedGroupsProperty(predefined_groups);
   }
 }
 
-void PerformanceDataMonitor::setupOutputFormatFromProperties(const std::shared_ptr<core::ProcessContext>& context) {
+void PerformanceDataMonitor::setupOutputFormatFromProperties(core::ProcessContext& context) {
   std::string output_format_string;
-  if (context->getProperty(OutputFormatProperty, output_format_string)) {
+  if (context.getProperty(OutputFormatProperty, output_format_string)) {
     if (output_format_string == OPEN_TELEMETRY_FORMAT_STR) {
       output_format_ = OutputFormat::OPENTELEMETRY;
     } else if (output_format_string == JSON_FORMAT_STR) {
@@ -270,7 +270,7 @@ void PerformanceDataMonitor::setupOutputFormatFromProperties(const std::shared_p
   }
 
   std::string output_compactness_string;
-  if (context->getProperty(OutputCompactness, output_compactness_string)) {
+  if (context.getProperty(OutputCompactness, output_compactness_string)) {
     if (output_compactness_string == PRETTY_FORMAT_STR) {
       pretty_output_ = true;
     } else if (output_compactness_string == COMPACT_FORMAT_STR) {
@@ -280,27 +280,27 @@ void PerformanceDataMonitor::setupOutputFormatFromProperties(const std::shared_p
     }
   }
 
-  logger_->log_trace("OutputFormat is configured to be %s %s", pretty_output_ ? "pretty" : "compact", output_format_ == OutputFormat::JSON ? "JSON" : "OpenTelemetry");
+  logger_->log_trace("OutputFormat is configured to be {} {}", pretty_output_ ? "pretty" : "compact", output_format_ == OutputFormat::JSON ? "JSON" : "OpenTelemetry");
 }
 
-void PerformanceDataMonitor::setupDecimalPlacesFromProperties(const std::shared_ptr<core::ProcessContext>& context) {
+void PerformanceDataMonitor::setupDecimalPlacesFromProperties(core::ProcessContext& context) {
   std::string decimal_places_str;
-  if (!context->getProperty(DecimalPlaces, decimal_places_str) || decimal_places_str == "") {
+  if (!context.getProperty(DecimalPlaces, decimal_places_str) || decimal_places_str == "") {
     decimal_places_ = std::nullopt;
     return;
   }
 
   int64_t decimal_places;
-  if (context->getProperty(DecimalPlaces, decimal_places)) {
+  if (context.getProperty(DecimalPlaces, decimal_places)) {
     if (decimal_places > std::numeric_limits<uint8_t>::max() || decimal_places < 1)
       throw Exception(PROCESS_SCHEDULE_EXCEPTION, "PerformanceDataMonitor Decimal Places is out of range");
     decimal_places_ = static_cast<uint8_t>(decimal_places);
   }
   if (decimal_places_.has_value())
-    logger_->log_trace("Rounding is enabled with %d decimal places", decimal_places_.value());
+    logger_->log_trace("Rounding is enabled with {} decimal places", decimal_places_.value());
 }
 
-void PerformanceDataMonitor::setupMembersFromProperties(const std::shared_ptr<core::ProcessContext>& context) {
+void PerformanceDataMonitor::setupMembersFromProperties(core::ProcessContext& context) {
   setupCountersFromProperties(context);
   setupPredefinedGroupsFromProperties(context);
   setupOutputFormatFromProperties(context);
