@@ -22,11 +22,11 @@
 #include <fstream>
 #include <functional>
 
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "processors/PutFile.h"
 #include "utils/file/FileUtils.h"
-#include "utils/TestUtils.h"
+#include "unit/TestUtils.h"
 #include "PerformanceDataMonitor.h"
 #include "rapidjson/filereadstream.h"
 
@@ -65,8 +65,8 @@ class PerformanceDataMonitorTester {
   TestController test_controller_;
   std::filesystem::path dir_;
   std::shared_ptr<TestPlan> plan_;
-  std::shared_ptr<core::Processor> performance_monitor_;
-  std::shared_ptr<core::Processor> putfile_;
+  core::Processor* performance_monitor_;
+  core::Processor* putfile_;
 };
 
 
