@@ -16,15 +16,15 @@
  * limitations under the License.
  */
 
-#include "SingleProcessorTestController.h"
-#include "Catch.h"
+#include "unit/SingleProcessorTestController.h"
+#include "unit/Catch.h"
 #include "processors/ProcFsMonitor.h"
 
 namespace org::apache::nifi::minifi::extensions::procfs::tests {
 
 TEST_CASE("ProcFsMonitorTests", "[procfsmonitortests]") {
-  std::shared_ptr<ProcFsMonitor> proc_fs_monitor = std::make_shared<ProcFsMonitor>("ProcFsMonitor");
-  org::apache::nifi::minifi::test::SingleProcessorTestController test_controller_{proc_fs_monitor};
+  org::apache::nifi::minifi::test::SingleProcessorTestController test_controller_{std::make_unique<ProcFsMonitor>("ProcFsMonitor")};
+  auto proc_fs_monitor = test_controller_.getProcessor();
 
   SECTION("Absolute JSON") {
     test_controller_.plan->setProperty(proc_fs_monitor, ProcFsMonitor::ResultRelativenessProperty, "Absolute");
