@@ -59,17 +59,16 @@ class PythonCreator : public minifi::core::CoreComponent {
   }
 
   void configure(const std::shared_ptr<Configure> &configuration) override {
-    PythonDependencyInstaller dependency_installer(configuration);
-    dependency_installer.installDependenciesFromRequirementsFiles();
-    auto engine = std::make_shared<python::PythonScriptEngine>();
     std::optional<std::string> pathListings = configuration ? configuration->get(minifi::Configuration::nifi_python_processor_dir) : std::nullopt;
     if (!pathListings) {
       return;
     }
     configure({pathListings.value()});
 
-    auto python_lib_path = getPythonLibPath(configuration);
+    PythonDependencyInstaller dependency_installer(configuration);
+    dependency_installer.installDependencies(classpaths_);
 
+    auto python_lib_path = getPythonLibPath(configuration);
     for (const auto &path : classpaths_) {
       const auto script_name = path.stem();
       const auto package = getPackage(pathListings.value(), path.string());
@@ -79,25 +78,29 @@ class PythonCreator : public minifi::core::CoreComponent {
         full_name = utils::string::join_pack("org.apache.nifi.minifi.processors.", package, ".", script_name.string());
         class_name = full_name;
       }
+
+      const std::string qualified_module_name_prefix = "org.apache.nifi.minifi.processors.";
+      std::string qualified_module_name = full_name.substr(qualified_module_name_prefix.length());
       if (path.string().find("nifi_python_processors") != std::string::npos) {
         auto utils_path = (std::filesystem::path("nifi_python_processors") / "utils").string();
         if (path.string().find(utils_path) != std::string::npos) {
           continue;
         }
-        dependency_installer.installInlinePythonDependencies(path);
         logger_->log_info("Registering NiFi python processor: {}", class_name);
         core::getClassLoader().registerClass(class_name, std::make_unique<PythonObjectFactory>(path.string(), script_name.string(),
-          PythonProcessorType::NIFI_TYPE, std::vector<std::filesystem::path>{python_lib_path, std::filesystem::path{pathListings.value()}, path.parent_path()}));
+          PythonProcessorType::NIFI_TYPE, std::vector<std::filesystem::path>{python_lib_path, std::filesystem::path{pathListings.value()}, path.parent_path()}, qualified_module_name));
       } else {
         logger_->log_info("Registering MiNiFi python processor: {}", class_name);
         core::getClassLoader().registerClass(class_name, std::make_unique<PythonObjectFactory>(path.string(), script_name.string(),
-          PythonProcessorType::MINIFI_TYPE, std::vector<std::filesystem::path>{python_lib_path, std::filesystem::path{pathListings.value()}}));
+          PythonProcessorType::MINIFI_TYPE, std::vector<std::filesystem::path>{python_lib_path, std::filesystem::path{pathListings.value()}}, qualified_module_name));
       }
       registered_classes_.push_back(class_name);
       try {
         registerScriptDescription(class_name, full_name, path, script_name.string());
+      } catch (const PythonScriptWarning &warning) {
+        logger_->log_info("Could not process {}.py: {} -- if this is a helper file, then this is OK", script_name, warning.what());
       } catch (const std::exception &err) {
-        logger_->log_error("Cannot load {}: {}", script_name, err.what());
+        logger_->log_error("Could not process {}.py: {}", script_name, err.what());
       }
     }
   }
@@ -112,7 +115,7 @@ class PythonCreator : public minifi::core::CoreComponent {
     processor->initialize();
     minifi::BundleDetails details;
     details.artifact = path.filename().string();
-    details.version = minifi::AgentBuild::VERSION;
+    details.version = processor->getVersion() && !processor->getVersion()->empty() ? *processor->getVersion() : minifi::AgentBuild::VERSION;
     details.group = "python";
 
     minifi::ClassDescription description{
@@ -121,7 +124,7 @@ class PythonCreator : public minifi::core::CoreComponent {
       .full_name_ = full_name,
       .description_ = processor->getDescription(),
       .class_properties_ = processor->getPythonProperties(),
-      .class_relationships_ = processor->getSupportedRelationships(),
+      .class_relationships_ = processor->getPythonRelationships(),
       .supports_dynamic_properties_ = processor->getPythonSupportDynamicProperties(),
       .inputRequirement_ = toString(processor->getInputRequirement()),
       .isSingleThreaded_ = processor->isSingleThreaded()};
