@@ -33,17 +33,19 @@ enum class PythonProcessorType {
   NIFI_TYPE
 };
 
-class PythonObjectFactory : public org::apache::nifi::minifi::core::DefautObjectFactory<org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor> {
+class PythonObjectFactory : public org::apache::nifi::minifi::core::DefaultObjectFactory<org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor> {
  public:
-  explicit PythonObjectFactory(std::string file, std::string class_name, PythonProcessorType python_processor_type, const std::vector<std::filesystem::path>& python_paths)
+  explicit PythonObjectFactory(std::string file, std::string class_name, PythonProcessorType python_processor_type,
+    const std::vector<std::filesystem::path>& python_paths, std::string qualified_module_name)
       : file_(std::move(file)),
         class_name_(std::move(class_name)),
         python_paths_(python_paths),
-        python_processor_type_(python_processor_type) {
+        python_processor_type_(python_processor_type),
+        qualified_module_name_(std::move(qualified_module_name)) {
   }
 
   std::unique_ptr<org::apache::nifi::minifi::core::CoreComponent> create(const std::string &name) override {
-    auto obj = DefautObjectFactory::create(name);
+    auto obj = DefaultObjectFactory::create(name);
     auto ptr = org::apache::nifi::minifi::utils::dynamic_unique_cast<org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor>(std::move(obj));
     if (ptr == nullptr) {
       return nullptr;
@@ -52,13 +54,14 @@ class PythonObjectFactory : public org::apache::nifi::minifi::core::DefautObject
       ptr->setPythonClassName(class_name_);
       ptr->setPythonPaths(python_paths_);
     }
+    ptr->setQualifiedModuleName(qualified_module_name_);
     ptr->initialize();
     ptr->setProperty(org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor::ScriptFile, file_);
     return ptr;
   }
 
   std::unique_ptr<org::apache::nifi::minifi::core::CoreComponent> create(const std::string &name, const org::apache::nifi::minifi::utils::Identifier &uuid) override {
-    auto obj = DefautObjectFactory::create(name, uuid);
+    auto obj = DefaultObjectFactory::create(name, uuid);
     auto ptr = org::apache::nifi::minifi::utils::dynamic_unique_cast<org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor>(std::move(obj));
     if (ptr == nullptr) {
       return nullptr;
@@ -67,24 +70,31 @@ class PythonObjectFactory : public org::apache::nifi::minifi::core::DefautObject
       ptr->setPythonClassName(class_name_);
       ptr->setPythonPaths(python_paths_);
     }
+    ptr->setQualifiedModuleName(qualified_module_name_);
     ptr->initialize();
     ptr->setProperty(org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor::ScriptFile, file_);
     return ptr;
   }
 
   org::apache::nifi::minifi::core::CoreComponent* createRaw(const std::string &name) override {
-    auto ptr = dynamic_cast<org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor*>(DefautObjectFactory::createRaw(name));
+    auto ptr = dynamic_cast<org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor*>(DefaultObjectFactory::createRaw(name));
+    if (python_processor_type_ == PythonProcessorType::NIFI_TYPE) {
+      ptr->setPythonClassName(class_name_);
+      ptr->setPythonPaths(python_paths_);
+    }
+    ptr->setQualifiedModuleName(qualified_module_name_);
     ptr->initialize();
     ptr->setProperty(org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor::ScriptFile, file_);
     return dynamic_cast<org::apache::nifi::minifi::core::CoreComponent*>(ptr);
   }
 
   org::apache::nifi::minifi::core::CoreComponent* createRaw(const std::string &name, const org::apache::nifi::minifi::utils::Identifier &uuid) override {
-    auto ptr = dynamic_cast<org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor*>(DefautObjectFactory::createRaw(name, uuid));
+    auto ptr = dynamic_cast<org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor*>(DefaultObjectFactory::createRaw(name, uuid));
     if (python_processor_type_ == PythonProcessorType::NIFI_TYPE) {
       ptr->setPythonClassName(class_name_);
       ptr->setPythonPaths(python_paths_);
     }
+    ptr->setQualifiedModuleName(qualified_module_name_);
     ptr->initialize();
     ptr->setProperty(org::apache::nifi::minifi::extensions::python::processors::ExecutePythonProcessor::ScriptFile, file_);
     return dynamic_cast<org::apache::nifi::minifi::core::CoreComponent*>(ptr);
@@ -95,4 +105,5 @@ class PythonObjectFactory : public org::apache::nifi::minifi::core::DefautObject
   std::string class_name_;
   std::vector<std::filesystem::path> python_paths_;
   PythonProcessorType python_processor_type_;
+  std::string qualified_module_name_;
 };
