@@ -90,20 +90,20 @@ void PythonScriptEngine::describe(core::Processor* proc) {
   }
 }
 
-void PythonScriptEngine::onSchedule(const std::shared_ptr<core::ProcessContext> &context) {
+void PythonScriptEngine::onSchedule(core::ProcessContext& context) {
   if (processor_instance_.get() != nullptr) {
-    callProcessorObjectMethod("onSchedule", std::weak_ptr(context));
+    callProcessorObjectMethod("onSchedule", &context);
   } else {
-    call("onSchedule", std::weak_ptr(context));
+    call("onSchedule", &context);
   }
 }
 
-void PythonScriptEngine::onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) {
+void PythonScriptEngine::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
   auto py_session = std::make_shared<python::PyProcessSession>(session);
   if (processor_instance_.get() != nullptr) {
-    callProcessorObjectMethod("onTrigger", std::weak_ptr(context), std::weak_ptr(py_session));
+    callProcessorObjectMethod("onTrigger", &context, std::weak_ptr(py_session));
   } else {
-    call("onTrigger", std::weak_ptr(context), std::weak_ptr(py_session));
+    call("onTrigger", &context, std::weak_ptr(py_session));
   }
 }
 
@@ -135,9 +135,9 @@ void PythonScriptEngine::evaluateModuleImports() {
 
   for (const auto& module_path : module_paths_) {
     if (std::filesystem::is_regular_file(module_path)) {
-      evalInternal("sys.path.append(r'" + module_path.parent_path().string() + "')");
+      evalInternal("sys.path.insert(0, r'" + module_path.parent_path().string() + "')");
     } else {
-      evalInternal("sys.path.append(r'" + module_path.string() + "')");
+      evalInternal("sys.path.insert(0, r'" + module_path.string() + "')");
     }
   }
 }
@@ -200,7 +200,66 @@ void PythonScriptEngine::initializeProcessorObject(const std::string& python_cla
       throw PythonScriptException("Could not bind 'REL_ORIGINAL' object to '" + python_class_name + "' python processor object");
     }
   } else {
-    throw PythonScriptException("No python class '" + python_class_name + "' was found!");
+    throw PythonScriptWarning("No Python class '" + python_class_name + "' was found");
+  }
+}
+
+std::vector<core::Relationship> PythonScriptEngine::getCustomPythonRelationships() {
+  GlobalInterpreterLock gil;
+  std::vector<core::Relationship> relationships;
+  if (processor_instance_.get() != nullptr) {
+    auto python_list_of_relationships = OwnedList(callProcessorObjectMethod("getRelationships"));
+    if (python_list_of_relationships.get() == Py_None) {
+      return relationships;
+    }
+    try {
+      for (size_t i = 0; i < python_list_of_relationships.length(); ++i) {
+        if (PyObject_HasAttrString(python_list_of_relationships[i].get(), "name") == 0) {
+          logger_->log_error("Error in python processor getRelationships method: Custom relationship object has no name attribute!");
+          continue;
+        }
+        auto name = OwnedStr(PyObject_GetAttrString(python_list_of_relationships[i].get(), "name"));
+        if (name.get() == nullptr) {
+          logger_->log_error("Error in python processor getRelationships method: Custom relationship object's name attribute could not be read!");
+          continue;
+        }
+
+        if (PyObject_HasAttrString(python_list_of_relationships[i].get(), "description") == 0) {
+          logger_->log_error("Error in python processor getRelationships method: Custom relationship object has no description attribute!");
+          continue;
+        }
+        auto description = OwnedStr(PyObject_GetAttrString(python_list_of_relationships[i].get(), "description"));
+        if (description.get() == nullptr) {
+          logger_->log_error("Error in python processor getRelationships method: Custom relationship object's description attribute could not be read!");
+          continue;
+        }
+
+        relationships.push_back(core::Relationship(name.toUtf8String(), description.toUtf8String()));
+      }
+    } catch (const std::exception& e) {
+      throw PythonScriptException(e.what());
+    }
+  }
+  return relationships;
+}
+
+void PythonScriptEngine::setModuleAttributes(const std::string& qualified_module_name) {
+  GlobalInterpreterLock gil;
+  size_t last_dot = qualified_module_name.find_last_of('.');
+
+  std::string qualified_package_name;
+  if (last_dot != std::string::npos) {
+    qualified_package_name = qualified_module_name.substr(0, last_dot);
+  }
+
+  if (!qualified_package_name.empty()) {
+    auto package_name_object = OwnedObject(PyUnicode_FromStringAndSize(qualified_package_name.data(), gsl::narrow<Py_ssize_t>(qualified_package_name.length())));
+    PyDict_SetItemString(bindings_.get(), "__package__", package_name_object.get());
+  }
+
+  if (!qualified_module_name.empty()) {
+    auto module_name_object = OwnedObject(PyUnicode_FromStringAndSize(qualified_module_name.data(), gsl::narrow<Py_ssize_t>(qualified_module_name.length())));
+    PyDict_SetItemString(bindings_.get(), "__name__", module_name_object.get());
   }
 }
 
