@@ -19,9 +19,9 @@
 #include <memory>
 #include <string>
 
-#include "SingleProcessorTestController.h"
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/SingleProcessorTestController.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 
 #include "../../script/ExecuteScript.h"
 #include "utils/file/FileUtils.h"
@@ -29,6 +29,16 @@
 
 namespace org::apache::nifi::minifi::processors::test {
 
+TEST_CASE("Python: hello world") {
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
+
+  execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
+  execute_script->setProperty(ExecuteScript::ScriptBody, R"(print("Hello world!"))");
+
+  CHECK_NOTHROW(controller.trigger());
+}
+
 TEST_CASE("Script engine is not set", "[executescriptMisconfiguration]") {
   TestController test_controller;
   auto plan = test_controller.createPlan();
@@ -69,9 +79,8 @@ TEST_CASE("Test both script body and script file set", "[executescriptMisconfigu
 }
 
 TEST_CASE("Python: Test session get should return None if there are no flowfiles in the incoming connections") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
@@ -88,9 +97,8 @@ def onTrigger(context, session):
 }
 
 TEST_CASE("Python: Test Read File", "[executescriptPythonRead]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
@@ -118,9 +126,8 @@ def onTrigger(context, session):
 }
 
 TEST_CASE("Python: Test Write File", "[executescriptPythonWrite]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
@@ -145,9 +152,8 @@ def onTrigger(context, session):
 }
 
 TEST_CASE("Python: Test Create", "[executescriptPythonCreate]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
@@ -168,9 +174,8 @@ def onTrigger(context, session):
 }
 
 TEST_CASE("Python: Test Update Attribute", "[executescriptPythonUpdateAttribute]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
@@ -194,9 +199,8 @@ def onTrigger(context, session):
 }
 
 TEST_CASE("Python: Test Get Context Property", "[executescriptPythonGetContextProperty]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
@@ -216,9 +220,8 @@ def onTrigger(context, session):
 TEST_CASE("Python: Test Module Directory property", "[executescriptPythonModuleDirectoryProperty]") {
   using org::apache::nifi::minifi::utils::file::get_executable_dir;
 
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   const auto script_files_directory =  minifi::utils::file::FileUtils::get_executable_dir() / "resources" / "test_python_scripts";
@@ -235,9 +238,8 @@ TEST_CASE("Python: Test Module Directory property", "[executescriptPythonModuleD
 }
 
 TEST_CASE("Python: Non existent script file should throw", "[executescriptPythonNonExistentScriptFile]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
 
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
@@ -247,9 +249,8 @@ TEST_CASE("Python: Non existent script file should throw", "[executescriptPython
 }
 
 TEST_CASE("Python can remove flowfiles", "[ExecuteScript]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<ExecuteScript>();
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
   execute_script->setProperty(ExecuteScript::ScriptBody, R"(
@@ -262,9 +263,8 @@ def onTrigger(context, session):
 }
 
 TEST_CASE("Python can store states in StateManager", "[ExecuteScript]") {
-  const auto execute_script = std::make_shared<ExecuteScript>("ExecuteScript");
-
-  minifi::test::SingleProcessorTestController controller{execute_script};
+  minifi::test::SingleProcessorTestController controller{std::make_unique<ExecuteScript>("ExecuteScript")};
+  const auto execute_script = controller.getProcessor();
   LogTestController::getInstance().setTrace<minifi::processors::ExecuteScript>();
   execute_script->setProperty(ExecuteScript::ScriptEngine, "python");
   execute_script->setProperty(ExecuteScript::ScriptBody,
