@@ -18,7 +18,6 @@
 
 #include "PyProcessSession.h"
 #include <utility>
-#include "PyException.h"
 #include "PyScriptFlowFile.h"
 #include "PyRelationship.h"
 #include "types/PyOutputStream.h"
@@ -30,16 +29,12 @@ namespace org::apache::nifi::minifi::extensions::python {
 
 namespace core = org::apache::nifi::minifi::core;
 
-PyProcessSession::PyProcessSession(std::shared_ptr<core::ProcessSession> session)
-    : session_(std::move(session)) {
+PyProcessSession::PyProcessSession(core::ProcessSession& session)
+    : session_(session) {
 }
 
 std::shared_ptr<core::FlowFile> PyProcessSession::get() {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-
-  auto flow_file = session_->get();
+  auto flow_file = session_.get();
 
   if (flow_file == nullptr) {
     return nullptr;
@@ -52,110 +47,81 @@ std::shared_ptr<core::FlowFile> PyProcessSession::get() {
 
 void PyProcessSession::transfer(const std::shared_ptr<core::FlowFile>& flow_file,
                                 const core::Relationship& relationship) {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-
   if (!flow_file) {
     throw std::runtime_error("Access of FlowFile after it has been released");
   }
 
-  session_->transfer(flow_file, relationship);
+  session_.transfer(flow_file, relationship);
 }
 
 void PyProcessSession::transferToCustomRelationship(const std::shared_ptr<core::FlowFile>& flow_file, const std::string& relationship_name) {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-
   if (!flow_file) {
     throw std::runtime_error("Access of FlowFile after it has been released");
   }
 
-  session_->transferToCustomRelationship(flow_file, relationship_name);
+  session_.transferToCustomRelationship(flow_file, relationship_name);
 }
 
 void PyProcessSession::read(const std::shared_ptr<core::FlowFile>& flow_file, BorrowedObject input_stream_callback) {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-
   if (!flow_file) {
     throw std::runtime_error("Access of FlowFile after it has been released");
   }
 
-  session_->read(flow_file, [&input_stream_callback](const std::shared_ptr<io::InputStream>& input_stream) -> int64_t {
+  session_.read(flow_file, [&input_stream_callback](const std::shared_ptr<io::InputStream>& input_stream) -> int64_t {
     return Long(Callable(input_stream_callback.getAttribute("process"))(std::weak_ptr(input_stream))).asInt64();
   });
 }
 
 void PyProcessSession::write(const std::shared_ptr<core::FlowFile>& flow_file, BorrowedObject output_stream_callback) {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-
   if (!flow_file) {
     throw std::runtime_error("Access of FlowFile after it has been released");
   }
 
-  session_->write(flow_file, [&output_stream_callback](const std::shared_ptr<io::OutputStream>& output_stream) -> int64_t {
+  session_.write(flow_file, [&output_stream_callback](const std::shared_ptr<io::OutputStream>& output_stream) -> int64_t {
     return Long(Callable(output_stream_callback.getAttribute("process"))(std::weak_ptr(output_stream))).asInt64();
   });
 }
 
 std::shared_ptr<core::FlowFile> PyProcessSession::create(const std::shared_ptr<core::FlowFile>& flow_file) {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-
-  auto result = session_->create(flow_file.get());
+  auto result = session_.create(flow_file.get());
 
   flow_files_.push_back(result);
   return result;
 }
 
 std::shared_ptr<core::FlowFile> PyProcessSession::clone(const std::shared_ptr<core::FlowFile>& flow_file) {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-
   if (!flow_file) {
     throw std::runtime_error("Flow file to clone is nullptr");
   }
 
-  auto result = session_->clone(*flow_file);
+  auto result = session_.clone(*flow_file);
 
   flow_files_.push_back(result);
   return result;
 }
 
 void PyProcessSession::remove(const std::shared_ptr<core::FlowFile>& flow_file) {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-  std::shared_ptr<core::FlowFile> result;
-
-  session_->remove(flow_file);
+  session_.remove(flow_file);
   flow_files_.erase(ranges::remove_if(flow_files_, [&flow_file](const auto& ff)-> bool { return ff == flow_file; }), flow_files_.end());
 }
 
 std::string PyProcessSession::getContentsAsString(const std::shared_ptr<core::FlowFile>& flow_file) {
-  if (!session_) {
-    throw std::runtime_error("Access of ProcessSession after it has been released");
-  }
-
   if (!flow_file) {
     throw std::runtime_error("Access of FlowFile after it has been released");
   }
 
   std::string content;
-  session_->read(flow_file, [&content](const std::shared_ptr<io::InputStream>& input_stream) -> int64_t {
+  session_.read(flow_file, [&content](const std::shared_ptr<io::InputStream>& input_stream) -> int64_t {
     content.resize(input_stream->size());
     return gsl::narrow<int64_t>(input_stream->read(as_writable_bytes(std::span(content))));
   });
   return content;
 }
 
+void PyProcessSession::putAttribute(const std::shared_ptr<core::FlowFile>& flow_file, std::string_view key, const std::string& value) {
+  session_.putAttribute(*flow_file, key, value);
+}
+
 extern "C" {
 
 static PyMethodDef PyProcessSessionObject_methods[] = {  // NOLINT(cppcoreguidelines-avoid-c-arrays)
@@ -168,6 +134,7 @@ static PyMethodDef PyProcessSessionObject_methods[] = {  // NOLINT(cppcoreguidel
     {"transferToCustomRelationship", (PyCFunction) PyProcessSessionObject::transferToCustomRelationship, METH_VARARGS, nullptr},
     {"remove", (PyCFunction) PyProcessSessionObject::remove, METH_VARARGS, nullptr},
     {"getContentsAsBytes", (PyCFunction) PyProcessSessionObject::getContentsAsBytes, METH_VARARGS, nullptr},
+    {"putAttribute", (PyCFunction) PyProcessSessionObject::putAttribute, METH_VARARGS, nullptr},
     {}  /* Sentinel */
 };
 
@@ -195,7 +162,7 @@ int PyProcessSessionObject::init(PyProcessSessionObject* self, PyObject* args, P
 
   auto process_session = PyCapsule_GetPointer(weak_ptr_capsule, HeldTypeName);
   if (!process_session)
-    throw PyException();
+    return -1;
   self->process_session_ = *static_cast<std::weak_ptr<PyProcessSession>*>(process_session);
   return 0;
 }
@@ -211,14 +178,24 @@ PyObject* PyProcessSessionObject::get(PyProcessSessionObject* self, PyObject*) {
   return object::returnReference(nullptr);
 }
 
-PyObject* PyProcessSessionObject::create(PyProcessSessionObject* self, PyObject*) {
+PyObject* PyProcessSessionObject::create(PyProcessSessionObject* self, PyObject* args) {
   auto session = self->process_session_.lock();
   if (!session) {
     PyErr_SetString(PyExc_AttributeError, "tried reading process session outside 'on_trigger'");
     return nullptr;
   }
 
-  if (auto flow_file = session->create(nullptr))
+  std::shared_ptr<core::FlowFile> parent_flow_file;
+  auto arg_size = PyTuple_Size(args);
+  if (arg_size > 0) {
+    PyObject* script_flow_file = nullptr;
+    if (!PyArg_ParseTuple(args, "O!", PyScriptFlowFile::typeObject(), &script_flow_file)) {
+      return nullptr;
+    }
+    parent_flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
+  }
+
+  if (auto flow_file = session->create(parent_flow_file))
     return object::returnReference(std::weak_ptr(flow_file));
   return object::returnReference(nullptr);
 }
@@ -231,7 +208,7 @@ PyObject* PyProcessSessionObject::clone(PyProcessSessionObject* self, PyObject*
   }
   PyObject* script_flow_file = nullptr;
   if (!PyArg_ParseTuple(args, "O!", PyScriptFlowFile::typeObject(), &script_flow_file)) {
-    throw PyException();
+    return nullptr;
   }
   const auto flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
 
@@ -248,7 +225,7 @@ PyObject* PyProcessSessionObject::remove(PyProcessSessionObject* self, PyObject*
   }
   PyObject* script_flow_file = nullptr;
   if (!PyArg_ParseTuple(args, "O!", PyScriptFlowFile::typeObject(), &script_flow_file)) {
-    throw PyException();
+    return nullptr;
   }
   const auto flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
   session->remove(flow_file);
@@ -259,19 +236,19 @@ PyObject* PyProcessSessionObject::read(PyProcessSessionObject* self, PyObject* a
   auto session = self->process_session_.lock();
   if (!session) {
     PyErr_SetString(PyExc_AttributeError, "tried reading process session outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
 
   PyObject* script_flow_file = nullptr;
   PyObject* callback = nullptr;
   if (!PyArg_ParseTuple(args, "O!O", PyScriptFlowFile::typeObject(), &script_flow_file, &callback)) {
-    throw PyException();
+    return nullptr;
   }
 
   const auto flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
   if (!flow_file) {
     PyErr_SetString(PyExc_AttributeError, "tried reading FlowFile outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
   session->read(flow_file, BorrowedObject(callback));
   Py_RETURN_NONE;
@@ -281,19 +258,19 @@ PyObject* PyProcessSessionObject::write(PyProcessSessionObject* self, PyObject*
   auto session = self->process_session_.lock();
   if (!session) {
     PyErr_SetString(PyExc_AttributeError, "tried reading process session outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
 
   PyObject* script_flow_file = nullptr;
   PyObject* callback = nullptr;
   if (!PyArg_ParseTuple(args, "O!O", PyScriptFlowFile::typeObject(), &script_flow_file, &callback)) {
-    throw PyException();
+    return nullptr;
   }
 
   const auto flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
   if (!flow_file) {
     PyErr_SetString(PyExc_AttributeError, "tried reading FlowFile outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
   session->write(flow_file, BorrowedObject(callback));
   Py_RETURN_NONE;
@@ -303,19 +280,19 @@ PyObject* PyProcessSessionObject::transfer(PyProcessSessionObject* self, PyObjec
   auto session = self->process_session_.lock();
   if (!session) {
     PyErr_SetString(PyExc_AttributeError, "tried reading process session outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
 
   PyObject* script_flow_file = nullptr;
   PyObject* relationship = nullptr;
   if (!PyArg_ParseTuple(args, "O!O!", PyScriptFlowFile::typeObject(), &script_flow_file, PyRelationship::typeObject(), &relationship)) {
-    throw PyException();
+    return nullptr;
   }
 
   const auto flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
   if (!flow_file) {
     PyErr_SetString(PyExc_AttributeError, "tried reading FlowFile outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
   session->transfer(flow_file, reinterpret_cast<PyRelationship*>(relationship)->relationship_);
   Py_RETURN_NONE;
@@ -325,13 +302,13 @@ PyObject* PyProcessSessionObject::transferToCustomRelationship(PyProcessSessionO
   auto session = self->process_session_.lock();
   if (!session) {
     PyErr_SetString(PyExc_AttributeError, "tried reading process session outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
 
   PyObject* script_flow_file = nullptr;
   const char* relationship_name = nullptr;
   if (!PyArg_ParseTuple(args, "O!s", PyScriptFlowFile::typeObject(), &script_flow_file, &relationship_name)) {
-    throw PyException();
+    return nullptr;
   }
 
   if (!relationship_name) {
@@ -348,7 +325,7 @@ PyObject* PyProcessSessionObject::transferToCustomRelationship(PyProcessSessionO
   const auto flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
   if (!flow_file) {
     PyErr_SetString(PyExc_AttributeError, "tried reading FlowFile outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
 
   BorrowedStr name = BorrowedStr::fromTuple(args, 0);
@@ -364,7 +341,7 @@ PyObject* PyProcessSessionObject::getContentsAsBytes(PyProcessSessionObject* sel
   }
   PyObject* script_flow_file = nullptr;
   if (!PyArg_ParseTuple(args, "O!", PyScriptFlowFile::typeObject(), &script_flow_file)) {
-    throw PyException();
+    return nullptr;
   }
   const auto flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
   auto content = session->getContentsAsString(flow_file);
@@ -372,6 +349,47 @@ PyObject* PyProcessSessionObject::getContentsAsBytes(PyProcessSessionObject* sel
   return PyBytes_FromStringAndSize(content.c_str(), gsl::narrow<Py_ssize_t>(content.size()));
 }
 
+PyObject* PyProcessSessionObject::putAttribute(PyProcessSessionObject* self, PyObject* args) {
+  auto session = self->process_session_.lock();
+  if (!session) {
+    PyErr_SetString(PyExc_AttributeError, "tried reading process session outside 'on_trigger'");
+    return nullptr;
+  }
+  PyObject* script_flow_file = nullptr;
+  const char* attribute_key = nullptr;
+  const char* attribute_value = nullptr;
+  if (!PyArg_ParseTuple(args, "O!ss", PyScriptFlowFile::typeObject(), &script_flow_file, &attribute_key, &attribute_value)) {
+    return nullptr;
+  }
+
+  const auto flow_file = reinterpret_cast<PyScriptFlowFile*>(script_flow_file)->script_flow_file_.lock();
+  if (!flow_file) {
+    PyErr_SetString(PyExc_AttributeError, "tried reading FlowFile outside 'on_trigger'");
+    return nullptr;
+  }
+
+  if (!attribute_key) {
+    PyErr_SetString(PyExc_AttributeError, "Attribute key is invalid!");
+    return nullptr;
+  }
+
+  std::string attribute_key_str(attribute_key);
+  if (attribute_key_str.empty()) {
+    PyErr_SetString(PyExc_AttributeError, "Attribute key is empty!");
+    return nullptr;
+  }
+
+  if (!attribute_value) {
+    PyErr_SetString(PyExc_AttributeError, "Attribute value is invalid!");
+    return nullptr;
+  }
+
+  std::string attribute_value_str(attribute_value);
+
+  session->putAttribute(flow_file, attribute_key_str, attribute_value_str);
+  Py_RETURN_NONE;
+}
+
 PyTypeObject* PyProcessSessionObject::typeObject() {
   static OwnedObject PyProcessSessionObjectType{PyType_FromSpec(&PyProcessSessionObjectTypeSpec)};
   return reinterpret_cast<PyTypeObject*>(PyProcessSessionObjectType.get());
