@@ -18,15 +18,33 @@
 #include "PyProcessor.h"
 #include <string>
 #include <optional>
-#include "PyException.h"
 #include "Types.h"
 
-extern "C" {
 namespace org::apache::nifi::minifi::extensions::python {
+namespace {
+bool getBoolFromTuple(PyObject* tuple, Py_ssize_t location) {
+  auto object = PyTuple_GetItem(tuple, location);
+
+  if (!object) {
+    throw PyException();
+  }
+
+  if (object == Py_True)
+    return true;
+  if (object == Py_False)
+    return false;
+
+  PyErr_SetString(PyExc_AttributeError, "Expected to get boolean parameter, but got something else");
+  throw PyException();
+}
+}  // namespace
+
+extern "C" {
 
 static PyMethodDef PyProcessor_methods[] = {  // NOLINT(cppcoreguidelines-avoid-c-arrays)
     {"setSupportsDynamicProperties", (PyCFunction) PyProcessor::setSupportsDynamicProperties, METH_VARARGS, nullptr},
     {"setDescription", (PyCFunction) PyProcessor::setDescription, METH_VARARGS, nullptr},
+    {"setVersion", (PyCFunction) PyProcessor::setVersion, METH_VARARGS, nullptr},
     {"addProperty", (PyCFunction) PyProcessor::addProperty, METH_VARARGS, nullptr},
     {}  /* Sentinel */
 };
@@ -55,7 +73,7 @@ int PyProcessor::init(PyProcessor* self, PyObject* args, PyObject*) {
 
   auto processor = PyCapsule_GetPointer(weak_ptr_capsule, HeldTypeName);
   if (!processor)
-    throw PyException();
+    return -1;
   self->processor_ = *static_cast<HeldType*>(processor);
   return 0;
 }
@@ -64,7 +82,7 @@ PyObject* PyProcessor::setSupportsDynamicProperties(PyProcessor* self, PyObject*
   auto processor = self->processor_.lock();
   if (!processor) {
     PyErr_SetString(PyExc_AttributeError, "tried reading processor outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
 
   processor->setSupportsDynamicProperties();
@@ -75,38 +93,44 @@ PyObject* PyProcessor::setDescription(PyProcessor* self, PyObject* args) {
   auto processor = self->processor_.lock();
   if (!processor) {
     PyErr_SetString(PyExc_AttributeError, "tried reading processor outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
   }
 
   const char* description = nullptr;
   if (!PyArg_ParseTuple(args, "s", &description)) {
-    throw PyException();
+    return nullptr;
   }
   processor->setDescription(std::string(description));
   Py_RETURN_NONE;
 }
 
-namespace {
-bool getBoolFromTuple(PyObject* tuple, Py_ssize_t location) {
-  auto object = PyTuple_GetItem(tuple, location);
+PyObject* PyProcessor::setVersion(PyProcessor* self, PyObject* args) {
+  auto processor = self->processor_.lock();
+  if (!processor) {
+    PyErr_SetString(PyExc_AttributeError, "tried reading processor outside 'on_trigger'");
+    return nullptr;
+  }
 
-  if (!object)
-    throw PyException();
-
-  if (object == Py_True)
-    return true;
-  if (object == Py_False)
-    return false;
-  throw std::invalid_argument("Expected to get Py_True or Py_False, but got something else");
+  const char* version = nullptr;
+  if (!PyArg_ParseTuple(args, "s", &version)) {
+    return nullptr;
+  }
+  processor->setVersion(std::string(version));
+  Py_RETURN_NONE;
 }
-}  // namespace
-
 
 PyObject* PyProcessor::addProperty(PyProcessor* self, PyObject* args) {
   auto processor = self->processor_.lock();
   if (!processor) {
     PyErr_SetString(PyExc_AttributeError, "tried reading processor outside 'on_trigger'");
-    Py_RETURN_NONE;
+    return nullptr;
+  }
+
+  static constexpr Py_ssize_t ExpectedNumArgs = 9;
+  auto arg_size = PyTuple_Size(args);
+  if (arg_size < ExpectedNumArgs) {
+    PyErr_SetString(PyExc_AttributeError, fmt::format("addProperty was called with too few arguments: need {}, got {}", ExpectedNumArgs, arg_size).c_str());
+    return nullptr;
   }
 
   BorrowedStr name = BorrowedStr::fromTuple(args, 0);
@@ -116,32 +140,44 @@ PyObject* PyProcessor::addProperty(PyProcessor* self, PyObject* args) {
   if (default_value_pystr.get() && default_value_pystr.get() != Py_None) {
     default_value = default_value_pystr.toUtf8String();
   }
-  bool is_required = getBoolFromTuple(args, 3);
-  bool supports_expression_language = getBoolFromTuple(args, 4);
 
+  bool is_required = false;
+  bool supports_expression_language = false;
   bool sensitive = false;
-  auto arg_size = PyTuple_Size(args);
-  if (arg_size > 5) {
+
+  try {
+    is_required = getBoolFromTuple(args, 3);
+    supports_expression_language = getBoolFromTuple(args, 4);
+
     sensitive = getBoolFromTuple(args, 5);
+  } catch (const PyException&) {
+    return nullptr;
   }
 
   std::optional<int64_t> validator_value;
-  if (arg_size > 6) {
-    auto validator_value_pyint = BorrowedLong::fromTuple(args, 6);
-    if (validator_value_pyint.get() && validator_value_pyint.get() != Py_None) {
-      validator_value = validator_value_pyint.asInt64();
+  auto validator_value_pyint = BorrowedLong::fromTuple(args, 6);
+  if (validator_value_pyint.get() && validator_value_pyint.get() != Py_None) {
+    validator_value = validator_value_pyint.asInt64();
+  }
+
+  std::vector<std::string> allowable_values_str;
+  auto allowable_values_pylist = BorrowedList::fromTuple(args, 7);
+  if (allowable_values_pylist.get() && allowable_values_pylist.get() != Py_None) {
+    for (size_t i = 0; i < allowable_values_pylist.length(); ++i) {
+      auto value = BorrowedStr{allowable_values_pylist[i]};
+      allowable_values_str.push_back(value.toUtf8String());
     }
   }
+  std::vector<std::string_view> allowable_values(begin(allowable_values_str), end(allowable_values_str));
 
   std::optional<std::string> controller_service_type_name;
-  if (arg_size > 7) {
-    auto controller_service_type_name_pystr = BorrowedStr::fromTuple(args, 7);
-    if (controller_service_type_name_pystr.get() && controller_service_type_name_pystr.get() != Py_None) {
-      controller_service_type_name = controller_service_type_name_pystr.toUtf8String();
-    }
+  auto controller_service_type_name_pystr = BorrowedStr::fromTuple(args, 8);
+  if (controller_service_type_name_pystr.get() && controller_service_type_name_pystr.get() != Py_None) {
+    controller_service_type_name = controller_service_type_name_pystr.toUtf8String();
   }
 
-  processor->addProperty(name.toUtf8String(), description.toUtf8String(), default_value, is_required, supports_expression_language, sensitive, validator_value, controller_service_type_name);
+  processor->addProperty(name.toUtf8String(), description.toUtf8String(), default_value, is_required, supports_expression_language, sensitive,
+      validator_value, allowable_values, controller_service_type_name);
   Py_RETURN_NONE;
 }
 
@@ -150,5 +186,5 @@ PyTypeObject* PyProcessor::typeObject() {
   return reinterpret_cast<PyTypeObject*>(PyProcessorType.get());
 }
 
-}  // namespace org::apache::nifi::minifi::extensions::python
 }  // extern "C"
+}  // namespace org::apache::nifi::minifi::extensions::python
