@@ -16,19 +16,17 @@ a * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  */
 
 #include "PyStateManager.h"
-#include <string>
-#include "PyException.h"
 
 extern "C" {
 namespace org::apache::nifi::minifi::extensions::python {
 
-static PyMethodDef PyStateManager_methods[] = {
+static PyMethodDef PyStateManager_methods[] = {  // NOLINT(cppcoreguidelines-avoid-c-arrays)
     {"get", (PyCFunction) PyStateManager::get, METH_VARARGS, nullptr},
     {"set", (PyCFunction) PyStateManager::set, METH_VARARGS, nullptr},
     {}  /* Sentinel */
 };
 
-static PyType_Slot PyStateManagerTypeSpecSlots[] = {
+static PyType_Slot PyStateManagerTypeSpecSlots[] = {  // NOLINT(cppcoreguidelines-avoid-c-arrays)
     {Py_tp_dealloc, reinterpret_cast<void*>(pythonAllocatedInstanceDealloc<PyStateManager>)},
     {Py_tp_init, reinterpret_cast<void*>(PyStateManager::init)},
     {Py_tp_methods, reinterpret_cast<void*>(PyStateManager_methods)},
@@ -52,7 +50,7 @@ int PyStateManager::init(PyStateManager* self, PyObject* args, PyObject*) {
 
   auto state_manager = PyCapsule_GetPointer(weak_ptr_capsule, HeldTypeName);
   if (!state_manager)
-    throw PyException();
+    return -1;
   self->state_manager_ = *static_cast<HeldType*>(state_manager);
   return 0;
 }
