@@ -28,18 +28,22 @@
 
 namespace org::apache::nifi::minifi::io {
 
-RocksDbStream::RocksDbStream(std::string path, gsl::not_null<minifi::internal::RocksDatabase*> db, bool write_enable, minifi::internal::WriteBatch* batch)
+RocksDbStream::RocksDbStream(std::string path, gsl::not_null<minifi::internal::RocksDatabase*> db, bool write_enable, minifi::internal::WriteBatch* batch,
+  bool use_synchronous_writes, bool verify_checksums)
     : BaseStream(),
       path_(std::move(path)),
       write_enable_(write_enable),
       db_(db),
-      exists_([this] {
+      exists_([this, verify_checksums] {
         auto opendb = db_->open();
-        return opendb && opendb->Get(rocksdb::ReadOptions(), path_, &value_).ok();
+        rocksdb::ReadOptions options;
+        options.verify_checksums = verify_checksums;
+        return opendb && opendb->Get(options, path_, &value_).ok();
       }()),
       offset_(0),
       batch_(batch),
-      size_(value_.size()) {
+      size_(value_.size()),
+      use_synchronous_writes_(use_synchronous_writes) {
 }
 
 void RocksDbStream::close() {
@@ -67,7 +71,7 @@ size_t RocksDbStream::write(const uint8_t *value, size_t size) {
     status = batch_->Merge(path_, slice_value);
   } else {
     rocksdb::WriteOptions opts;
-    opts.sync = true;
+    opts.sync = use_synchronous_writes_;
     status = opendb->Merge(opts, path_, slice_value);
   }
   if (status.ok()) {
