@@ -26,12 +26,7 @@
 #include "logging/Logger.h"
 #include "utils/crypto/EncryptionManager.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
-namespace repository {
+namespace org::apache::nifi::minifi::core::repository {
 
 struct DbEncryptionOptions {
   std::string database;
@@ -44,9 +39,4 @@ struct EncryptionEq {
   bool operator()(const rocksdb::Env* lhs, const rocksdb::Env* rhs) const;
 };
 
-}  // namespace repository
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::core::repository
