@@ -72,12 +72,12 @@ class ExecuteScript : public core::Processor {
   EXTENSIONAPI static constexpr auto ModuleDirectory = core::PropertyDefinitionBuilder<>::createProperty("Module Directory")
       .withDescription(R"(Comma-separated list of paths to files and/or directories which contain modules required by the script)")
       .build();
-  EXTENSIONAPI static constexpr auto Properties = std::array<core::PropertyReference, 4>{
+  EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({
       ScriptEngine,
       ScriptFile,
       ScriptBody,
       ModuleDirectory
-  };
+  });
 
 
   EXTENSIONAPI static constexpr auto Success = core::RelationshipDefinition{"success", "Script successes"};
@@ -93,7 +93,10 @@ class ExecuteScript : public core::Processor {
 
   void initialize() override;
   void onSchedule(core::ProcessContext& context, core::ProcessSessionFactory& session_factory) override;
-  void onTriggerSharedPtr(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) override;
+  void onTrigger(core::ProcessContext& context, core::ProcessSession& session) override;
+  void notifyStop() override {
+    script_executor_.reset();
+  }
 
  private:
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ExecuteScript>::getLogger(uuid_);
