@@ -17,8 +17,6 @@
  */
 
 #include <sys/stat.h>
-#undef NDEBUG
-#include <cassert>
 #include <cstring>
 #include <utility>
 #include <chrono>
@@ -37,8 +35,8 @@
 #include <unistd.h>
 #endif
 
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "utils/file/FileUtils.h"
 #include "core/Core.h"
 #include "core/logging/Logger.h"
@@ -50,7 +48,7 @@
 #include "processors/GenerateFlowFile.h"
 #include "processors/LogAttribute.h"
 #include "tools/SFTPTestServer.h"
-#include "utils/TestUtils.h"
+#include "unit/TestUtils.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -93,8 +91,8 @@ class ListSFTPTestsFixture {
   void createPlan(const utils::Identifier* list_sftp_uuid = nullptr, const std::shared_ptr<minifi::Configure>& configuration = nullptr) {
     const auto state_dir = plan == nullptr ? testController.createTempDirectory() : plan->getStateDir();
 
-    log_attribute.reset();
-    list_sftp.reset();
+    log_attribute = nullptr;
+    list_sftp = nullptr;
     plan.reset();
 
     if (configuration) {
@@ -162,8 +160,8 @@ class ListSFTPTestsFixture {
   std::filesystem::path working_directory = testController.createTempDirectory();
   std::shared_ptr<TestPlan> plan;
   std::unique_ptr<SFTPTestServer> sftp_server;
-  std::shared_ptr<core::Processor> list_sftp;
-  std::shared_ptr<core::Processor> log_attribute;
+  core::Processor* list_sftp = nullptr;
+  core::Processor* log_attribute = nullptr;
 };
 
 class PersistentListSFTPTestsFixture : public ListSFTPTestsFixture {
