@@ -20,21 +20,19 @@
 
 namespace org::apache::nifi::minifi::sql {
 
-SQLColumnIdentifier::SQLColumnIdentifier(std::string str) {
-  // foo, "foo", [foo], `foo` are identifiers in different servers
-  value_ = [&] () {
-    if (str.length() < 2) {
-      return str;
-    }
-    if ((str.front() == '"' && str.back() == '"')
-        || (str.front() == '[' && str.back() == ']')
-        || (str.front() == '`' && str.back() == '`')) {
-      return str.substr(1, str.length() - 2);
-    }
-    return str;
-  }();
-
-  original_value_ = std::move(str);
+SQLColumnIdentifier::SQLColumnIdentifier(std::string str)
+    : value_([&] {
+          if (str.length() < 2) {
+            return str;
+          }
+          if ((str.front() == '"' && str.back() == '"')
+              || (str.front() == '[' && str.back() == ']')
+              || (str.front() == '`' && str.back() == '`')) {
+            return str.substr(1, str.length() - 2);
+          }
+          return str;
+        }()),
+      original_value_(std::move(str)) {
 }
 
 }  // namespace org::apache::nifi::minifi::sql
