@@ -40,8 +40,8 @@ const std::string QueryDatabaseTable::RESULT_ROW_COUNT = "querydbtable.row.count
 const std::string QueryDatabaseTable::TABLENAME_KEY = "tablename";
 const std::string QueryDatabaseTable::MAXVALUE_KEY_PREFIX = "maxvalue.";
 
-QueryDatabaseTable::QueryDatabaseTable(std::string name, const utils::Identifier& uuid)
-  : SQLProcessor(std::move(name), uuid, core::logging::LoggerFactory<QueryDatabaseTable>::getLogger(uuid)) {
+QueryDatabaseTable::QueryDatabaseTable(std::string_view name, const utils::Identifier& uuid)
+  : SQLProcessor(name, uuid, core::logging::LoggerFactory<QueryDatabaseTable>::getLogger(uuid)) {
 }
 
 void QueryDatabaseTable::initialize() {
@@ -67,7 +67,7 @@ void QueryDatabaseTable::processOnSchedule(core::ProcessContext& context) {
 
   return_columns_.clear();
   queried_columns_.clear();
-  for (auto&& raw_col : utils::StringUtils::splitAndTrimRemovingEmpty(context.getProperty(ColumnNames).value_or(""), ",")) {
+  for (auto&& raw_col : utils::string::splitAndTrimRemovingEmpty(context.getProperty(ColumnNames).value_or(""), ",")) {
     if (!queried_columns_.empty()) {
       queried_columns_ += ", ";
     }
@@ -76,7 +76,7 @@ void QueryDatabaseTable::processOnSchedule(core::ProcessContext& context) {
   }
 
   max_value_columns_.clear();
-  for (auto&& raw_col : utils::StringUtils::splitAndTrimRemovingEmpty(context.getProperty(MaxValueColumnNames).value_or(""), ",")) {
+  for (auto&& raw_col : utils::string::splitAndTrimRemovingEmpty(context.getProperty(MaxValueColumnNames).value_or(""), ",")) {
     sql::SQLColumnIdentifier col_id(raw_col);
     if (!queried_columns_.empty() && !return_columns_.contains(col_id)) {
       // columns will be explicitly enumerated, we need to add the max value columns as it is not yet queried
@@ -92,7 +92,7 @@ void QueryDatabaseTable::processOnSchedule(core::ProcessContext& context) {
 void QueryDatabaseTable::processOnTrigger(core::ProcessContext& /*context*/, core::ProcessSession& session) {
   const auto& selectQuery = buildSelectQuery();
 
-  logger_->log_info("QueryDatabaseTable: selectQuery: '%s'", selectQuery.c_str());
+  logger_->log_info("QueryDatabaseTable: selectQuery: '{}'", selectQuery.c_str());
 
   auto statement = connection_->prepareStatement(selectQuery);
 
@@ -135,24 +135,24 @@ bool QueryDatabaseTable::loadMaxValuesFromStoredState(const std::unordered_map<s
     return false;
   }
   if (state.at(TABLENAME_KEY) != table_name_) {
-    logger_->log_info("Querying new table \"%s\", resetting state.", table_name_);
+    logger_->log_info("Querying new table \"{}\", resetting state.", table_name_);
     return false;
   }
   for (auto& elem : state) {
-    if (utils::StringUtils::startsWith(elem.first, MAXVALUE_KEY_PREFIX)) {
+    if (utils::string::startsWith(elem.first, MAXVALUE_KEY_PREFIX)) {
       sql::SQLColumnIdentifier column_name(elem.first.substr(MAXVALUE_KEY_PREFIX.length()));
       // add only those columns that we care about
       if (std::find(max_value_columns_.begin(), max_value_columns_.end(), column_name) != max_value_columns_.end()) {
         new_max_values.emplace(column_name, elem.second);
       } else {
-        logger_->log_info("State contains obsolete maximum-value column \"%s\", resetting state.", column_name.str());
+        logger_->log_info("State contains obsolete maximum-value column \"{}\", resetting state.", column_name.str());
         return false;
       }
     }
   }
   for (auto& column : max_value_columns_) {
     if (new_max_values.find(column) == new_max_values.end()) {
-      logger_->log_info("New maximum-value column \"%s\" specified, resetting state.", column.str());
+      logger_->log_info("New maximum-value column \"{}\" specified, resetting state.", column.str());
       return false;
     }
   }
@@ -181,16 +181,16 @@ void QueryDatabaseTable::initializeMaxValues(core::ProcessContext &context) {
 
 void QueryDatabaseTable::loadMaxValuesFromDynamicProperties(core::ProcessContext &context) {
   const auto dynamic_prop_keys = context.getDynamicPropertyKeys();
-  logger_->log_info("Received %zu dynamic properties", dynamic_prop_keys.size());
+  logger_->log_info("Received {} dynamic properties", dynamic_prop_keys.size());
 
   for (const auto& key : dynamic_prop_keys) {
-    if (!utils::StringUtils::startsWith(key, InitialMaxValueDynamicPropertyPrefix)) {
+    if (!utils::string::startsWith(key, InitialMaxValueDynamicPropertyPrefix)) {
       throw minifi::Exception(PROCESSOR_EXCEPTION, "QueryDatabaseTable: Unsupported dynamic property \"" + key + "\"");
     }
     sql::SQLColumnIdentifier column_name(key.substr(InitialMaxValueDynamicPropertyPrefix.length()));
     auto it = max_values_.find(column_name);
     if (it == max_values_.end()) {
-      logger_->log_warn("Initial maximum value specified for column \"%s\", which is not specified as a Maximum-value Column. Ignoring.", column_name.str());
+      logger_->log_warn("Initial maximum value specified for column \"{}\", which is not specified as a Maximum-value Column. Ignoring.", column_name.str());
       continue;
     }
     // do not overwrite existing max value
@@ -200,7 +200,7 @@ void QueryDatabaseTable::loadMaxValuesFromDynamicProperties(core::ProcessContext
     std::string value;
     if (context.getDynamicProperty(key, value) && !value.empty()) {
       it->second = value;
-      logger_->log_info("Setting initial maximum value of %s to %s", column_name.str(), value);
+      logger_->log_info("Setting initial maximum value of {} to {}", column_name.str(), value);
     }
   }
 }
@@ -221,7 +221,7 @@ std::string QueryDatabaseTable::buildSelectQuery() {
     // Logic to differentiate ">" vs ">=" based on index is copied from:
     // https://github.com/apache/nifi/blob/master/nifi-nar-bundles/nifi-standard-bundle/nifi-standard-processors/src/main/java/org/apache/nifi/processors/standard/AbstractQueryDatabaseTable.java
     // (under comment "Add a condition for the WHERE clause"). And implementation explanation: https://issues.apache.org/jira/browse/NIFI-2712.
-    where_clauses.push_back(utils::StringUtils::join_pack(column_name.str(), index == 0 ? " > " : " >= ", max_value));
+    where_clauses.push_back(utils::string::join_pack(column_name.str(), index == 0 ? " > " : " >= ", max_value));
   }
 
   if (!extra_where_clause_.empty()) {
@@ -229,7 +229,7 @@ std::string QueryDatabaseTable::buildSelectQuery() {
   }
 
   if (!where_clauses.empty()) {
-    query += " where " + utils::StringUtils::join(" and ", where_clauses);
+    query += " where " + utils::string::join(" and ", where_clauses);
   }
 
   return query;
