@@ -43,7 +43,7 @@ class VolatileMapStateStorage : virtual public KeyValueStateStorage {
   EXTENSIONAPI static constexpr auto LinkedServices = core::PropertyDefinitionBuilder<>::createProperty("Linked Services")
       .withDescription("Referenced Controller Services")
       .build();
-  EXTENSIONAPI static constexpr auto Properties = std::array<core::PropertyReference, 1>{LinkedServices};
+  EXTENSIONAPI static constexpr auto Properties = std::to_array<core::PropertyReference>({LinkedServices});
   EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
   ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
 
