@@ -42,15 +42,15 @@ void ExtractText::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void ExtractText::onTrigger(core::ProcessContext *context, core::ProcessSession *session) {
-  std::shared_ptr<core::FlowFile> flowFile = session->get();
+void ExtractText::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
+  std::shared_ptr<core::FlowFile> flowFile = session.get();
 
   if (!flowFile) {
     return;
   }
 
-  session->read(flowFile, ReadCallback{flowFile, context, logger_});
-  session->transfer(flowFile, Success);
+  session.read(flowFile, ReadCallback{flowFile, &context, logger_});
+  session.transfer(flowFile, Success);
 }
 
 int64_t ExtractText::ReadCallback::operator()(const std::shared_ptr<io::InputStream>& stream) const {
@@ -142,7 +142,7 @@ int64_t ExtractText::ReadCallback::operator()(const std::shared_ptr<io::InputStr
           workStr = matches.suffix();
         }
       } catch (const Exception &e) {
-        logger_->log_error("%s error encountered when trying to construct regular expression from property (key: %s) value: %s",
+        logger_->log_error("{} error encountered when trying to construct regular expression from property (key: {}) value: {}",
                            e.what(), k, value);
         continue;
       }
