@@ -26,13 +26,14 @@
 #include "core/logging/LoggerConfiguration.h"
 
 #include "asio/ip/udp.hpp"
+#include "utils/net/AsioSocketUtils.h"
 
 using asio::ip::udp;
 
 namespace org::apache::nifi::minifi::processors {
 
-PutUDP::PutUDP(std::string name, const utils::Identifier& uuid)
-    : Processor(std::move(name), uuid), logger_{core::logging::LoggerFactory<PutUDP>::getLogger(uuid)}
+PutUDP::PutUDP(std::string_view name, const utils::Identifier& uuid)
+    : Processor(name, uuid), logger_{core::logging::LoggerFactory<PutUDP>::getLogger(uuid)}
 { }
 
 PutUDP::~PutUDP() = default;
@@ -44,40 +45,36 @@ void PutUDP::initialize() {
 
 void PutUDP::notifyStop() {}
 
-void PutUDP::onSchedule(core::ProcessContext* const context, core::ProcessSessionFactory*) {
-  gsl_Expects(context);
-
+void PutUDP::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
   // if the required properties are missing or empty even before evaluating the EL expression, then we can throw in onSchedule, before we waste any flow files
-  if (context->getProperty(Hostname).value_or(std::string{}).empty()) {
+  if (context.getProperty(Hostname).value_or(std::string{}).empty()) {
     throw Exception{ExceptionType::PROCESSOR_EXCEPTION, "missing hostname"};
   }
-  if (context->getProperty(Port).value_or(std::string{}).empty()) {
+  if (context.getProperty(Port).value_or(std::string{}).empty()) {
     throw Exception{ExceptionType::PROCESSOR_EXCEPTION, "missing port"};
   }
 }
 
-void PutUDP::onTrigger(core::ProcessContext* context, core::ProcessSession* const session) {
-  gsl_Expects(context && session);
-
-  const auto flow_file = session->get();
+void PutUDP::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
+  const auto flow_file = session.get();
   if (!flow_file) {
     yield();
     return;
   }
 
-  const auto hostname = context->getProperty(Hostname, flow_file).value_or(std::string{});
-  const auto port = context->getProperty(Port, flow_file).value_or(std::string{});
+  const auto hostname = context.getProperty(Hostname, flow_file.get()).value_or(std::string{});
+  const auto port = context.getProperty(Port, flow_file.get()).value_or(std::string{});
   if (hostname.empty() || port.empty()) {
-    logger_->log_error("[%s] invalid target endpoint: hostname: %s, port: %s", flow_file->getUUIDStr(),
+    logger_->log_error("[{}] invalid target endpoint: hostname: {}, port: {}", flow_file->getUUIDStr(),
         hostname.empty() ? "(empty)" : hostname.c_str(),
         port.empty() ? "(empty)" : port.c_str());
-    session->transfer(flow_file, Failure);
+    session.transfer(flow_file, Failure);
     return;
   }
 
-  const auto data = session->readBuffer(flow_file);
+  const auto data = session.readBuffer(flow_file);
   if (io::isError(data.status)) {
-    session->transfer(flow_file, Failure);
+    session.transfer(flow_file, Failure);
     return;
   }
 
@@ -99,33 +96,33 @@ void PutUDP::onTrigger(core::ProcessContext* context, core::ProcessSession* cons
       udp::socket socket(io_context);
       socket.open(resolver_entry.endpoint().protocol(), error);
       if (error) {
-        logger->log_debug("opening %s socket failed due to %s ", resolver_entry.endpoint().protocol() == udp::v4() ? "IPv4" : "IPv6", error.message());
+        logger->log_debug("opening {} socket failed due to {} ", resolver_entry.endpoint().protocol() == udp::v4() ? "IPv4" : "IPv6", error.message());
         continue;
       }
       socket.send_to(asio::buffer(data.buffer), resolver_entry.endpoint(), udp::socket::message_flags{}, error);
       if (error) {
-        core::logging::LOG_DEBUG(logger) << "sending to endpoint " << resolver_entry.endpoint() << " failed due to " << error.message();
+        logger->log_debug("sending to endpoint {} failed due to {}", resolver_entry.endpoint(), error.message());
         continue;
       }
-      core::logging::LOG_DEBUG(logger) << "sending to endpoint " << resolver_entry.endpoint() << " succeeded";
+      logger->log_debug("sending to endpoint {} succeeded", resolver_entry.endpoint());
       return {};
     }
     return nonstd::make_unexpected(error);
   };
 
   const auto transfer_to_success = [&session, &flow_file]() -> void {
-    session->transfer(flow_file, Success);
+    session.transfer(flow_file, Success);
   };
 
   const auto transfer_to_failure = [&session, &flow_file, &logger = this->logger_](std::error_code ec) -> void {
     gsl_Expects(ec);
-    logger->log_error("%s", ec.message());
-    session->transfer(flow_file, Failure);
+    logger->log_error("{}", ec.message());
+    session.transfer(flow_file, Failure);
   };
 
   resolve_hostname()
-      | utils::flatMap(send_data_to_endpoint)
-      | utils::map(transfer_to_success)
+      | utils::andThen(send_data_to_endpoint)
+      | utils::transform(transfer_to_success)
       | utils::orElse(transfer_to_failure);
 }
 
