@@ -28,8 +28,8 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-ReplaceText::ReplaceText(std::string name, const utils::Identifier& uuid)
-  : core::Processor(std::move(name), uuid),
+ReplaceText::ReplaceText(std::string_view name, const utils::Identifier& uuid)
+  : core::Processor(name, uuid),
     logger_(core::logging::LoggerFactory<ReplaceText>::getLogger(uuid)) {
 }
 
@@ -38,26 +38,21 @@ void ReplaceText::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void ReplaceText::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>&) {
-  gsl_Expects(context);
+void ReplaceText::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  evaluation_mode_ = utils::parseEnumProperty<EvaluationModeType>(context, EvaluationMode);
+  logger_->log_debug("the {} property is set to {}", EvaluationMode.name, magic_enum::enum_name(evaluation_mode_));
 
-  evaluation_mode_ = utils::parseEnumProperty<EvaluationModeType>(*context, EvaluationMode);
-  logger_->log_debug("the %s property is set to %s", std::string(EvaluationMode.name), std::string{magic_enum::enum_name(evaluation_mode_)});
-
-  if (auto line_by_line_evaluation_mode = utils::parseOptionalEnumProperty<LineByLineEvaluationModeType>(*context, LineByLineEvaluationMode)) {
+  if (auto line_by_line_evaluation_mode = utils::parseOptionalEnumProperty<LineByLineEvaluationModeType>(context, LineByLineEvaluationMode)) {
     line_by_line_evaluation_mode_ = *line_by_line_evaluation_mode;
-    logger_->log_debug("the %s property is set to %s", std::string(LineByLineEvaluationMode.name), std::string{magic_enum::enum_name(line_by_line_evaluation_mode_)});
+    logger_->log_debug("the {} property is set to {}", LineByLineEvaluationMode.name, magic_enum::enum_name(line_by_line_evaluation_mode_));
   }
 
-  replacement_strategy_ = utils::parseEnumProperty<ReplacementStrategyType>(*context, ReplacementStrategy);
-  logger_->log_debug("the %s property is set to %s", std::string(ReplacementStrategy.name), std::string{magic_enum::enum_name(replacement_strategy_)});
+  replacement_strategy_ = utils::parseEnumProperty<ReplacementStrategyType>(context, ReplacementStrategy);
+  logger_->log_debug("the {} property is set to {}", ReplacementStrategy.name, magic_enum::enum_name(replacement_strategy_));
 }
 
-void ReplaceText::onTrigger(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSession>& session) {
-  gsl_Expects(context);
-  gsl_Expects(session);
-
-  std::shared_ptr<core::FlowFile> flow_file = session->get();
+void ReplaceText::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
+  std::shared_ptr<core::FlowFile> flow_file = session.get();
   if (!flow_file) {
     logger_->log_trace("No flow file");
     yield();
@@ -75,65 +70,55 @@ void ReplaceText::onTrigger(const std::shared_ptr<core::ProcessContext>& context
       return;
   }
 
-  throw Exception{PROCESSOR_EXCEPTION, utils::StringUtils::join_pack("Unsupported ", EvaluationMode.name, ": ", std::string{magic_enum::enum_name(evaluation_mode_)})};
+  throw Exception{PROCESSOR_EXCEPTION, utils::string::join_pack("Unsupported ", EvaluationMode.name, ": ", std::string{magic_enum::enum_name(evaluation_mode_)})};
 }
 
-ReplaceText::Parameters ReplaceText::readParameters(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::FlowFile>& flow_file) const {
+ReplaceText::Parameters ReplaceText::readParameters(core::ProcessContext& context, const std::shared_ptr<core::FlowFile>& flow_file) const {
   Parameters parameters;
 
-  bool found_search_value;
-  if (replacement_strategy_ == ReplacementStrategyType::REGEX_REPLACE) {
-    found_search_value = context->getProperty(SearchValue, parameters.search_value_);
-  } else {
-    found_search_value = context->getProperty(SearchValue, parameters.search_value_, flow_file);
-  }
+  bool found_search_value = (replacement_strategy_ == ReplacementStrategyType::REGEX_REPLACE ?
+      context.getProperty(SearchValue, parameters.search_value_) : context.getProperty(SearchValue, parameters.search_value_, flow_file.get()));
   if (found_search_value) {
-    logger_->log_debug("the %s property is set to %s", std::string{SearchValue.name}, parameters.search_value_);
+    logger_->log_debug("the {} property is set to {}", SearchValue.name, parameters.search_value_);
     if (replacement_strategy_ == ReplacementStrategyType::REGEX_REPLACE) {
       parameters.search_regex_ = std::regex{parameters.search_value_};
     }
   }
   if ((replacement_strategy_ == ReplacementStrategyType::REGEX_REPLACE || replacement_strategy_ == ReplacementStrategyType::LITERAL_REPLACE) && parameters.search_value_.empty()) {
-    throw Exception{PROCESSOR_EXCEPTION, utils::StringUtils::join_pack("Error: missing or empty ", SearchValue.name, " property")};
+    throw Exception{PROCESSOR_EXCEPTION, utils::string::join_pack("Error: missing or empty ", SearchValue.name, " property")};
   }
 
-  bool found_replacement_value;
-  if (replacement_strategy_ == ReplacementStrategyType::REGEX_REPLACE) {
-    found_replacement_value = context->getProperty(ReplacementValue, parameters.replacement_value_);
-  } else {
-    found_replacement_value = context->getProperty(ReplacementValue, parameters.replacement_value_, flow_file);
-  }
+  bool found_replacement_value = (replacement_strategy_ == ReplacementStrategyType::REGEX_REPLACE ?
+      context.getProperty(ReplacementValue, parameters.replacement_value_) : context.getProperty(ReplacementValue, parameters.replacement_value_, flow_file.get()));
   if (found_replacement_value) {
-    logger_->log_debug("the %s property is set to %s", std::string(ReplacementValue.name), parameters.replacement_value_);
+    logger_->log_debug("the {} property is set to {}", ReplacementValue.name, parameters.replacement_value_);
   } else {
-    throw Exception{PROCESSOR_EXCEPTION, utils::StringUtils::join_pack("Missing required property: ", ReplacementValue.name)};
+    throw Exception{PROCESSOR_EXCEPTION, utils::string::join_pack("Missing required property: ", ReplacementValue.name)};
   }
 
   if (evaluation_mode_ == EvaluationModeType::LINE_BY_LINE) {
-    auto [chomped_value, line_ending] = utils::StringUtils::chomp(parameters.replacement_value_);
+    auto [chomped_value, line_ending] = utils::string::chomp(parameters.replacement_value_);
     parameters.replacement_value_ = std::move(chomped_value);
   }
 
   return parameters;
 }
 
-void ReplaceText::replaceTextInEntireFile(const std::shared_ptr<core::FlowFile>& flow_file, const std::shared_ptr<core::ProcessSession>& session, const Parameters& parameters) const {
+void ReplaceText::replaceTextInEntireFile(const std::shared_ptr<core::FlowFile>& flow_file, core::ProcessSession& session, const Parameters& parameters) const {
   gsl_Expects(flow_file);
-  gsl_Expects(session);
 
   try {
-    const auto input = to_string(session->readBuffer(flow_file));
-    session->writeBuffer(flow_file, applyReplacements(input, flow_file, parameters));
-    session->transfer(flow_file, Success);
+    const auto input = to_string(session.readBuffer(flow_file));
+    session.writeBuffer(flow_file, applyReplacements(input, flow_file, parameters));
+    session.transfer(flow_file, Success);
   } catch (const Exception& exception) {
-    logger_->log_error("Error in ReplaceText (Entire text mode): %s", exception.what());
-    session->transfer(flow_file, Failure);
+    logger_->log_error("Error in ReplaceText (Entire text mode): {}", exception.what());
+    session.transfer(flow_file, Failure);
   }
 }
 
-void ReplaceText::replaceTextLineByLine(const std::shared_ptr<core::FlowFile>& flow_file, const std::shared_ptr<core::ProcessSession>& session, const Parameters& parameters) const {
+void ReplaceText::replaceTextLineByLine(const std::shared_ptr<core::FlowFile>& flow_file, core::ProcessSession& session, const Parameters& parameters) const {
   gsl_Expects(flow_file);
-  gsl_Expects(session);
 
   try {
     utils::LineByLineInputOutputStreamCallback read_write_callback{[this, &flow_file, &parameters](const std::string& input_line, bool is_first_line, bool is_last_line) {
@@ -149,18 +134,18 @@ void ReplaceText::replaceTextLineByLine(const std::shared_ptr<core::FlowFile>& f
         case LineByLineEvaluationModeType::EXCEPT_LAST_LINE:
           return is_last_line ? input_line: applyReplacements(input_line, flow_file, parameters);
       }
-      throw Exception{PROCESSOR_EXCEPTION, utils::StringUtils::join_pack("Unsupported ", LineByLineEvaluationMode.name, ": ", std::string{magic_enum::enum_name(line_by_line_evaluation_mode_)})};
+      throw Exception{PROCESSOR_EXCEPTION, utils::string::join_pack("Unsupported ", LineByLineEvaluationMode.name, ": ", std::string{magic_enum::enum_name(line_by_line_evaluation_mode_)})};
     }};
-    session->readWrite(flow_file, std::move(read_write_callback));
-    session->transfer(flow_file, Success);
+    session.readWrite(flow_file, std::move(read_write_callback));
+    session.transfer(flow_file, Success);
   } catch (const Exception& exception) {
-    logger_->log_error("Error in ReplaceText (Line-by-Line mode): %s", exception.what());
-    session->transfer(flow_file, Failure);
+    logger_->log_error("Error in ReplaceText (Line-by-Line mode): {}", exception.what());
+    session.transfer(flow_file, Failure);
   }
 }
 
 std::string ReplaceText::applyReplacements(const std::string& input, const std::shared_ptr<core::FlowFile>& flow_file, const Parameters& parameters) const {
-  const auto [chomped_input, line_ending] = utils::StringUtils::chomp(input);
+  const auto [chomped_input, line_ending] = utils::string::chomp(input);
 
   switch (replacement_strategy_) {
     case ReplacementStrategyType::PREPEND:
@@ -182,7 +167,7 @@ std::string ReplaceText::applyReplacements(const std::string& input, const std::
       return applySubstituteVariables(chomped_input, flow_file) + line_ending;
   }
 
-  throw Exception{PROCESSOR_EXCEPTION, utils::StringUtils::join_pack("Unsupported ", ReplacementStrategy.name, ": ", std::string{magic_enum::enum_name(replacement_strategy_)})};
+  throw Exception{PROCESSOR_EXCEPTION, utils::string::join_pack("Unsupported ", ReplacementStrategy.name, ": ", std::string{magic_enum::enum_name(replacement_strategy_)})};
 }
 
 std::string ReplaceText::applyLiteralReplace(const std::string& input, const Parameters& parameters) {
@@ -239,7 +224,7 @@ std::string ReplaceText::getAttributeValue(const std::shared_ptr<core::FlowFile>
   if (attribute_value) {
     return *attribute_value;
   } else {
-    logger_->log_debug("Attribute %s not found in the flow file during %s", attribute_key, std::string{magic_enum::enum_name(ReplacementStrategyType::SUBSTITUTE_VARIABLES)});
+    logger_->log_debug("Attribute {} not found in the flow file during {}", attribute_key, magic_enum::enum_name(ReplacementStrategyType::SUBSTITUTE_VARIABLES));
     return match[0];
   }
 }
