@@ -26,24 +26,24 @@ void RetryFlowFile::initialize() {
   setSupportedRelationships(Relationships);
 }
 
-void RetryFlowFile::onSchedule(core::ProcessContext* context, core::ProcessSessionFactory* /* sessionFactory */) {
-  context->getProperty(RetryAttribute, retry_attribute_);
-  context->getProperty(MaximumRetries, maximum_retries_);
-  context->getProperty(PenalizeRetries, penalize_retries_);
-  context->getProperty(FailOnNonNumericalOverwrite, fail_on_non_numerical_overwrite_);
-  context->getProperty(ReuseMode, reuse_mode_);
+void RetryFlowFile::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  context.getProperty(RetryAttribute, retry_attribute_);
+  context.getProperty(MaximumRetries, maximum_retries_);
+  context.getProperty(PenalizeRetries, penalize_retries_);
+  context.getProperty(FailOnNonNumericalOverwrite, fail_on_non_numerical_overwrite_);
+  context.getProperty(ReuseMode, reuse_mode_);
   readDynamicPropertyKeys(context);
 }
 
-void RetryFlowFile::onTrigger(core::ProcessContext* context, core::ProcessSession* session) {
-  auto flow_file = session->get();
+void RetryFlowFile::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
+  auto flow_file = session.get();
   if (!flow_file) {
     return;
   }
 
   const auto maybe_retry_property_value = getRetryPropertyValue(flow_file);
   if (!maybe_retry_property_value) {
-    session->transfer(flow_file, Failure);
+    session.transfer(flow_file, Failure);
     return;
   }
   uint64_t retry_property_value = maybe_retry_property_value.value();
@@ -53,10 +53,10 @@ void RetryFlowFile::onTrigger(core::ProcessContext* context, core::ProcessSessio
   if (flow_file->getAttribute(last_retried_by_property_name, last_retried_by_uuid)) {
     if (last_retried_by_uuid != current_processor_uuid) {
       if (reuse_mode_ == FAIL_ON_REUSE) {
-        logger_->log_error("FlowFile %s was previously retried with the same attribute by a different "
-            "processor (uuid: %s, current uuid: %s). Transfering flowfile to 'failure'...",
+        logger_->log_error("FlowFile {} was previously retried with the same attribute by a different "
+            "processor (uuid: {}, current uuid: {}). Transfering flowfile to 'failure'...",
             flow_file->getUUIDStr(), last_retried_by_uuid, current_processor_uuid);
-        session->transfer(flow_file, Failure);
+        session.transfer(flow_file, Failure);
         return;
       }
       // Assuming reuse_mode_ == WARN_ON_REUSE || reuse_mode_ == RESET_REUSE
@@ -72,22 +72,22 @@ void RetryFlowFile::onTrigger(core::ProcessContext* context, core::ProcessSessio
   if (retry_property_value < maximum_retries_) {
     flow_file->setAttribute(retry_attribute_, std::to_string(retry_property_value + 1));
     if (penalize_retries_) {
-      session->penalize(flow_file);
+      session.penalize(flow_file);
     }
-    session->transfer(flow_file, Retry);
+    session.transfer(flow_file, Retry);
     return;
   }
   setRetriesExceededAttributesOnFlowFile(context, flow_file);
-  session->transfer(flow_file, RetriesExceeded);
+  session.transfer(flow_file, RetriesExceeded);
 }
 
-void RetryFlowFile::readDynamicPropertyKeys(core::ProcessContext* context) {
+void RetryFlowFile::readDynamicPropertyKeys(const core::ProcessContext& context) {
   exceeded_flowfile_attribute_keys_.clear();
-  const std::vector<std::string> dynamic_prop_keys = context->getDynamicPropertyKeys();
-  logger_->log_info("RetryFlowFile registering %d keys", dynamic_prop_keys.size());
+  const std::vector<std::string> dynamic_prop_keys = context.getDynamicPropertyKeys();
+  logger_->log_info("RetryFlowFile registering {} keys", dynamic_prop_keys.size());
   for (const auto& key : dynamic_prop_keys) {
     exceeded_flowfile_attribute_keys_.emplace_back(core::PropertyDefinitionBuilder<>::createProperty(key).withDescription("auto generated").supportsExpressionLanguage(true).build());
-    logger_->log_info("RetryFlowFile registered attribute '%s'", key);
+    logger_->log_info("RetryFlowFile registered attribute '{}'", key);
   }
 }
 
@@ -101,20 +101,20 @@ std::optional<uint64_t> RetryFlowFile::getRetryPropertyValue(const std::shared_p
   }
   catch(const utils::internal::ParseException&) {
     if (fail_on_non_numerical_overwrite_) {
-      logger_->log_info("Non-numerical retry property in RetryFlowFile (value: %s). Sending flowfile to failure...", value_as_string);
+      logger_->log_info("Non-numerical retry property in RetryFlowFile (value: {}). Sending flowfile to failure...", value_as_string);
       return std::nullopt;
     }
   }
-  logger_->log_info("Non-numerical retry property in RetryFlowFile: overwriting %s with 0.", value_as_string);
+  logger_->log_info("Non-numerical retry property in RetryFlowFile: overwriting {} with 0.", value_as_string);
   return 0;
 }
 
-void RetryFlowFile::setRetriesExceededAttributesOnFlowFile(core::ProcessContext* context, const std::shared_ptr<core::FlowFile>& flow_file) const {
+void RetryFlowFile::setRetriesExceededAttributesOnFlowFile(core::ProcessContext& context, const std::shared_ptr<core::FlowFile>& flow_file) const {
   for (const auto& attribute : exceeded_flowfile_attribute_keys_) {
     std::string value;
-    context->getDynamicProperty(attribute, value, flow_file);
+    context.getDynamicProperty(attribute, value, flow_file.get());
     flow_file->setAttribute(attribute.getName(), value);
-    logger_->log_info("Set attribute '%s' of flow file '%s' with value '%s'", attribute.getName(), flow_file->getUUIDStr(), value);
+    logger_->log_info("Set attribute '{}' of flow file '{}' with value '{}'", attribute.getName(), flow_file->getUUIDStr(), value);
   }
 }
 
