@@ -36,23 +36,22 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-RouteText::RouteText(std::string name, const utils::Identifier& uuid)
-    : core::Processor(std::move(name), uuid), logger_(core::logging::LoggerFactory<RouteText>::getLogger(uuid)) {}
+RouteText::RouteText(std::string_view name, const utils::Identifier& uuid)
+    : core::Processor(name, uuid), logger_(core::logging::LoggerFactory<RouteText>::getLogger(uuid)) {}
 
 void RouteText::initialize() {
   setSupportedProperties(Properties);
   setSupportedRelationships(Relationships);
 }
 
-void RouteText::onSchedule(core::ProcessContext* context, core::ProcessSessionFactory* /*sessionFactory*/) {
-  gsl_Expects(context);
-  routing_ = utils::parseEnumProperty<route_text::Routing>(*context, RoutingStrategy);
-  matching_ = utils::parseEnumProperty<route_text::Matching>(*context, MatchingStrategy);
-  context->getProperty(TrimWhitespace, trim_);
-  case_policy_ = context->getProperty<bool>(IgnoreCase).value_or(false) ? route_text::CasePolicy::IGNORE_CASE : route_text::CasePolicy::CASE_SENSITIVE;
-  group_regex_ = context->getProperty(GroupingRegex) | utils::map([] (const auto& str) {return utils::Regex(str);});
-  segmentation_ = utils::parseEnumProperty<route_text::Segmentation>(*context, SegmentationStrategy);
-  context->getProperty(GroupingFallbackValue, group_fallback_);
+void RouteText::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  routing_ = utils::parseEnumProperty<route_text::Routing>(context, RoutingStrategy);
+  matching_ = utils::parseEnumProperty<route_text::Matching>(context, MatchingStrategy);
+  context.getProperty(TrimWhitespace, trim_);
+  case_policy_ = context.getProperty<bool>(IgnoreCase).value_or(false) ? route_text::CasePolicy::IGNORE_CASE : route_text::CasePolicy::CASE_SENSITIVE;
+  group_regex_ = context.getProperty(GroupingRegex) | utils::transform([] (const auto& str) {return utils::Regex(str);});
+  segmentation_ = utils::parseEnumProperty<route_text::Segmentation>(context, SegmentationStrategy);
+  context.getProperty(GroupingFallbackValue, group_fallback_);
 }
 
 class RouteText::ReadCallback {
@@ -147,7 +146,7 @@ class RouteText::MatchingContext {
       return it->second;
     }
     std::string value;
-    if (!process_context_.getDynamicProperty(prop, value, flow_file_)) {
+    if (!process_context_.getDynamicProperty(prop, value, flow_file_.get())) {
       throw Exception(PROCESSOR_EXCEPTION, "Missing dynamic property: '" + prop.getName() + "'");
     }
     std::vector<utils::Regex::Mode> flags;
@@ -163,7 +162,7 @@ class RouteText::MatchingContext {
       return it->second;
     }
     std::string value;
-    if (!process_context_.getDynamicProperty(prop, value, flow_file_)) {
+    if (!process_context_.getDynamicProperty(prop, value, flow_file_.get())) {
       throw Exception(PROCESSOR_EXCEPTION, "Missing dynamic property: '" + prop.getName() + "'");
     }
     return (string_values_[prop.getName()] = value);
@@ -175,7 +174,7 @@ class RouteText::MatchingContext {
       return it->second.searcher_;
     }
     std::string value;
-    if (!process_context_.getDynamicProperty(prop, value, flow_file_)) {
+    if (!process_context_.getDynamicProperty(prop, value, flow_file_.get())) {
       throw Exception(PROCESSOR_EXCEPTION, "Missing dynamic property: '" + prop.getName() + "'");
     }
 
@@ -198,6 +197,7 @@ class RouteText::MatchingContext {
     OwningSearcher(OwningSearcher&&) = delete;
     OwningSearcher& operator=(const OwningSearcher&) = delete;
     OwningSearcher& operator=(OwningSearcher&&) = delete;
+    ~OwningSearcher() = default;
 
     std::string str_;
     utils::Searcher<std::string::const_iterator, CaseAwareHash, CaseAwareEq> searcher_;
@@ -217,17 +217,16 @@ struct Route {
 };
 }  // namespace
 
-void RouteText::onTrigger(core::ProcessContext *context, core::ProcessSession *session) {
-  gsl_Expects(context && session);
-  auto flow_file = session->get();
+void RouteText::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
+  auto flow_file = session.get();
   if (!flow_file) {
-    context->yield();
+    context.yield();
     return;
   }
 
   std::map<Route, std::string> flow_file_contents;
 
-  MatchingContext matching_context(*context, flow_file, case_policy_);
+  MatchingContext matching_context(context, flow_file, case_policy_);
 
   ReadCallback callback(segmentation_, flow_file->getSize(), [&] (Segment segment) {
     std::string_view original_value = segment.value_;
@@ -278,18 +277,18 @@ void RouteText::onTrigger(core::ProcessContext *context, core::ProcessSession *s
     }
     throw Exception(PROCESSOR_EXCEPTION, "Unknown routing strategy");
   });
-  session->read(flow_file, std::move(callback));
+  session.read(flow_file, std::move(callback));
 
   for (const auto& [route, content] : flow_file_contents) {
-    auto new_flow_file = session->create(flow_file);
+    auto new_flow_file = session.create(flow_file.get());
     if (route.group_name_) {
       new_flow_file->setAttribute(GROUP_ATTRIBUTE_NAME, route.group_name_.value());
     }
-    session->writeBuffer(new_flow_file, content);
-    session->transfer(new_flow_file, route.relationship_);
+    session.writeBuffer(new_flow_file, content);
+    session.transfer(new_flow_file, route.relationship_);
   }
 
-  session->transfer(flow_file, Original);
+  session.transfer(flow_file, Original);
 }
 
 std::string_view RouteText::preprocess(std::string_view str) const {
@@ -303,11 +302,35 @@ std::string_view RouteText::preprocess(std::string_view str) const {
     }
   }
   if (trim_) {
-    str = utils::StringUtils::trim(str);
+    str = utils::string::trim(str);
   }
   return str;
 }
 
+namespace {
+bool getDynamicPropertyWithOverrides(core::ProcessContext& context,
+    const core::Property &property,
+    std::string &value,
+    core::FlowFile& flow_file,
+    const std::map<std::string, std::string>& overrides) {
+  std::map<std::string, std::optional<std::string>> original_attributes;
+  for (const auto& [override_key, override_value] : overrides) {
+    original_attributes[override_key] = flow_file.getAttribute(override_key);
+    flow_file.setAttribute(override_key, override_value);
+  }
+  auto onExit = gsl::finally([&]{
+    for (const auto& attr : original_attributes) {
+      if (attr.second) {
+        flow_file.setAttribute(attr.first, attr.second.value());
+      } else {
+        flow_file.removeAttribute(attr.first);
+      }
+    }
+  });
+  return context.getDynamicProperty(property, value, &flow_file);
+}
+}  // namespace
+
 bool RouteText::matchSegment(MatchingContext& context, const Segment& segment, const core::Property& prop) const {
   switch (matching_) {
     case route_text::Matching::EXPRESSION: {
@@ -320,23 +343,23 @@ bool RouteText::matchSegment(MatchingContext& context, const Segment& segment, c
         variables["lineNo"] = std::to_string(segment.idx_);
       }
       std::string result;
-      if (context.process_context_.getDynamicProperty(prop, result, context.flow_file_, variables)) {
-        return utils::StringUtils::toBool(result).value_or(false);
+      if (getDynamicPropertyWithOverrides(context.process_context_, prop, result, *context.flow_file_, variables)) {
+        return utils::string::toBool(result).value_or(false);
       } else {
         throw Exception(PROCESSOR_EXCEPTION, "Missing dynamic property: '" + prop.getName() + "'");
       }
     }
     case route_text::Matching::STARTS_WITH: {
-      return utils::StringUtils::startsWith(segment.value_, context.getStringProperty(prop), case_policy_ == route_text::CasePolicy::CASE_SENSITIVE);
+      return utils::string::startsWith(segment.value_, context.getStringProperty(prop), case_policy_ == route_text::CasePolicy::CASE_SENSITIVE);
     }
     case route_text::Matching::ENDS_WITH: {
-      return utils::StringUtils::endsWith(segment.value_, context.getStringProperty(prop), case_policy_ == route_text::CasePolicy::CASE_SENSITIVE);
+      return utils::string::endsWith(segment.value_, context.getStringProperty(prop), case_policy_ == route_text::CasePolicy::CASE_SENSITIVE);
     }
     case route_text::Matching::CONTAINS: {
       return std::search(segment.value_.begin(), segment.value_.end(), context.getSearcher(prop)) != segment.value_.end();
     }
     case route_text::Matching::EQUALS: {
-      return utils::StringUtils::equals(segment.value_, context.getStringProperty(prop), case_policy_ == route_text::CasePolicy::CASE_SENSITIVE);
+      return utils::string::equals(segment.value_, context.getStringProperty(prop), case_policy_ == route_text::CasePolicy::CASE_SENSITIVE);
     }
     case route_text::Matching::CONTAINS_REGEX: {
       std::string segment_str = std::string(segment.value_);
@@ -377,7 +400,7 @@ void RouteText::onDynamicPropertyModified(const core::Property& /*orig_property*
     core::RelationshipDefinition rel{property_name, "Dynamic Route"};
     dynamic_relationships_[property_name] = rel;
     relationships.push_back(rel);
-    logger_->log_info("RouteText registered dynamic route '%s' with expression '%s'", property_name, prop.getValue().to_string());
+    logger_->log_info("RouteText registered dynamic route '{}' with expression '{}'", property_name, prop.getValue().to_string());
   }
 
   setSupportedRelationships(relationships);
