@@ -20,15 +20,17 @@
 #include <filesystem>
 #include <chrono>
 
-#include "TestBase.h"
-#include "SingleProcessorTestController.h"
-#include "Catch.h"
+#include "unit/TestBase.h"
+#include "unit/SingleProcessorTestController.h"
+#include "unit/Catch.h"
 #include "LogAttribute.h"
 #include "GetFile.h"
 #include "utils/file/FileUtils.h"
-#include "utils/TestUtils.h"
+#include "unit/TestUtils.h"
 #include "unit/ProvenanceTestHelper.h"
-#include "Utils.h"
+#ifdef WIN32
+#include "impl/expression/Expression.h"
+#endif
 
 using namespace std::literals::chrono_literals;
 
@@ -50,7 +52,7 @@ class GetFileTestController {
   std::filesystem::path input_file_name_;
   std::filesystem::path large_input_file_name_;
   std::filesystem::path hidden_input_file_name_;
-  std::shared_ptr<core::Processor> get_file_processor_;
+  core::Processor* get_file_processor_ = nullptr;
 };
 
 GetFileTestController::GetFileTestController()
@@ -71,9 +73,9 @@ GetFileTestController::GetFileTestController()
   auto log_attr = test_plan_->addProcessor("LogAttribute", "Log", core::Relationship("success", "description"), true);
   test_plan_->setProperty(log_attr, minifi::processors::LogAttribute::FlowFilesToLog, "0");
 
-  utils::putFileToDir(temp_dir_, input_file_name_, "The quick brown fox jumps over the lazy dog\n");
-  utils::putFileToDir(temp_dir_, large_input_file_name_, "The quick brown fox jumps over the lazy dog who is 2 legit to quit\n");
-  utils::putFileToDir(temp_dir_, hidden_input_file_name_, "But noone has ever seen it\n");
+  minifi::test::utils::putFileToDir(temp_dir_, input_file_name_, "The quick brown fox jumps over the lazy dog\n");
+  minifi::test::utils::putFileToDir(temp_dir_, large_input_file_name_, "The quick brown fox jumps over the lazy dog who is 2 legit to quit\n");
+  minifi::test::utils::putFileToDir(temp_dir_, hidden_input_file_name_, "But noone has ever seen it\n");
 
 #ifdef WIN32
   const auto hide_file_err = minifi::test::utils::hide_file(getFullPath(hidden_input_file_name_));
@@ -171,7 +173,7 @@ TEST_CASE("Check if subdirectories are ignored or not if Recurse property is set
 
   auto subdir_path = test_controller.getFullPath("subdir");
   utils::file::FileUtils::create_dir(subdir_path);
-  utils::putFileToDir(subdir_path, "subfile.txt", "Some content in a subfile\n");
+  minifi::test::utils::putFileToDir(subdir_path, "subfile.txt", "Some content in a subfile\n");
 
   SECTION("File in subdirectory is ignored when Recurse property set to false")  {
     test_controller.setProperty(minifi::processors::GetFile::Recurse, "false");
@@ -268,14 +270,14 @@ TEST_CASE("Test if GetFile honors PollInterval property when triggered multiple
 TEST_CASE("GetFile sets attributes correctly") {
   using minifi::processors::GetFile;
 
-  const auto get_file = std::make_shared<GetFile>("GetFile");
   LogTestController::getInstance().setTrace<GetFile>();
-  minifi::test::SingleProcessorTestController test_controller(get_file);
+  minifi::test::SingleProcessorTestController test_controller(std::make_unique<GetFile>("GetFile"));
+  const auto get_file = test_controller.getProcessor();
   std::filesystem::path dir = test_controller.createTempDirectory();
   get_file->setProperty(GetFile::Directory, dir.string());
   SECTION("File in subdirectory of input directory") {
     std::filesystem::create_directories(dir / "a" / "b");
-    utils::putFileToDir(dir / "a" / "b", "alpha.txt", "The quick brown fox jumps over the lazy dog\n");
+    minifi::test::utils::putFileToDir(dir / "a" / "b", "alpha.txt", "The quick brown fox jumps over the lazy dog\n");
     auto result = test_controller.trigger();
     REQUIRE((result.contains(GetFile::Success) && result.at(GetFile::Success).size() == 1));
     auto flow_file = result.at(GetFile::Success)[0];
@@ -284,7 +286,7 @@ TEST_CASE("GetFile sets attributes correctly") {
     CHECK(flow_file->getAttribute(minifi::core::SpecialFlowAttribute::FILENAME) == "alpha.txt");
   }
   SECTION("File directly in input directory") {
-    utils::putFileToDir(dir, "beta.txt", "The quick brown fox jumps over the lazy dog\n");
+    minifi::test::utils::putFileToDir(dir, "beta.txt", "The quick brown fox jumps over the lazy dog\n");
     auto result = test_controller.trigger();
     REQUIRE((result.contains(GetFile::Success) && result.at(GetFile::Success).size() == 1));
     auto flow_file = result.at(GetFile::Success)[0];
@@ -293,3 +295,29 @@ TEST_CASE("GetFile sets attributes correctly") {
     CHECK(flow_file->getAttribute(minifi::core::SpecialFlowAttribute::FILENAME) == "beta.txt");
   }
 }
+
+TEST_CASE("GetFile can use expression language in Directory property") {
+#ifdef WIN32
+  minifi::expression::dateSetInstall(TZ_DATA_DIR);
+#endif
+  using minifi::processors::GetFile;
+  LogTestController::getInstance().setTrace<GetFile>();
+
+  minifi::test::SingleProcessorTestController test_controller(std::make_unique<GetFile>("GetFile"));
+  const auto get_file = test_controller.getProcessor();
+
+  std::filesystem::path base_dir = test_controller.createTempDirectory();
+  auto date_str = date::format("%Y-%m-%d", std::chrono::system_clock::now());
+  auto dir = base_dir/ date_str;
+  std::filesystem::create_directories(dir);
+  get_file->setProperty(GetFile::Directory, base_dir.string() + "/${now():format('%Y-%m-%d')}");
+  minifi::test::utils::putFileToDir(dir, "testfile.txt", "The quick brown fox jumps over the lazy dog\n");
+
+  auto result = test_controller.trigger();
+
+  REQUIRE((result.contains(GetFile::Success) && result.at(GetFile::Success).size() == 1));
+  auto flow_file = result.at(GetFile::Success)[0];
+  CHECK(flow_file->getAttribute(minifi::core::SpecialFlowAttribute::PATH) == (std::filesystem::path(".") / "").string());
+  CHECK(flow_file->getAttribute(minifi::core::SpecialFlowAttribute::ABSOLUTE_PATH) == (dir / "").string());
+  CHECK(flow_file->getAttribute(minifi::core::SpecialFlowAttribute::FILENAME) == "testfile.txt");
+}
