@@ -17,8 +17,8 @@
  */
 
 #include "FlowFileRecord.h"
-#include "TestBase.h"
-#include "Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "processors/RouteText.h"
 
 namespace processors = minifi::processors;
@@ -54,7 +54,7 @@ struct RouteTextController : public TestController {
 
   RouteTextController() {
     plan_ = createPlan();
-    plan_->addProcessor(proc_, "RouteText");
+    proc_ = plan_->addProcessor(std::make_unique<processors::RouteText>("RouteText"), "RouteText");
     input_ = plan_->addConnection(nullptr, {"success", ""}, proc_);
     createOutput(processors::RouteText::Original);
     createOutput(processors::RouteText::Unmatched);
@@ -124,7 +124,7 @@ struct RouteTextController : public TestController {
   }
 
   std::shared_ptr<TestPlan> plan_ = createPlan();
-  std::shared_ptr<core::Processor> proc_ = std::make_shared<processors::RouteText>("RouteText");
+  core::Processor* proc_ = nullptr;
   std::map<std::string, minifi::Connection*> outputs_;
   minifi::Connection* input_;
 };
