@@ -21,7 +21,7 @@
 #include <algorithm>
 
 #include "date/date.h"
-#include "spdlog/spdlog.h"  // TODO(szaszm): make fmt directly available
+#include "fmt/format.h"
 #include "utils/GeneralUtils.h"
 #include "utils/OptionalUtils.h"
 #include "core/ProcessContext.h"
@@ -32,8 +32,8 @@ namespace org::apache::nifi::minifi::extensions::systemd {
 
 namespace chr = std::chrono;
 
-ConsumeJournald::ConsumeJournald(std::string name, const utils::Identifier &id, std::unique_ptr<libwrapper::LibWrapper>&& libwrapper)
-    :core::Processor{std::move(name), id}, libwrapper_{std::move(libwrapper)}
+ConsumeJournald::ConsumeJournald(std::string_view name, const utils::Identifier &id, std::unique_ptr<libwrapper::LibWrapper>&& libwrapper)
+    :core::Processor{name, id}, libwrapper_{std::move(libwrapper)}
 {}
 
 void ConsumeJournald::initialize() {
@@ -52,8 +52,8 @@ void ConsumeJournald::notifyStop() {
   worker_ = nullptr;
 }
 
-void ConsumeJournald::onSchedule(core::ProcessContext* const context, core::ProcessSessionFactory* const sessionFactory) {
-  gsl_Expects(context && sessionFactory && !running_ && worker_);
+void ConsumeJournald::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
+  gsl_Expects(!running_ && worker_);
   using JournalTypeEnum = systemd::JournalType;
 
   const auto parse_payload_format = [](const std::string& property_value) -> std::optional<systemd::PayloadFormat> {
@@ -67,24 +67,24 @@ void ConsumeJournald::onSchedule(core::ProcessContext* const context, core::Proc
     if (property_value == JOURNAL_TYPE_BOTH) return JournalTypeEnum::Both;
     return std::nullopt;
   };
-  batch_size_ = context->getProperty<size_t>(BatchSize).value();
-  payload_format_ = (context->getProperty(PayloadFormat) | utils::flatMap(parse_payload_format)
+  batch_size_ = context.getProperty<size_t>(BatchSize).value();
+  payload_format_ = (context.getProperty(PayloadFormat) | utils::andThen(parse_payload_format)
       | utils::orElse([]{ throw Exception{ExceptionType::PROCESSOR_EXCEPTION, "invalid payload format"}; }))
       .value();
-  include_timestamp_ = context->getProperty<bool>(IncludeTimestamp).value();
-  const auto journal_type = (context->getProperty(JournalType) | utils::flatMap(parse_journal_type)
+  include_timestamp_ = context.getProperty<bool>(IncludeTimestamp).value();
+  const auto journal_type = (context.getProperty(JournalType) | utils::andThen(parse_journal_type)
       | utils::orElse([]{ throw Exception{ExceptionType::PROCESSOR_EXCEPTION, "invalid journal type"}; }))
       .value();
-  const auto process_old_messages = context->getProperty<bool>(ProcessOldMessages).value_or(false);
+  const auto process_old_messages = context.getProperty<bool>(ProcessOldMessages).value_or(false);
   timestamp_format_ = [&context] {
-    auto tf_prop = (context->getProperty(TimestampFormat)
+    auto tf_prop = (context.getProperty(TimestampFormat)
         | utils::orElse([]{ throw Exception{ExceptionType::PROCESSOR_EXCEPTION, "invalid timestamp format" }; }))
         .value();
     if (tf_prop == "ISO" || tf_prop == "ISO 8601" || tf_prop == "ISO8601") return std::string{"%FT%T%Ez"};
     return tf_prop;
   }();
 
-  state_manager_ = context->getStateManager();
+  state_manager_ = context.getStateManager();
   // All journal-related API calls are thread-agnostic, meaning they need to be called from the same thread. In our environment,
   // where a processor can easily be scheduled on different threads, we ensure this by executing all library calls on a dedicated
   // worker thread. This is why all such operations are dispatched to a thread and immediately waited for in the initiating thread.
@@ -93,14 +93,14 @@ void ConsumeJournald::onSchedule(core::ProcessContext* const context, core::Proc
     return process_old_messages ? journal.seekHead() : journal.seekTail();
   };
   worker_->enqueue([this, &seek_default] {
-    const auto cursor = state_manager_->get() | utils::map([](std::unordered_map<std::string, std::string>&& m) { return m.at(CURSOR_KEY); });
+    const auto cursor = state_manager_->get() | utils::transform([](std::unordered_map<std::string, std::string>&& m) { return m.at(CURSOR_KEY); });
     if (!cursor) {
       seek_default(*journal_);
     } else {
       const auto ret = journal_->seekCursor(cursor->c_str());
       if (ret < 0) {
         const auto error_message = std::generic_category().default_error_condition(-ret).message();
-        logger_->log_warn("Failed to seek to cursor: %s. Seeking to tail or head (depending on Process Old Messages property) instead. cursor=\"%s\"", error_message, *cursor);
+        logger_->log_warn("Failed to seek to cursor: {}. Seeking to tail or head (depending on Process Old Messages property) instead. cursor=\"{}\"", error_message, *cursor);
         seek_default(*journal_);
       }
     }
@@ -108,8 +108,7 @@ void ConsumeJournald::onSchedule(core::ProcessContext* const context, core::Proc
   running_ = true;
 }
 
-void ConsumeJournald::onTrigger(core::ProcessContext* const context, core::ProcessSession* const session) {
-  gsl_Expects(context && session);
+void ConsumeJournald::onTrigger(core::ProcessContext&, core::ProcessSession& session) {
   if (!running_.load(std::memory_order_acquire)) return;
   auto cursor_and_messages = getCursorAndMessageBatch().get();
   auto messages = std::move(cursor_and_messages.second);
@@ -119,17 +118,17 @@ void ConsumeJournald::onTrigger(core::ProcessContext* const context, core::Proce
   }
 
   for (auto& msg: messages) {
-    const auto flow_file = session->create();
-    if (payload_format_ == systemd::PayloadFormat::Syslog) session->writeBuffer(flow_file, gsl::make_span(formatSyslogMessage(msg)));
+    const auto flow_file = session.create();
+    if (payload_format_ == systemd::PayloadFormat::Syslog) session.writeBuffer(flow_file, gsl::make_span(formatSyslogMessage(msg)));
     for (auto& field: msg.fields) {
       if (field.name == "MESSAGE" && payload_format_ == systemd::PayloadFormat::Raw) {
-        session->writeBuffer(flow_file, gsl::make_span(field.value));
+        session.writeBuffer(flow_file, gsl::make_span(field.value));
       } else {
         flow_file->setAttribute(std::move(field.name), std::move(field.value));
       }
     }
     if (include_timestamp_) flow_file->setAttribute("timestamp", date::format(timestamp_format_, chr::floor<chr::microseconds>(msg.timestamp)));
-    session->transfer(flow_file, Success);
+    session.transfer(flow_file, Success);
   }
   state_manager_->set({{"cursor", std::move(cursor_and_messages.first)}});
 }
@@ -147,7 +146,7 @@ std::optional<std::span<const char>> ConsumeJournald::enumerateJournalEntry(libw
 }
 
 std::optional<ConsumeJournald::journal_field> ConsumeJournald::getNextField(libwrapper::Journal& journal) {
-  return enumerateJournalEntry(journal) | utils::map([](std::span<const char> field) {
+  return enumerateJournalEntry(journal) | utils::transform([](std::span<const char> field) {
     const auto eq_pos = std::find(std::begin(field), std::end(field), '=');
     gsl_Ensures(eq_pos != std::end(field) && "field string must contain an equals sign");
     const auto eq_idx = gsl::narrow<size_t>(eq_pos - std::begin(field));
@@ -205,12 +204,12 @@ std::string ConsumeJournald::formatSyslogMessage(const journal_message& msg) con
 
   const auto pid_string = utils::optional_from_ptr(syslog_pid)
       | utils::orElse([&] { return utils::optional_from_ptr(systemd_pid); })
-      | utils::map([](const std::string* const pid) { return fmt::format("[{}]", *pid); });
+      | utils::transform([](const std::string* const pid) { return fmt::format("[{}]", *pid); });
 
   return fmt::format("{} {} {}{}: {}",
       date::format(timestamp_format_, chr::floor<chr::microseconds>(msg.timestamp)),
-      (utils::optional_from_ptr(systemd_hostname) | utils::map(utils::dereference)).value_or("unknown_host"),
-      (utils::optional_from_ptr(syslog_identifier) | utils::map(utils::dereference)).value_or("unknown_process"),
+      (utils::optional_from_ptr(systemd_hostname) | utils::transform(utils::dereference)).value_or("unknown_host"),
+      (utils::optional_from_ptr(syslog_identifier) | utils::transform(utils::dereference)).value_or("unknown_process"),
       pid_string.value_or(std::string{}),
       *message);
 }
