@@ -33,7 +33,7 @@
 
 namespace org::apache::nifi::minifi::processors {
 
-#define LOG_LAST_ERROR(func) logger_->log_error("!"#func" error %x", GetLastError())
+#define LOG_LAST_ERROR(func) logger_->log_error("!"#func" error {:#x}", GetLastError())
 
 class Bookmark {
  public:
