@@ -31,8 +31,8 @@ enum class PortType {
 
 class Port final : public ForwardingNode {
  public:
-  Port(std::string name, const utils::Identifier& uuid, PortType port_type) : ForwardingNode(std::move(name), uuid, core::logging::LoggerFactory<Port>::getLogger(uuid)), port_type_(port_type) {}
-  Port(std::string name, PortType port_type) : ForwardingNode(std::move(name), core::logging::LoggerFactory<Port>::getLogger()), port_type_(port_type) {}
+  Port(std::string_view name, const utils::Identifier& uuid, PortType port_type) : ForwardingNode(name, uuid, core::logging::LoggerFactory<Port>::getLogger(uuid)), port_type_(port_type) {}
+  Port(std::string_view name, PortType port_type) : ForwardingNode(name, core::logging::LoggerFactory<Port>::getLogger()), port_type_(port_type) {}
   PortType getPortType() const {
     return port_type_;
   }
