@@ -19,18 +19,31 @@
 #pragma once
 
 #include <memory>
+#include <utility>
+#include <map>
 #include "ResourceClaim.h"
 #include "io/BaseStream.h"
 
 namespace org::apache::nifi::minifi::core {
 
+class StreamAppendLock;
+class ContentRepository;
+
 class ContentSession {
+  struct AppendState {
+    std::shared_ptr<io::BaseStream> stream;
+    size_t base_size;
+    std::unique_ptr<StreamAppendLock> lock;
+  };
+
  public:
+  explicit ContentSession(std::shared_ptr<ContentRepository> repository): repository_(std::move(repository)) {}
+
   virtual std::shared_ptr<ResourceClaim> create() = 0;
 
   virtual std::shared_ptr<io::BaseStream> write(const std::shared_ptr<ResourceClaim>& resource_id) = 0;
 
-  virtual std::shared_ptr<io::BaseStream> append(const std::shared_ptr<ResourceClaim>& resource_id) = 0;
+  virtual std::shared_ptr<io::BaseStream> append(const std::shared_ptr<ResourceClaim>& resource_id, size_t offset, const std::function<void(const std::shared_ptr<ResourceClaim>&)>& on_copy);
 
   virtual std::shared_ptr<io::BaseStream> read(const std::shared_ptr<ResourceClaim>& resource_id) = 0;
 
@@ -39,6 +52,13 @@ class ContentSession {
   virtual void rollback() = 0;
 
   virtual ~ContentSession() = default;
+
+ protected:
+  virtual std::shared_ptr<io::BaseStream> append(const std::shared_ptr<ResourceClaim>& resource_id) = 0;
+
+  // contains aux data on resources that have been appended to
+  std::map<std::shared_ptr<ResourceClaim>, AppendState> append_state_;
+  std::shared_ptr<ContentRepository> repository_;
 };
 
 }  // namespace org::apache::nifi::minifi::core
