@@ -41,6 +41,7 @@
 #include "core/state/nodes/FlowInformation.h"
 #include "utils/file/FileSystem.h"
 #include "utils/ChecksumCalculator.h"
+#include "ParameterContext.h"
 
 namespace org::apache::nifi::minifi::core {
 
@@ -58,7 +59,7 @@ struct ConfigurationContext {
   std::shared_ptr<Configure> configuration;
   std::optional<std::filesystem::path> path{std::nullopt};
   std::shared_ptr<utils::file::FileSystem> filesystem{std::make_shared<utils::file::FileSystem>()};
-  std::optional<utils::crypto::EncryptionProvider> sensitive_properties_encryptor{std::nullopt};
+  std::optional<utils::crypto::EncryptionProvider> sensitive_values_encryptor{std::nullopt};
 };
 
 enum class FlowSerializationType { Json, NifiJson, Yaml };
@@ -133,21 +134,20 @@ class FlowConfiguration : public CoreComponent {
 
   utils::ChecksumCalculator& getChecksumCalculator() { return checksum_calculator_; }
 
+  const std::unordered_map<std::string, gsl::not_null<std::unique_ptr<ParameterContext>>>& getParameterContexts() const {
+    return parameter_contexts_;
+  }
+
  protected:
-  // service provider reference.
-  std::shared_ptr<core::controller::StandardControllerServiceProvider> service_provider_;
-  // based, shared controller service map.
-  std::shared_ptr<core::controller::ControllerServiceMap> controller_services_;
-  // configuration path
+  std::unordered_map<std::string, gsl::not_null<std::unique_ptr<ParameterContext>>> parameter_contexts_;
   std::optional<std::filesystem::path> config_path_;
-  // flow file repo
   std::shared_ptr<core::Repository> flow_file_repo_;
-  // content repository.
   std::shared_ptr<core::ContentRepository> content_repo_;
   std::shared_ptr<Configure> configuration_;
+  std::shared_ptr<core::controller::StandardControllerServiceProvider> service_provider_;
   std::shared_ptr<state::response::FlowVersion> flow_version_;
   std::shared_ptr<utils::file::FileSystem> filesystem_;
-  utils::crypto::EncryptionProvider sensitive_properties_encryptor_;
+  utils::crypto::EncryptionProvider sensitive_values_encryptor_;
   utils::ChecksumCalculator checksum_calculator_;
 
  private:
