@@ -37,11 +37,12 @@
 #include "Port.h"
 #include "core/logging/Logger.h"
 #include "controller/ControllerServiceNode.h"
-#include "controller/ControllerServiceMap.h"
+#include "controller/ControllerServiceNodeMap.h"
 #include "utils/Id.h"
-#include "utils/BaseHTTPClient.h"
+#include "http/BaseHTTPClient.h"
 #include "utils/CallBackTimer.h"
 #include "range/v3/algorithm/find_if.hpp"
+#include "core/ParameterContext.h"
 
 struct ProcessGroupTestAccessor;
 
@@ -120,7 +121,7 @@ class ProcessGroup : public CoreComponent {
   void setHttpProxyPort(int port) {
     proxy_.port = port;
   }
-  utils::HTTPProxy getHTTPProxy() {
+  http::HTTPProxy getHTTPProxy() {
     return proxy_;
   }
   // Set Processor yield period in MilliSecond
@@ -198,12 +199,7 @@ class ProcessGroup : public CoreComponent {
    */
   void addControllerService(const std::string &nodeId, const std::shared_ptr<core::controller::ControllerServiceNode> &node);
 
-  /**
-   * Find controllerservice node will search child groups until the nodeId is found.
-   * @param node node identifier
-   * @return controller service node, if it exists.
-   */
-  std::shared_ptr<core::controller::ControllerServiceNode> findControllerService(const std::string &nodeId) const;
+  core::controller::ControllerServiceNode* findControllerService(const std::string &nodeId, Traverse traverse = Traverse::ExcludeChildren) const;
 
   std::vector<const core::controller::ControllerServiceNode*> getAllControllerServices() const;
 
@@ -222,6 +218,13 @@ class ProcessGroup : public CoreComponent {
 
   void verify() const;
 
+  void setParameterContext(ParameterContext* parameter_context);
+  ParameterContext* getParameterContext() const;
+
+  const std::set<std::unique_ptr<ProcessGroup>>& getChildProcessGroups() const {
+    return child_process_groups_;
+  }
+
  protected:
   void startProcessingProcessors(TimerDrivenSchedulingAgent& timeScheduler, EventDrivenSchedulingAgent& eventScheduler, CronDrivenSchedulingAgent& cronScheduler);
 
@@ -249,12 +252,14 @@ class ProcessGroup : public CoreComponent {
   // Transmitting
   std::atomic<bool> transmitting_;
   // http proxy
-  utils::HTTPProxy proxy_;
+  http::HTTPProxy proxy_;
   std::string transport_protocol_;
 
   // controller services
 
-  core::controller::ControllerServiceMap controller_service_map_;
+  core::controller::ControllerServiceNodeMap controller_service_map_;
+
+  ParameterContext* parameter_context_ = nullptr;
 
  private:
   static Port* findPortById(const std::set<Port*>& ports, const utils::Identifier& uuid);
