@@ -52,10 +52,16 @@ class ProcessorMetrics : public state::response::ResponseNode {
   std::chrono::milliseconds getAverageSessionCommitRuntime() const;
   std::chrono::milliseconds getLastSessionCommitRuntime() const;
   void addLastSessionCommitRuntime(std::chrono::milliseconds runtime);
+  std::optional<size_t> getTransferredFlowFilesToRelationshipCount(const std::string& relationship) const;
 
-  std::atomic<size_t> iterations{0};
+  std::atomic<size_t> invocations{0};
+  std::atomic<size_t> incoming_flow_files{0};
   std::atomic<size_t> transferred_flow_files{0};
+  std::atomic<uint64_t> incoming_bytes{0};
   std::atomic<uint64_t> transferred_bytes{0};
+  std::atomic<uint64_t> bytes_read{0};
+  std::atomic<uint64_t> bytes_written{0};
+  std::atomic<uint64_t> processing_nanos{0};
 
  protected:
   template<typename ValueType>
@@ -78,9 +84,9 @@ class ProcessorMetrics : public state::response::ResponseNode {
   };
 
   [[nodiscard]] std::unordered_map<std::string, std::string> getCommonLabels() const;
-  static const uint8_t STORED_ON_TRIGGER_RUNTIME_COUNT = 10;
+  static constexpr uint8_t STORED_ON_TRIGGER_RUNTIME_COUNT = 10;
 
-  std::mutex transferred_relationships_mutex_;
+  mutable std::mutex transferred_relationships_mutex_;
   std::unordered_map<std::string, size_t> transferred_relationships_;
   const Processor& source_processor_;
   Averager<std::chrono::milliseconds> on_trigger_runtime_averager_;
