@@ -66,14 +66,14 @@ class ControllerService : public ConfigurableComponent, public Connectable {
     current_state_ = DISABLED;
   }
 
-  explicit ControllerService(std::string name, const utils::Identifier &uuid)
-      : Connectable(std::move(name), uuid),
+  explicit ControllerService(std::string_view name, const utils::Identifier &uuid)
+      : Connectable(name, uuid),
         configuration_(std::make_shared<Configure>()) {
     current_state_ = DISABLED;
   }
 
-  explicit ControllerService(std::string name)
-      : Connectable(std::move(name)),
+  explicit ControllerService(std::string_view name)
+      : Connectable(name),
         configuration_(std::make_shared<Configure>()) {
     current_state_ = DISABLED;
   }
