@@ -29,7 +29,7 @@
 #include "ControllerServiceLookup.h"
 #include "core/ConfigurableComponent.h"
 #include "ControllerServiceNode.h"
-#include "ControllerServiceMap.h"
+#include "ControllerServiceNodeMap.h"
 #include "core/ClassLoader.h"
 #include "utils/Monitors.h"
 
@@ -38,16 +38,16 @@ namespace org::apache::nifi::minifi::core::controller {
 class ControllerServiceProvider : public CoreComponent, public ConfigurableComponent, public ControllerServiceLookup {
  public:
   explicit ControllerServiceProvider(std::string_view name)
-      : CoreComponent(name) {
-    controller_map_ = std::make_shared<ControllerServiceMap>();
+      : CoreComponent(name),
+        controller_map_{std::make_unique<ControllerServiceNodeMap>()} {
   }
 
-  explicit ControllerServiceProvider(std::shared_ptr<ControllerServiceMap> services)
+  explicit ControllerServiceProvider(std::unique_ptr<ControllerServiceNodeMap> services)
       : CoreComponent(core::className<ControllerServiceProvider>()),
         controller_map_(std::move(services)) {
   }
 
-  explicit ControllerServiceProvider(std::string_view name, std::shared_ptr<ControllerServiceMap> services)
+  explicit ControllerServiceProvider(std::string_view name, std::unique_ptr<ControllerServiceNodeMap> services)
       : CoreComponent(name),
         controller_map_(std::move(services)) {
   }
@@ -58,52 +58,31 @@ class ControllerServiceProvider : public CoreComponent, public ConfigurableCompo
   ControllerServiceProvider& operator=(const ControllerServiceProvider &other) = delete;
   ControllerServiceProvider& operator=(ControllerServiceProvider &&other) = delete;
 
-  virtual ~ControllerServiceProvider() = default;
+  ~ControllerServiceProvider() override = default;
 
-  /**
-   * Creates a controller service node wrapping the controller service
-   *
-   * @param type service type.
-   * @param id controller service identifier.
-   * @return shared pointer to the controller service node.
-   */
   virtual std::shared_ptr<ControllerServiceNode> createControllerService(const std::string &type, const std::string &longType, const std::string &id, bool firstTimeAdded) = 0;
 
-  /**
-   * Gets a controller service node wrapping the controller service
-   *
-   * @param type service type.
-   * @param id controller service identifier.
-   * @return shared pointer to the controller service node.
-   */
-  virtual std::shared_ptr<ControllerServiceNode> getControllerServiceNode(const std::string &id) const {
-    return controller_map_->getControllerServiceNode(id);
+  virtual ControllerServiceNode* getControllerServiceNode(const std::string &id) const {
+    return controller_map_->get(id);
+  }
+
+  virtual ControllerServiceNode* getControllerServiceNode(const std::string &id, const utils::Identifier &processor_or_controller_uuid) const {
+    return controller_map_->get(id, processor_or_controller_uuid);
   }
 
-  /**
-   * Removes all controller services.
-   */
   virtual void clearControllerServices() = 0;
 
-  /**
-   * Gets a list of all controller services.
-   */
   virtual std::vector<std::shared_ptr<core::controller::ControllerServiceNode>> getAllControllerServices() {
     return controller_map_->getAllControllerServices();
   }
 
-  /**
-   * Gets the controller service for the provided identifier
-   * @param identifier service identifier.
-   */
   std::shared_ptr<ControllerService> getControllerService(const std::string &identifier) const override;
+  std::shared_ptr<ControllerService> getControllerService(const std::string &identifier, const utils::Identifier &processor_uuid) const override;
+
+  void putControllerServiceNode(const std::string& identifier, const std::shared_ptr<ControllerServiceNode>& controller_service_node, ProcessGroup* process_group);
 
-  /**
-   * Determines if Controller service is enabled.
-   * @param identifier service identifier.
-   */
   bool isControllerServiceEnabled(const std::string &identifier) override {
-    std::shared_ptr<ControllerServiceNode> node = getControllerServiceNode(identifier);
+    const ControllerServiceNode* const node = getControllerServiceNode(identifier);
     if (nullptr != node) {
       return linkedServicesAre(ENABLED, node);
     } else {
@@ -111,12 +90,8 @@ class ControllerServiceProvider : public CoreComponent, public ConfigurableCompo
     }
   }
 
-  /**
-   * Determines if Controller service is being enabled.
-   * @param identifier service identifier.
-   */
   bool isControllerServiceEnabling(const std::string &identifier) override {
-    std::shared_ptr<ControllerServiceNode> node = getControllerServiceNode(identifier);
+    const ControllerServiceNode* const node = getControllerServiceNode(identifier);
     if (nullptr != node) {
       return linkedServicesAre(ENABLING, node);
     } else {
@@ -146,10 +121,7 @@ class ControllerServiceProvider : public CoreComponent, public ConfigurableCompo
   }
 
  protected:
-  /**
-   * verifies that linked services match the provided state.
-   */
-  inline bool linkedServicesAre(ControllerServiceState state, const std::shared_ptr<ControllerServiceNode> &node) {
+  inline bool linkedServicesAre(ControllerServiceState state, const ControllerServiceNode* node) {
     if (node->getControllerServiceImplementation()->getState() == state) {
       for (auto child_service : node->getLinkedControllerServices()) {
         if (child_service->getControllerServiceImplementation()->getState() != state) {
@@ -166,18 +138,14 @@ class ControllerServiceProvider : public CoreComponent, public ConfigurableCompo
     return true;
   }
 
-  /**
-   * Finds linked components
-   * @param referenceNode reference node from whcih we will find linked references.
-   */
-  std::vector<std::shared_ptr<core::controller::ControllerServiceNode>> findLinkedComponents(std::shared_ptr<core::controller::ControllerServiceNode> &referenceNode) {
-    std::vector<std::shared_ptr<core::controller::ControllerServiceNode>> references;
+  std::vector<core::controller::ControllerServiceNode*> findLinkedComponents(core::controller::ControllerServiceNode* referenceNode) {
+    std::vector<core::controller::ControllerServiceNode*> references;
 
-    for (std::shared_ptr<core::controller::ControllerServiceNode> linked_node : referenceNode->getLinkedControllerServices()) {
+    for (auto* linked_node : referenceNode->getLinkedControllerServices()) {
       references.push_back(linked_node);
-      std::vector<std::shared_ptr<core::controller::ControllerServiceNode>> linked_references = findLinkedComponents(linked_node);
+      std::vector<core::controller::ControllerServiceNode*> linked_references = findLinkedComponents(linked_node);
 
-      auto removal_predicate = [&linked_references](std::shared_ptr<core::controller::ControllerServiceNode> key) ->bool {
+      auto removal_predicate = [&linked_references](core::controller::ControllerServiceNode* key) ->bool {
         return std::find(linked_references.begin(), linked_references.end(), key) != linked_references.end();
       };
 
@@ -188,7 +156,7 @@ class ControllerServiceProvider : public CoreComponent, public ConfigurableCompo
     return references;
   }
 
-  std::shared_ptr<ControllerServiceMap> controller_map_;
+  std::unique_ptr<ControllerServiceNodeMap> controller_map_;
 };
 
 }  // namespace org::apache::nifi::minifi::core::controller
