@@ -19,6 +19,7 @@
 
 #include <memory>
 #include <string>
+#include <vector>
 
 #include "MetricsPublisher.h"
 #include "utils/gsl.h"
@@ -27,6 +28,7 @@ namespace org::apache::nifi::minifi::state {
 
 gsl::not_null<std::unique_ptr<MetricsPublisher>> createMetricsPublisher(const std::string& name, const std::shared_ptr<Configure>& configuration,
   const std::shared_ptr<state::response::ResponseNodeLoader>& response_node_loader);
-std::unique_ptr<MetricsPublisher> createMetricsPublisher(const std::shared_ptr<Configure>& configuration, const std::shared_ptr<state::response::ResponseNodeLoader>& response_node_loader);
+std::vector<gsl::not_null<std::unique_ptr<MetricsPublisher>>> createMetricsPublishers(
+  const std::shared_ptr<Configure>& configuration, const std::shared_ptr<state::response::ResponseNodeLoader>& response_node_loader);
 
 }  // namespace org::apache::nifi::minifi::state
