@@ -27,6 +27,8 @@
 #include <cassert>
 
 #ifdef WIN32
+// ignore the warning about inheriting via dominance from CRCStreamBase
+#pragma warning(disable : 4250)
 #include <winsock2.h>
 
 #else
