@@ -77,6 +77,11 @@ class Configuration : public Properties {
   static constexpr const char *nifi_flowfile_repository_rocksdb_compaction_period = "nifi.flowfile.repository.rocksdb.compaction.period";
   static constexpr const char *nifi_dbcontent_repository_rocksdb_compaction_period = "nifi.database.content.repository.rocksdb.compaction.period";
   static constexpr const char *nifi_dbcontent_repository_purge_period = "nifi.database.content.repository.purge.period";
+  static constexpr const char *nifi_content_repository_rocksdb_use_synchronous_writes = "nifi.content.repository.rocksdb.use.synchronous.writes";
+  static constexpr const char *nifi_content_repository_rocksdb_read_verify_checksums = "nifi.content.repository.rocksdb.read.verify.checksums";
+  static constexpr const char *nifi_flowfile_repository_rocksdb_read_verify_checksums = "nifi.flowfile.repository.rocksdb.read.verify.checksums";
+  static constexpr const char *nifi_provenance_repository_rocksdb_read_verify_checksums = "nifi.provenance.repository.rocksdb.read.verify.checksums";
+  static constexpr const char *nifi_rocksdb_state_storage_read_verify_checksums = "nifi.rocksdb.state.storage.read.verify.checksums";
 
   static constexpr const char *nifi_remote_input_secure = "nifi.remote.input.secure";
   static constexpr const char *nifi_security_need_ClientAuth = "nifi.security.need.ClientAuth";
@@ -107,13 +112,9 @@ class Configuration : public Properties {
   static constexpr const char *nifi_c2_flow_url = "nifi.c2.flow.url";
   static constexpr const char *nifi_c2_flow_base_url = "nifi.c2.flow.base.url";
   static constexpr const char *nifi_c2_full_heartbeat = "nifi.c2.full.heartbeat";
-  static constexpr const char *nifi_c2_coap_connector_service = "nifi.c2.coap.connector.service";
   static constexpr const char *nifi_c2_agent_heartbeat_period = "nifi.c2.agent.heartbeat.period";
   static constexpr const char *nifi_c2_agent_class = "nifi.c2.agent.class";
   static constexpr const char *nifi_c2_agent_heartbeat_reporter_classes = "nifi.c2.agent.heartbeat.reporter.classes";
-  static constexpr const char *nifi_c2_agent_coap_host = "nifi.c2.agent.coap.host";
-  static constexpr const char *nifi_c2_agent_coap_port = "nifi.c2.agent.coap.port";
-  static constexpr const char *nifi_c2_agent_protocol_class = "nifi.c2.agent.protocol.class";
   static constexpr const char *nifi_c2_agent_identifier = "nifi.c2.agent.identifier";
   static constexpr const char *nifi_c2_agent_identifier_fallback = "nifi.c2.agent.identifier.fallback";
   static constexpr const char *nifi_c2_agent_trigger_classes = "nifi.c2.agent.trigger.classes";
@@ -121,6 +122,7 @@ class Configuration : public Properties {
   static constexpr const char *nifi_c2_root_class_definitions = "nifi.c2.root.class.definitions";
   static constexpr const char *nifi_c2_rest_listener_port = "nifi.c2.rest.listener.port";
   static constexpr const char *nifi_c2_rest_listener_cacert = "nifi.c2.rest.listener.cacert";
+  static constexpr const char *nifi_c2_rest_path_base = "nifi.c2.rest.path.base";
   static constexpr const char *nifi_c2_rest_url = "nifi.c2.rest.url";
   static constexpr const char *nifi_c2_rest_url_ack = "nifi.c2.rest.url.ack";
   static constexpr const char *nifi_c2_rest_ssl_context_service = "nifi.c2.rest.ssl.context.service";
@@ -145,12 +147,6 @@ class Configuration : public Properties {
   static constexpr const char *minifi_disk_space_watchdog_stop_threshold = "minifi.disk.space.watchdog.stop.threshold";
   static constexpr const char *minifi_disk_space_watchdog_restart_threshold = "minifi.disk.space.watchdog.restart.threshold";
 
-  // JNI options
-  static constexpr const char *nifi_framework_dir = "nifi.framework.dir";
-  static constexpr const char *nifi_jvm_options = "nifi.jvm.options";
-  static constexpr const char *nifi_nar_directory = "nifi.nar.directory";
-  static constexpr const char *nifi_nar_deploy_directory = "nifi.nar.deploy.directory";
-
   // Log options
   static constexpr const char *nifi_log_spdlog_pattern = "nifi.log.spdlog.pattern";
   static constexpr const char *nifi_log_spdlog_shorten_names = "nifi.log.spdlog.shorten_names";
