@@ -41,12 +41,12 @@ bool Configure::get(const std::string& key, const std::string& alternate_key, st
   if (get(key, value)) {
     if (get(alternate_key)) {
       const auto logger = core::logging::LoggerFactory<Configure>::getLogger();
-      logger->log_warn("Both the property '%s' and an alternate property '%s' are set. Using '%s'.", key, alternate_key, key);
+      logger->log_warn("Both the property '{}' and an alternate property '{}' are set. Using '{}'.", key, alternate_key, key);
     }
     return true;
   } else if (get(alternate_key, value)) {
     const auto logger = core::logging::LoggerFactory<Configure>::getLogger();
-    logger->log_warn("%s is an alternate property that may not be supported in future releases. Please use %s instead.", alternate_key, key);
+    logger->log_warn("{} is an alternate property that may not be supported in future releases. Please use {} instead.", alternate_key, key);
     return true;
   } else {
     return false;
@@ -71,7 +71,7 @@ std::optional<std::string> Configure::getWithFallback(const std::string& key, co
 
 std::optional<std::string> Configure::getRawValue(const std::string& key) const {
   static constexpr std::string_view log_prefix = "nifi.log.";
-  if (utils::StringUtils::startsWith(key, log_prefix)) {
+  if (utils::string::startsWith(key, log_prefix)) {
     if (logger_properties_) {
       return logger_properties_->getString(key.substr(log_prefix.length()));
     }
@@ -111,7 +111,7 @@ void Configure::setFallbackAgentIdentifier(const std::string& id) {
 
 void Configure::set(const std::string& key, const std::string& value, PropertyChangeLifetime lifetime) {
   const std::string_view log_prefix = "nifi.log.";
-  if (utils::StringUtils::startsWith(key, log_prefix)) {
+  if (utils::string::startsWith(key, log_prefix)) {
     if (logger_properties_) {
       logger_properties_changed_ = true;
       logger_properties_->set(key.substr(log_prefix.length()), value, lifetime);
