@@ -37,7 +37,7 @@
 #include "core/Connectable.h"
 #include "utils/file/PathUtils.h"
 #include "utils/file/FileSystem.h"
-#include "utils/BaseHTTPClient.h"
+#include "http/BaseHTTPClient.h"
 #include "io/NetworkPrioritizer.h"
 #include "io/FileStream.h"
 #include "core/ClassLoader.h"
@@ -50,7 +50,8 @@ namespace org::apache::nifi::minifi {
 FlowController::FlowController(std::shared_ptr<core::Repository> provenance_repo, std::shared_ptr<core::Repository> flow_file_repo,
                                std::shared_ptr<Configure> configure, std::shared_ptr<core::FlowConfiguration> flow_configuration,
                                std::shared_ptr<core::ContentRepository> content_repo, std::unique_ptr<state::MetricsPublisherStore> metrics_publisher_store,
-                               std::shared_ptr<utils::file::FileSystem> filesystem, std::function<void()> request_restart)
+                               std::shared_ptr<utils::file::FileSystem> filesystem, std::function<void()> request_restart,
+                               utils::file::AssetManager* asset_manager)
     : core::controller::ForwardingControllerServiceProvider(core::className<FlowController>()),
       running_(false),
       initialized_(false),
@@ -82,7 +83,7 @@ FlowController::FlowController(std::shared_ptr<core::Repository> provenance_repo
     if (auto publisher = metrics_publisher_store_->getMetricsPublisher(c2::C2_METRICS_PUBLISHER).lock()) {
       c2_metrics_publisher = std::dynamic_pointer_cast<c2::C2MetricsPublisher>(publisher);
     }
-    c2_agent_ = std::make_unique<c2::C2Agent>(configuration_, c2_metrics_publisher, std::move(filesystem), std::move(request_restart));
+    c2_agent_ = std::make_unique<c2::C2Agent>(configuration_, c2_metrics_publisher, std::move(filesystem), std::move(request_restart), asset_manager);
   }
 
   if (c2::isControllerSocketEnabled(configuration_)) {
@@ -105,23 +106,23 @@ FlowController::~FlowController() {
   logger_->log_trace("Destroying FlowController");
 }
 
-bool FlowController::applyConfiguration(const std::string &source, const std::string &configurePayload, const std::optional<std::string>& flow_id) {
+nonstd::expected<void, std::string> FlowController::applyConfiguration(const std::string &source, const std::string &configurePayload, const std::optional<std::string>& flow_id) {
   std::unique_ptr<core::ProcessGroup> newRoot;
   try {
     newRoot = updateFromPayload(source, configurePayload, flow_id);
   } catch (const std::exception& ex) {
     logger_->log_error("Invalid configuration payload, type: {}, what: {}", typeid(ex).name(), ex.what());
-    return false;
+    return nonstd::make_unexpected(fmt::format("Invalid configuration payload, type: {}, what: {}", typeid(ex).name(), ex.what()));
   } catch (...) {
     logger_->log_error("Invalid configuration payload, type: {}", getCurrentExceptionTypeName());
-    return false;
+    return nonstd::make_unexpected(fmt::format("Invalid configuration payload, type: {}", getCurrentExceptionTypeName()));
   }
 
   if (newRoot == nullptr)
-    return false;
+    return nonstd::make_unexpected("Could not create root process group");
 
   if (!isRunning())
-    return false;
+    return nonstd::make_unexpected("FlowController is not running");
 
   logger_->log_info("Starting to reload Flow Controller with flow control name {}, version {}", newRoot->getName(), newRoot->getVersion());
 
@@ -163,7 +164,10 @@ bool FlowController::applyConfiguration(const std::string &source, const std::st
     }
   }
 
-  return started;
+  if (!started) {
+    return nonstd::make_unexpected("Failed to start flow");
+  }
+  return {};
 }
 
 int16_t FlowController::stop() {
@@ -381,17 +385,16 @@ std::vector<std::string> FlowController::getSupportedConfigurationFormats() cons
   return flow_configuration_->getSupportedFormats();
 }
 
-int16_t FlowController::applyUpdate(const std::string &source, const std::string &configuration, bool persist, const std::optional<std::string>& flow_id) {
-  if (applyConfiguration(source, configuration, flow_id)) {
+nonstd::expected<void, std::string> FlowController::applyUpdate(const std::string &source, const std::string &configuration, bool persist, const std::optional<std::string>& flow_id) {
+  auto result = applyConfiguration(source, configuration, flow_id);
+  if (result) {
     if (persist) {
       const auto* process_group = root_wrapper_.getRoot();
       gsl_Expects(process_group);
       flow_configuration_->persist(*process_group);
     }
-    return 0;
-  } else {
-    return -1;
   }
+  return result;
 }
 
 int16_t FlowController::clearConnection(const std::string &connection) {
