@@ -18,10 +18,12 @@
  * limitations under the License.
  */
 #include "SchedulingAgent.h"
+
 #include <chrono>
+#include <memory>
 #include <thread>
 #include <utility>
-#include <memory>
+
 #include "core/Processor.h"
 #include "utils/gsl.h"
 
@@ -36,13 +38,10 @@ bool hasWorkToDo(org::apache::nifi::minifi::core::Processor* processor) {
 
 namespace org::apache::nifi::minifi {
 
-nonstd::expected<void, std::exception_ptr> SchedulingAgent::onTrigger(core::Processor* processor,
-    const std::shared_ptr<core::ProcessContext> &process_context,
-    const std::shared_ptr<core::ProcessSessionFactory> &session_factory) {
-  gsl_Expects(processor);
+bool SchedulingAgent::processorYields(core::Processor* processor) const {
   if (processor->isYield()) {
     logger_->log_debug("Not running {} since it must yield", processor->getName());
-    return {};
+    return true;
   }
 
   // No need to yield, reset yield expiration to 0
@@ -52,30 +51,43 @@ nonstd::expected<void, std::exception_ptr> SchedulingAgent::onTrigger(core::Proc
 
   if (!hasWorkToDo(processor)) {
     processor->yield(bored_yield_duration);
-    return {};
+    return true;
   }
   if (processor->isThrottledByBackpressure()) {
     logger_->log_debug("backpressure applied because too much outgoing for {} {}", processor->getUUIDStr(), processor->getName());
     processor->yield(bored_yield_duration);
+    return true;
+  }
+
+  return false;
+}
+
+nonstd::expected<void, std::exception_ptr> SchedulingAgent::triggerAndCommit(core::Processor* processor,
+    const std::shared_ptr<core::ProcessContext>& process_context,
+    const std::shared_ptr<core::ProcessSessionFactory>& session_factory) {
+  gsl_Expects(processor);
+  if (processorYields(processor)) {
     return {};
   }
 
-  auto schedule_it = scheduled_processors_.end();
-
+  auto processor_scheduling_info = SchedulingInfo(processor);
   {
     std::lock_guard<std::mutex> lock(watchdog_mtx_);
-    schedule_it = scheduled_processors_.emplace(processor).first;
+    scheduled_processors_.push_back(gsl::make_not_null(&processor_scheduling_info));
   }
 
-  const auto guard = gsl::finally([this, &schedule_it](){
+  const auto guard = gsl::finally([this, &processor_scheduling_info](){
     std::lock_guard<std::mutex> lock(watchdog_mtx_);
-    scheduled_processors_.erase(schedule_it);
+    [[maybe_unused]] const auto erased_scheduling_infos_count = std::erase(scheduled_processors_, gsl::make_not_null(&processor_scheduling_info));
+    gsl_Assert(1 == erased_scheduling_infos_count);
   });
 
+
   processor->incrementActiveTasks();
   auto decrement_task = gsl::finally([processor]() { processor->decrementActiveTask(); });
+
   try {
-    processor->onTrigger(process_context, session_factory);
+    processor->triggerAndCommit(process_context, session_factory);
   } catch (const std::exception& exception) {
     logger_->log_warn("Caught Exception during SchedulingAgent::onTrigger of processor {} (uuid: {}), type: {}, what: {}",
         processor->getName(), processor->getUUIDStr(), typeid(exception).name(), exception.what());
@@ -90,15 +102,53 @@ nonstd::expected<void, std::exception_ptr> SchedulingAgent::onTrigger(core::Proc
   return {};
 }
 
+nonstd::expected<bool, std::exception_ptr> SchedulingAgent::trigger(core::Processor* processor,
+    const std::shared_ptr<core::ProcessContext>& process_context,
+    const std::shared_ptr<core::ProcessSession>& process_session) {
+  gsl_Expects(processor);
+  if (processorYields(processor)) {
+    return false;
+  }
+
+  auto processor_scheduling_info = SchedulingInfo(processor);
+  {
+    std::lock_guard<std::mutex> lock(watchdog_mtx_);
+    scheduled_processors_.push_back(gsl::make_not_null(&processor_scheduling_info));
+  }
+
+  const auto guard = gsl::finally([this, &processor_scheduling_info](){
+    std::lock_guard<std::mutex> lock(watchdog_mtx_);
+    [[maybe_unused]] const auto erased_scheduling_infos_count = std::erase(scheduled_processors_, gsl::make_not_null(&processor_scheduling_info));
+    gsl_Assert(1 == erased_scheduling_infos_count);
+  });
+
+  processor->incrementActiveTasks();
+  auto decrement_task = gsl::finally([processor]() { processor->decrementActiveTask(); });
+  try {
+    processor->trigger(process_context, process_session);
+  } catch (const std::exception& exception) {
+    logger_->log_warn("Caught Exception during SchedulingAgent::onTrigger of processor {} (uuid: {}), type: {}, what: {}",
+        processor->getName(), processor->getUUIDStr(), typeid(exception).name(), exception.what());
+    processor->yield(admin_yield_duration_);
+    return nonstd::make_unexpected(std::current_exception());
+  } catch (...) {
+    logger_->log_warn("Caught Exception during SchedulingAgent::onTrigger of processor {} (uuid: {}), type: {}",
+        processor->getName(), processor->getUUIDStr(), getCurrentExceptionTypeName());
+    processor->yield(admin_yield_duration_);
+    return nonstd::make_unexpected(std::current_exception());
+  }
+  return true;
+}
+
 void SchedulingAgent::watchDogFunc() {
   std::lock_guard<std::mutex> lock(watchdog_mtx_);
   auto now = std::chrono::steady_clock::now();
   for (const auto& info : scheduled_processors_) {
-    auto elapsed = now - info.last_alert_time_;
+    auto elapsed = now - info->last_alert_time_;
     if (elapsed > alert_time_) {
-      int64_t elapsed_ms{ std::chrono::duration_cast<std::chrono::milliseconds>(now - info.start_time_).count() };
-      logger_->log_warn("{}::onTrigger has been running for {}  ms in {}", info.name_, elapsed_ms, info.uuid_);
-      info.last_alert_time_ = now;
+      int64_t elapsed_ms{ std::chrono::duration_cast<std::chrono::milliseconds>(now - info->start_time_).count() };
+      logger_->log_warn("{}::onTrigger has been running for {}  ms in {}", info->name_, elapsed_ms, info->uuid_);
+      info->last_alert_time_ = now;
     }
   }
 }
