@@ -47,7 +47,7 @@ bool LinuxPowerManagerService::canIncrease() {
       std::getline(status_file, status_str);
       status_file.close();
 
-      if (!utils::StringUtils::equalsIgnoreCase(status_keyword_, status_str)) {
+      if (!utils::string::equalsIgnoreCase(status_keyword_, status_str)) {
         return true;
       }
     } catch (...) {
@@ -97,7 +97,7 @@ bool LinuxPowerManagerService::shouldReduce() {
       std::getline(status_file, status_str);
       status_file.close();
 
-      if (!utils::StringUtils::equalsIgnoreCase(status_keyword_, status_str)) {
+      if (!utils::string::equalsIgnoreCase(status_keyword_, status_str)) {
         all_discharging &= false;
       }
     } catch (...) {
@@ -122,13 +122,13 @@ bool LinuxPowerManagerService::shouldReduce() {
           overConsume = true;
           logger_->log_trace("All banks are discharging, suggesting reduction");
         } else {
-          core::logging::LOG_DEBUG(logger_) << "dischaging but can't reduce due to time " << curr_time << " " << last_time_ << "  " << wait_period_;
+          logger_->log_debug("Discharging but can't reduce due to time {} {} {}", curr_time, last_time_.load(), wait_period_.load());
         }
       }
     }
 
   } else {
-    logger_->log_trace("%d level is not below trigger of %d", battery_level_.load(), trigger_);
+    logger_->log_trace("{} level is not below trigger of {}", battery_level_.load(), trigger_);
   }
 
   return overConsume;
@@ -159,7 +159,7 @@ void LinuxPowerManagerService::onEnable() {
   core::Property capacityPaths;
   core::Property statusPaths;
 
-  uint64_t wait;
+  uint64_t wait = 0;
   if (getProperty(TriggerThreshold, trigger_) && getProperty(WaitPeriod, wait)) {
     wait_period_ = wait;
 
