@@ -33,11 +33,10 @@ FlowConfiguration::FlowConfiguration(ConfigurationContext ctx)
       flow_file_repo_(std::move(ctx.flow_file_repo)),
       content_repo_(std::move(ctx.content_repo)),
       configuration_(std::move(ctx.configuration)),
+      service_provider_(std::make_shared<core::controller::StandardControllerServiceProvider>(std::make_unique<core::controller::ControllerServiceNodeMap>(), configuration_)),
       filesystem_(std::move(ctx.filesystem)),
-      sensitive_properties_encryptor_(std::move(ctx.sensitive_properties_encryptor.value())),
+      sensitive_values_encryptor_(std::move(ctx.sensitive_values_encryptor.value())),
       logger_(logging::LoggerFactory<FlowConfiguration>::getLogger()) {
-  controller_services_ = std::make_shared<core::controller::ControllerServiceMap>();
-  service_provider_ = std::make_shared<core::controller::StandardControllerServiceProvider>(controller_services_, configuration_);
   std::string flowUrl;
   std::string bucket_id = "default";
   std::string flowId;
@@ -94,10 +93,9 @@ std::unique_ptr<core::reporting::SiteToSiteProvenanceReportingTask> FlowConfigur
 }
 
 std::unique_ptr<core::ProcessGroup> FlowConfiguration::updateFromPayload(const std::string& url, const std::string& yamlConfigPayload, const std::optional<std::string>& flow_id) {
-  auto old_services = controller_services_;
   auto old_provider = service_provider_;
-  controller_services_ = std::make_shared<core::controller::ControllerServiceMap>();
-  service_provider_ = std::make_shared<core::controller::StandardControllerServiceProvider>(controller_services_, configuration_);
+  auto old_parameter_contexts = std::move(parameter_contexts_);
+  service_provider_ = std::make_shared<core::controller::StandardControllerServiceProvider>(std::make_unique<core::controller::ControllerServiceNodeMap>(), configuration_);
   auto payload = getRootFromPayload(yamlConfigPayload);
   if (!url.empty() && payload != nullptr) {
     std::string payload_flow_id;
@@ -112,8 +110,8 @@ std::unique_ptr<core::ProcessGroup> FlowConfiguration::updateFromPayload(const s
     }
     flow_version_->setFlowVersion(url, bucket_id, flow_id ? *flow_id : payload_flow_id);
   } else {
-    controller_services_ = old_services;
     service_provider_ = old_provider;
+    parameter_contexts_ = std::move(old_parameter_contexts);
   }
   return payload;
 }
