@@ -32,6 +32,7 @@
 
 #include "core/ProcessSessionReadCallback.h"
 #include "io/StreamSlice.h"
+#include "io/StreamPipe.h"
 #include "utils/gsl.h"
 
 /* This implementation is only for native Windows systems.  */
@@ -78,7 +79,8 @@ ProcessSession::ProcessSession(std::shared_ptr<ProcessContext> processContext)
 
 ProcessSession::~ProcessSession() {
   if (stateManager_ && stateManager_->isTransactionInProgress()) {
-    logger_->log_error("Session has ended without decision on state (commit or rollback).");
+    logger_->log_critical("Session has ended without decision on state (commit or rollback).");
+    std::terminate();
   }
   removeReferences();
 }
@@ -183,10 +185,12 @@ std::shared_ptr<core::FlowFile> ProcessSession::clone(const FlowFile& parent, in
   if (record) {
     logger_->log_debug("Cloned parent flow files {} to {}, with {}:{}", parent.getUUIDStr(), record->getUUIDStr(), offset, size);
     if (parent.getResourceClaim()) {
-      record->setOffset(parent.getOffset() + offset);
-      record->setSize(size);
-      // Copy Resource Claim
-      record->setResourceClaim(parent.getResourceClaim());
+      write(record, [&] (const std::shared_ptr<io::OutputStream>& output) -> int64_t {
+        return read(parent, [&] (const std::shared_ptr<io::InputStream>& input) -> int64_t {
+          io::StreamSlice slice(input, offset, size);
+          return minifi::internal::pipe(slice, *output);
+        });
+      });
     }
     provenance_report_->clone(parent, *record);
   }
@@ -194,7 +198,7 @@ std::shared_ptr<core::FlowFile> ProcessSession::clone(const FlowFile& parent, in
 }
 
 void ProcessSession::remove(const std::shared_ptr<core::FlowFile> &flow) {
-  logger_->log_trace("Removing flow file with UUID: {}", flow->getUUIDStr());
+  logger_->log_debug("Removing flow file with UUID: {}", flow->getUUIDStr());
   flow->setDeleted(true);
   deleted_flowfiles_.push_back(flow);
   std::string reason = process_context_->getProcessorNode()->getName() + " drop flow record " + flow->getUUIDStr();
@@ -220,7 +224,7 @@ void ProcessSession::penalize(const std::shared_ptr<core::FlowFile> &flow) {
 }
 
 void ProcessSession::transfer(const std::shared_ptr<core::FlowFile>& flow, const Relationship& relationship) {
-  logger_->log_info("Transferring {} from {} to relationship {}", flow->getUUIDStr(), process_context_->getProcessorNode()->getName(), relationship.getName());
+  logger_->log_debug("Transferring {} from {} to relationship {}", flow->getUUIDStr(), process_context_->getProcessorNode()->getName(), relationship.getName());
   utils::Identifier uuid = flow->getUUID();
   if (auto it = added_flowfiles_.find(uuid); it != added_flowfiles_.end()) {
     it->second.rel = &*relationships_.insert(relationship).first;
@@ -235,9 +239,13 @@ void ProcessSession::transferToCustomRelationship(const std::shared_ptr<core::Fl
 }
 
 void ProcessSession::write(const std::shared_ptr<core::FlowFile> &flow, const io::OutputStreamCallback& callback) {
-  gsl_ExpectsAudit(updated_flowfiles_.contains(flow->getUUID())
-      || added_flowfiles_.contains(flow->getUUID())
-      || std::any_of(cloned_flowfiles_.begin(), cloned_flowfiles_.end(), [&flow](const auto& flow_file) { return flow == flow_file; }));
+  return write(*flow, callback);
+}
+
+void ProcessSession::write(core::FlowFile &flow, const io::OutputStreamCallback& callback) {
+  gsl_ExpectsAudit(updated_flowfiles_.contains(flow.getUUID())
+      || added_flowfiles_.contains(flow.getUUID())
+      || std::any_of(cloned_flowfiles_.begin(), cloned_flowfiles_.end(), [&flow](const auto& flow_file) { return &flow == flow_file.get(); }));
 
   std::shared_ptr<ResourceClaim> claim = content_session_->create();
 
@@ -252,14 +260,17 @@ void ProcessSession::write(const std::shared_ptr<core::FlowFile> &flow, const io
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to process flowfile content");
     }
 
-    flow->setSize(stream->size());
-    flow->setOffset(0);
-    flow->setResourceClaim(claim);
+    flow.setSize(stream->size());
+    flow.setOffset(0);
+    flow.setResourceClaim(claim);
 
     stream->close();
-    std::string details = process_context_->getProcessorNode()->getName() + " modify flow record content " + flow->getUUIDStr();
+    std::string details = process_context_->getProcessorNode()->getName() + " modify flow record content " + flow.getUUIDStr();
     auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
-    provenance_report_->modifyContent(*flow, details, duration);
+    provenance_report_->modifyContent(flow, details, duration);
+    if (metrics_) {
+      metrics_->bytes_written += stream->size();
+    }
   } catch (const std::exception& exception) {
     logger_->log_debug("Caught Exception during process session write, type: {}, what: {}", typeid(exception).name(), exception.what());
     throw;
@@ -272,6 +283,7 @@ void ProcessSession::write(const std::shared_ptr<core::FlowFile> &flow, const io
 void ProcessSession::writeBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const char> buffer) {
   writeBuffer(flow_file, as_bytes(buffer));
 }
+
 void ProcessSession::writeBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const std::byte> buffer) {
   write(flow_file, [buffer](const std::shared_ptr<io::OutputStream>& output_stream) {
     const auto write_status = output_stream->write(buffer);
@@ -308,6 +320,9 @@ void ProcessSession::append(const std::shared_ptr<core::FlowFile> &flow, const i
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to process flowfile content");
     }
     flow->setSize(flow_file_size + (stream->size() - stream_size_before_callback));
+    if (metrics_) {
+      metrics_->bytes_written += stream->size() - stream_size_before_callback;
+    }
 
     std::stringstream details;
     details << process_context_->getProcessorNode()->getName() << " modify flow record content " << flow->getUUIDStr();
@@ -325,6 +340,7 @@ void ProcessSession::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_fi
   appendBuffer(flow_file, as_bytes(buffer));
 }
 void ProcessSession::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_file, std::span<const std::byte> buffer) {
+  if (buffer.empty()) { return; }
   append(flow_file, [buffer](const std::shared_ptr<io::OutputStream>& output_stream) {
     const auto write_status = output_stream->write(buffer);
     return io::isError(write_status) ? -1 : gsl::narrow<int64_t>(write_status);
@@ -350,8 +366,12 @@ std::shared_ptr<io::InputStream> ProcessSession::getFlowFileContentStream(const
 }
 
 int64_t ProcessSession::read(const std::shared_ptr<core::FlowFile>& flow_file, const io::InputStreamCallback& callback) {
+  return read(*flow_file, callback);
+}
+
+int64_t ProcessSession::read(const core::FlowFile& flow_file, const io::InputStreamCallback& callback) {
   try {
-    auto flow_file_stream = getFlowFileContentStream(*flow_file);
+    auto flow_file_stream = getFlowFileContentStream(flow_file);
     if (!flow_file_stream) {
       return 0;
     }
@@ -360,6 +380,9 @@ int64_t ProcessSession::read(const std::shared_ptr<core::FlowFile>& flow_file, c
     if (ret < 0) {
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to process flowfile content");
     }
+    if (metrics_) {
+      metrics_->bytes_read += ret;
+    }
     return ret;
   } catch (const std::exception& exception) {
     logger_->log_debug("Caught Exception {}", exception.what());
@@ -370,7 +393,6 @@ int64_t ProcessSession::read(const std::shared_ptr<core::FlowFile>& flow_file, c
   }
 }
 
-
 int64_t ProcessSession::readWrite(const std::shared_ptr<core::FlowFile> &flow, const io::InputOutputStreamCallback& callback) {
   gsl_Expects(callback);
 
@@ -396,19 +418,23 @@ int64_t ProcessSession::readWrite(const std::shared_ptr<core::FlowFile> &flow, c
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to open flowfile content for write");
     }
 
-    int64_t bytes_written = callback(input_stream, output_stream);
-    if (bytes_written < 0) {
+    auto read_write_result = callback(input_stream, output_stream);
+    if (!read_write_result) {
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to process flowfile content");
     }
 
     input_stream->close();
     output_stream->close();
 
-    flow->setSize(gsl::narrow<uint64_t>(bytes_written));
+    flow->setSize(gsl::narrow<uint64_t>(read_write_result->bytes_written));
     flow->setOffset(0);
     flow->setResourceClaim(output_claim);
+    if (metrics_) {
+      metrics_->bytes_written += read_write_result->bytes_written;
+      metrics_->bytes_read += read_write_result->bytes_read;
+    }
 
-    return bytes_written;
+    return read_write_result->bytes_written;
   } catch (const std::exception& exception) {
     logger_->log_debug("Caught exception during process session readWrite, type: {}, what: {}", typeid(exception).name(), exception.what());
     throw;
@@ -473,6 +499,9 @@ void ProcessSession::importFrom(io::InputStream &stream, const std::shared_ptr<c
         flow->getOffset(), flow->getSize(), flow->getResourceClaim()->getContentFullPath(), flow->getUUIDStr());
 
     content_stream->close();
+    if (metrics_) {
+      metrics_->bytes_written += content_stream->size();
+    }
     std::stringstream details;
     details << process_context_->getProcessorNode()->getName() << " modify flow record content " << flow->getUUIDStr();
     auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
@@ -534,6 +563,9 @@ void ProcessSession::import(const std::string& source, const std::shared_ptr<Flo
                            flow->getUUIDStr());
 
         stream->close();
+        if (metrics_) {
+          metrics_->bytes_written += stream->size();
+        }
         input.close();
         if (!keepSource) {
           (void)std::remove(source.c_str());
@@ -636,6 +668,9 @@ void ProcessSession::import(const std::string& source, std::vector<std::shared_p
         logger_->log_debug("Import offset {} length {} into content {}, FlowFile UUID {}",
             flowFile->getOffset(), flowFile->getSize(), flowFile->getResourceClaim()->getContentFullPath(), flowFile->getUUIDStr());
         stream->close();
+        if (metrics_) {
+          metrics_->bytes_written += stream->size();
+        }
         std::string details = process_context_->getProcessorNode()->getName() + " modify flow record content " + flowFile->getUUIDStr();
         auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
         provenance_report_->modifyContent(*flowFile, details, duration);
@@ -803,9 +838,10 @@ ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<
 }
 
 void ProcessSession::commit() {
+  const auto commit_start_time = std::chrono::steady_clock::now();
   try {
     std::unordered_map<std::string, TransferMetrics> transfers;
-      auto increaseTransferMetrics = [&](const FlowFile& record, const Relationship& relationship) {
+    auto increaseTransferMetrics = [&](const FlowFile& record, const Relationship& relationship) {
       ++transfers[relationship.getName()].transfer_count;
       transfers[relationship.getName()].transfer_size += record.getSize();
     };
@@ -915,7 +951,12 @@ void ProcessSession::commit() {
     relationships_.clear();
     // persistent the provenance report
     this->provenance_report_->commit();
-    logger_->log_trace("ProcessSession committed for {}", process_context_->getProcessorNode()->getName());
+    logger_->log_debug("ProcessSession committed for {}", process_context_->getProcessorNode()->getName());
+    if (metrics_) {
+      auto time_delta = std::chrono::steady_clock::now() - commit_start_time;
+      metrics_->addLastSessionCommitRuntime(std::chrono::duration_cast<std::chrono::milliseconds>(time_delta));
+      metrics_->processing_nanos += std::chrono::duration_cast<std::chrono::nanoseconds>(time_delta).count();
+    }
   } catch (const std::exception& exception) {
     logger_->log_debug("Caught Exception during process session commit, type: {}, what: {}", typeid(exception).name(), exception.what());
     throw;
@@ -981,6 +1022,15 @@ void ProcessSession::rollback() {
   }
 }
 
+nonstd::expected<void, std::exception_ptr> ProcessSession::rollbackNoThrow() noexcept {
+  try {
+    rollback();
+    return {};
+  } catch(...) {
+    return nonstd::make_unexpected(std::current_exception());
+  }
+}
+
 void ProcessSession::persistFlowFilesBeforeTransfer(
     std::map<Connectable*, std::vector<std::shared_ptr<core::FlowFile> > >& transactionMap,
     const std::map<utils::Identifier, FlowFileUpdate>& modifiedFlowFiles) {
@@ -1116,6 +1166,10 @@ std::shared_ptr<core::FlowFile> ProcessSession::get() {
       if (flow_version != nullptr) {
         ret->setAttribute(SpecialFlowAttribute::FLOW_ID, flow_version->getFlowId());
       }
+      if (metrics_) {
+        metrics_->incoming_bytes += ret->getSize();
+        ++metrics_->incoming_flow_files;
+      }
       return ret;
     }
     current = dynamic_cast<Connection*>(process_context_->getProcessorNode()->pickIncomingConnection());
