@@ -61,10 +61,15 @@ std::unique_ptr<core::ContentRepository> createContentRepository(const std::stri
 
 class NoOpThreadedRepository : public core::ThreadedRepository {
  public:
-  explicit NoOpThreadedRepository(std::string repo_name)
-    : ThreadedRepository(std::move(repo_name)) {
+  explicit NoOpThreadedRepository(std::string_view repo_name)
+    : ThreadedRepository(repo_name) {
   }
 
+  NoOpThreadedRepository(NoOpThreadedRepository&&) = delete;
+  NoOpThreadedRepository(const NoOpThreadedRepository&) = delete;
+  NoOpThreadedRepository& operator=(NoOpThreadedRepository&&) = delete;
+  NoOpThreadedRepository& operator=(const NoOpThreadedRepository&) = delete;
+
   ~NoOpThreadedRepository() override {
     stop();
   }
@@ -100,7 +105,7 @@ std::unique_ptr<core::Repository> createRepository(const std::string& configurat
   // if the desired repos don't exist, we can try doing string matches and rely on volatile repositories
   if (class_name_lc == "flowfilerepository" || class_name_lc == "volatileflowfilerepository") {
     return instantiate<repository::VolatileFlowFileRepository>(repo_name);
-  } else if (class_name_lc == "provenancerepository" || class_name_lc == "volatileprovenancefilerepository") {
+  } else if (class_name_lc == "provenancerepository" || class_name_lc == "volatileprovenancerepository") {
     return instantiate<repository::VolatileProvenanceRepository>(repo_name);
   } else if (class_name_lc == "nooprepository") {
     return std::make_unique<core::NoOpThreadedRepository>(repo_name);
