@@ -75,7 +75,14 @@ FlowSchema FlowSchema::getDefault() {
       .rpg_input_ports = {"Input Ports"},
       .rpg_output_ports = {"Output Ports"},
       .rpg_port_properties = {"Properties"},
-      .rpg_port_target_id = {}
+      .rpg_port_target_id = {},
+
+      .parameter_contexts = {"Parameter Contexts"},
+      .parameters = {"Parameters"},
+      .description = {"description"},
+      .value = {"value"},
+      .parameter_context_name = {"Parameter Context Name"},
+      .sensitive = {"sensitive"}
   };
 }
 
@@ -123,7 +130,7 @@ FlowSchema FlowSchema::getNiFiFlowJson() {
       .input_ports = {"inputPorts"},
       .output_ports = {"outputPorts"},
 
-      .rpg_url = {"targetUri"},
+      .rpg_url = {"targetUris", "targetUri"},
       .rpg_yield_period = {"yieldDuration"},
       .rpg_timeout = {"communicationsTimeout"},
       .rpg_local_network_interface = {"localNetworkInterface"},
@@ -134,8 +141,15 @@ FlowSchema FlowSchema::getNiFiFlowJson() {
       .rpg_proxy_port = {"proxyPort"},
       .rpg_input_ports = {"inputPorts"},
       .rpg_output_ports = {"outputPorts"},
-      .rpg_port_properties = {},
-      .rpg_port_target_id = {"targetId"}
+      .rpg_port_properties = {"properties"},
+      .rpg_port_target_id = {"targetId"},
+
+      .parameter_contexts = {"parameterContexts"},
+      .parameters = {"parameters"},
+      .description = {"description"},
+      .value = {"value"},
+      .parameter_context_name = {"parameterContextName"},
+      .sensitive = {"sensitive"}
   };
 }
 
