@@ -17,6 +17,7 @@
  */
 
 #include "core/flow/Node.h"
+#include "fmt/format.h"
 
 namespace org::apache::nifi::minifi::core::flow {
 
@@ -24,10 +25,10 @@ Node::Iterator::Value Node::Iterator::operator*() const {
   Value value = impl_->operator*();
   if (value) {
     // sequence iterator
-    value.path_ = utils::StringUtils::join_pack(path_, "/", std::to_string(idx_));
+    value.impl_->path_ = utils::string::join_pack(impl_->path_, "/", std::to_string(idx_));
   } else if (value.second) {
     // map iterator
-    value.second.path_ = utils::StringUtils::join_pack(path_, "/", value.first.getString().value());
+    value.second.impl_->path_ = utils::string::join_pack(impl_->path_, "/", value.first.getString().value());
   }
   return value;
 }
