@@ -28,6 +28,8 @@
 #include "utils/TimeUtil.h"
 #include "utils/RegexUtils.h"
 #include "Funnel.h"
+#include "core/ParameterContext.h"
+#include "core/ParameterTokenParser.h"
 
 namespace org::apache::nifi::minifi::core::flow {
 
@@ -94,7 +96,11 @@ std::unique_ptr<core::ProcessGroup> StructuredConfiguration::parseProcessGroup(c
   Node outputPortsNode = node[schema_.output_ports];
   Node remoteProcessingGroupsNode = node[schema_.remote_process_group];
   Node childProcessGroupNodeSeq = node[schema_.process_groups];
+  Node parameterContextNameNode = node[schema_.parameter_context_name];
+  Node controllerServiceNode = node[schema_.controller_services];
 
+  parseParameterContext(parameterContextNameNode, *group);
+  parseControllerServices(controllerServiceNode, group.get());
   parseProcessorNode(processorsNode, group.get());
   parseRemoteProcessGroup(remoteProcessingGroupsNode, group.get());
   parseFunnels(funnelsNode, group.get());
@@ -116,20 +122,14 @@ std::unique_ptr<core::ProcessGroup> StructuredConfiguration::getRootFrom(const N
   try {
     schema_ = std::move(schema);
     uuids_.clear();
-    Node controllerServiceNode = root_node[schema_.root_group][schema_.controller_services];
+    Node parameterContextsNode = root_node[schema_.parameter_contexts];
     Node provenanceReportNode = root_node[schema_.provenance_reporting];
 
-    parseControllerServices(controllerServiceNode);
+    parseParameterContexts(parameterContextsNode);
     // Create the root process group
     std::unique_ptr<core::ProcessGroup> root = parseRootProcessGroup(root_node);
     parseProvenanceReporting(provenanceReportNode, root.get());
 
-    // set the controller services into the root group.
-    for (const auto& controller_service : controller_services_->getAllControllerServices()) {
-      root->addControllerService(controller_service->getName(), controller_service);
-      root->addControllerService(controller_service->getUUIDStr(), controller_service);
-    }
-
     root->verify();
 
     return root;
@@ -139,6 +139,41 @@ std::unique_ptr<core::ProcessGroup> StructuredConfiguration::getRootFrom(const N
   }
 }
 
+void StructuredConfiguration::parseParameterContexts(const Node& parameter_contexts_node) {
+  if (!parameter_contexts_node || !parameter_contexts_node.isSequence()) {
+    return;
+  }
+  for (const auto& parameter_context_node : parameter_contexts_node) {
+    checkRequiredField(parameter_context_node, schema_.name);
+
+    auto name = parameter_context_node[schema_.name].getString().value();
+    if (parameter_contexts_.find(name) != parameter_contexts_.end()) {
+      throw std::invalid_argument("Parameter context name '" + name + "' already exists, parameter context names must be unique!");
+    }
+    auto id = getRequiredIdField(parameter_context_node);
+
+    utils::Identifier uuid;
+    uuid = id;
+    auto parameter_context = std::make_unique<ParameterContext>(name, uuid);
+    parameter_context->setDescription(getOptionalField(parameter_context_node, schema_.description, ""));
+    for (const auto& parameter_node : parameter_context_node[schema_.parameters]) {
+      checkRequiredField(parameter_node, schema_.name);
+      checkRequiredField(parameter_node, schema_.value);
+      checkRequiredField(parameter_node, schema_.sensitive);
+      auto parameter_name = parameter_node[schema_.name].getString().value();
+      auto parameter_value = parameter_node[schema_.value].getString().value();
+      auto sensitive = parameter_node[schema_.sensitive].getBool().value();
+      auto parameter_description = getOptionalField(parameter_node, schema_.description, "");
+      if (sensitive) {
+        parameter_value = utils::crypto::property_encryption::decrypt(parameter_value, sensitive_values_encryptor_);
+      }
+      parameter_context->addParameter(Parameter{parameter_name, parameter_description, sensitive, parameter_value});
+    }
+
+    parameter_contexts_.emplace(name, gsl::make_not_null(std::move(parameter_context)));
+  }
+}
+
 void StructuredConfiguration::parseProcessorNode(const Node& processors_node, core::ProcessGroup* parentGroup) {
   int64_t runDurationNanos = -1;
   utils::Identifier uuid;
@@ -230,7 +265,7 @@ void StructuredConfiguration::parseProcessorNode(const Node& processors_node, co
 
     // handle processor properties
     if (Node propertiesNode = procNode[schema_.processor_properties]) {
-      parsePropertiesNode(propertiesNode, *processor, procCfg.name);
+      parsePropertiesNode(propertiesNode, *processor, procCfg.name, parentGroup->getParameterContext());
     }
 
     // Take care of scheduling
@@ -477,7 +512,7 @@ void StructuredConfiguration::parseProvenanceReporting(const Node& node, core::P
   parent_group->addProcessor(std::move(reportTask));
 }
 
-void StructuredConfiguration::parseControllerServices(const Node& controller_services_node) {
+void StructuredConfiguration::parseControllerServices(const Node& controller_services_node, core::ProcessGroup* parent_group) {
   if (!controller_services_node || !controller_services_node.isSequence()) {
     return;
   }
@@ -505,16 +540,20 @@ void StructuredConfiguration::parseControllerServices(const Node& controller_ser
       controller_service_node->initialize();
       if (Node propertiesNode = service_node[schema_.controller_service_properties]) {
         // we should propagate properties to the node and to the implementation
-        parsePropertiesNode(propertiesNode, *controller_service_node, name);
+        parsePropertiesNode(propertiesNode, *controller_service_node, name, parent_group->getParameterContext());
         if (auto controllerServiceImpl = controller_service_node->getControllerServiceImplementation(); controllerServiceImpl) {
-          parsePropertiesNode(propertiesNode, *controllerServiceImpl, name);
+          parsePropertiesNode(propertiesNode, *controllerServiceImpl, name, parent_group->getParameterContext());
         }
       }
+
+      service_provider_->putControllerServiceNode(id, controller_service_node, parent_group);
+      service_provider_->putControllerServiceNode(name, controller_service_node, parent_group);
+
+      parent_group->addControllerService(controller_service_node->getName(), controller_service_node);
+      parent_group->addControllerService(controller_service_node->getUUIDStr(), controller_service_node);
     } else {
       logger_->log_debug("Could not locate {}", type);
     }
-    controller_services_->put(id, controller_service_node);
-    controller_services_->put(name, controller_service_node);
   }
 }
 
@@ -599,9 +638,9 @@ void StructuredConfiguration::parseRPGPort(const Node& port_node, core::ProcessG
 
   // handle port properties
   if (Node propertiesNode = port_node[schema_.rpg_port_properties]) {
-    parsePropertiesNode(propertiesNode, *port, nameStr);
+    parsePropertiesNode(propertiesNode, *port, nameStr, nullptr);
   } else {
-    parsePropertyNodeElement(std::string(minifi::RemoteProcessorGroupPort::portUUID.name), port_node[schema_.rpg_port_target_id], *port);
+    parsePropertyNodeElement(std::string(minifi::RemoteProcessorGroupPort::portUUID.name), port_node[schema_.rpg_port_target_id], *port, nullptr);
     validateComponentProperties(*port, nameStr, port_node.getPath());
   }
 
@@ -621,7 +660,8 @@ void StructuredConfiguration::parseRPGPort(const Node& port_node, core::ProcessG
   }
 }
 
-void StructuredConfiguration::parsePropertyValueSequence(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& component) {
+void StructuredConfiguration::parsePropertyValueSequence(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& component,
+    ParameterContext* parameter_context) {
   core::Property myProp(property_name, "", "");
   component.getProperty(property_name, myProp);
 
@@ -629,16 +669,28 @@ void StructuredConfiguration::parsePropertyValueSequence(const std::string& prop
     if (nodeVal) {
       Node propertiesNode = nodeVal["value"];
       auto rawValueString = propertiesNode.getString().value();
+      std::unique_ptr<core::ParameterTokenParser> token_parser;
       if (myProp.isSensitive()) {
-        rawValueString = utils::crypto::property_encryption::decrypt(rawValueString, sensitive_properties_encryptor_);
+        rawValueString = utils::crypto::property_encryption::decrypt(rawValueString, sensitive_values_encryptor_);
+        token_parser = std::make_unique<core::SensitiveParameterTokenParser>(rawValueString, sensitive_values_encryptor_);
+      } else {
+        token_parser = std::make_unique<core::NonSensitiveParameterTokenParser>(rawValueString);
       }
+
+      try {
+        rawValueString = token_parser->replaceParameters(parameter_context);
+      } catch (const ParameterException& e) {
+        logger_->log_error("Error while substituting parameters in property '{}': {}", property_name, e.what());
+        throw;
+      }
+
       logger_->log_debug("Found property {}", property_name);
 
       if (!component.updateProperty(property_name, rawValueString)) {
         auto proc = dynamic_cast<core::Connectable*>(&component);
         if (proc) {
           logger_->log_warn("Received property {} with value {} but is not one of the properties for {}. Attempting to add as dynamic property.", property_name, rawValueString, proc->getName());
-          if (!component.setDynamicProperty(property_name, rawValueString)) {
+          if (!component.updateDynamicProperty(property_name, rawValueString)) {
             logger_->log_warn("Unable to set the dynamic property {}", property_name);
           } else {
             logger_->log_warn("Dynamic property {} has been set", property_name);
@@ -649,7 +701,8 @@ void StructuredConfiguration::parsePropertyValueSequence(const std::string& prop
   }
 }
 
-PropertyValue StructuredConfiguration::getValidatedProcessorPropertyForDefaultTypeInfo(const core::Property& property_from_processor, const Node& property_value_node) {
+PropertyValue StructuredConfiguration::getValidatedProcessorPropertyForDefaultTypeInfo(const core::Property& property_from_processor, const Node& property_value_node,
+    ParameterContext* parameter_context) {
   using state::response::Value;
   PropertyValue defaultValue;
   defaultValue = property_from_processor.getDefaultValue();
@@ -667,15 +720,26 @@ PropertyValue StructuredConfiguration::getValidatedProcessorPropertyForDefaultTy
       coercedValue = gsl::narrow<int>(int64_val.value());
     } else if (defaultType == Value::BOOL_TYPE && property_value_node.getBool()) {
       coercedValue = property_value_node.getBool().value();
-    } else if (property_from_processor.isSensitive()) {
-      coercedValue = utils::crypto::property_encryption::decrypt(property_value_node.getScalarAsString().value(), sensitive_properties_encryptor_);
     } else {
-      coercedValue = property_value_node.getScalarAsString().value();
+      std::string property_value_string;
+      std::unique_ptr<core::ParameterTokenParser> token_parser;
+      if (property_from_processor.isSensitive()) {
+        property_value_string = utils::crypto::property_encryption::decrypt(property_value_node.getScalarAsString().value(), sensitive_values_encryptor_);
+        token_parser = std::make_unique<core::SensitiveParameterTokenParser>(property_value_string, sensitive_values_encryptor_);
+      } else {
+        property_value_string = property_value_node.getScalarAsString().value();
+        token_parser = std::make_unique<core::NonSensitiveParameterTokenParser>(property_value_string);
+      }
+      property_value_string = token_parser->replaceParameters(parameter_context);
+      coercedValue = property_value_string;
     }
     return coercedValue;
   } catch (const utils::crypto::EncryptionError& e) {
     logger_->log_error("Fetching property failed with a decryption error: {}", e.what());
     throw;
+  } catch (const ParameterException& e) {
+    logger_->log_error("Error while substituting parameters in property '{}': {}", property_from_processor.getName(), e.what());
+    throw;
   } catch (const std::exception& e) {
     logger_->log_error("Fetching property failed with an exception of {}", e.what());
     logger_->log_error("Invalid conversion for field {}. Value {}", property_from_processor.getName(), property_value_node.getDebugString());
@@ -685,11 +749,12 @@ PropertyValue StructuredConfiguration::getValidatedProcessorPropertyForDefaultTy
   return defaultValue;
 }
 
-void StructuredConfiguration::parseSingleProperty(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& processor) {
+void StructuredConfiguration::parseSingleProperty(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& processor,
+    ParameterContext* parameter_context) {
   core::Property myProp(property_name, "", "");
   processor.getProperty(property_name, myProp);
 
-  const PropertyValue coercedValue = getValidatedProcessorPropertyForDefaultTypeInfo(myProp, property_value_node);
+  PropertyValue coercedValue = getValidatedProcessorPropertyForDefaultTypeInfo(myProp, property_value_node, parameter_context);
 
   bool property_set = false;
   try {
@@ -704,7 +769,7 @@ void StructuredConfiguration::parseSingleProperty(const std::string& property_na
     throw;
   }
   if (!property_set) {
-    const auto rawValueString = property_value_node.getScalarAsString().value();
+    const auto rawValueString = coercedValue.getValue()->getStringValue();
     auto proc = dynamic_cast<core::Connectable*>(&processor);
     if (proc) {
       logger_->log_warn("Received property {} but is not one of the properties for {}. Attempting to add as dynamic property.", property_name, proc->getName());
@@ -719,25 +784,27 @@ void StructuredConfiguration::parseSingleProperty(const std::string& property_na
   }
 }
 
-void StructuredConfiguration::parsePropertyNodeElement(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& processor) {
+void StructuredConfiguration::parsePropertyNodeElement(const std::string& property_name, const Node& property_value_node, core::ConfigurableComponent& processor,
+    ParameterContext* parameter_context) {
   logger_->log_trace("Encountered {}", property_name);
   if (!property_value_node || property_value_node.isNull()) {
     return;
   }
   if (property_value_node.isSequence()) {
-    parsePropertyValueSequence(property_name, property_value_node, processor);
+    parsePropertyValueSequence(property_name, property_value_node, processor, parameter_context);
   } else {
-    parseSingleProperty(property_name, property_value_node, processor);
+    parseSingleProperty(property_name, property_value_node, processor, parameter_context);
   }
 }
 
-void StructuredConfiguration::parsePropertiesNode(const Node& properties_node, core::ConfigurableComponent& component, const std::string& component_name) {
+void StructuredConfiguration::parsePropertiesNode(const Node& properties_node, core::ConfigurableComponent& component, const std::string& component_name,
+    ParameterContext* parameter_context) {
   // Treat generically as a node so we can perform inspection on entries to ensure they are populated
   logger_->log_trace("Entered {}", component_name);
   for (const auto& property_node : properties_node) {
     const auto propertyName = property_node.first.getString().value();
     const Node propertyValueNode = property_node.second;
-    parsePropertyNodeElement(propertyName, propertyValueNode, component);
+    parsePropertyNodeElement(propertyName, propertyValueNode, component, parameter_context);
   }
 
   validateComponentProperties(component, component_name, properties_node.getPath());
@@ -799,6 +866,21 @@ void StructuredConfiguration::parsePorts(const flow::Node& node, core::ProcessGr
   }
 }
 
+void StructuredConfiguration::parseParameterContext(const flow::Node& node, core::ProcessGroup& parent) {
+  if (!node) {
+    return;
+  }
+
+  auto parameter_context_name = node.getString().value();
+  if (parameter_context_name.empty()) {
+    return;
+  }
+
+  if (parameter_contexts_.find(parameter_context_name) != parameter_contexts_.end()) {
+    parent.setParameterContext(parameter_contexts_.at(parameter_context_name).get());
+  }
+}
+
 
 void StructuredConfiguration::validateComponentProperties(ConfigurableComponent& component, const std::string &component_name, const std::string &section) const {
   const auto &component_properties = component.getProperties();
@@ -889,8 +971,7 @@ std::string StructuredConfiguration::getRequiredIdField(const Node& node, std::s
 
 std::string StructuredConfiguration::getOptionalField(const Node& node, const std::vector<std::string>& field_name, const std::string& default_value, const std::string& info_message) {
   std::string infoMessage = info_message;
-  auto result = node[field_name];
-  if (!result) {
+  auto logInfoMessage = [&]() {
     if (infoMessage.empty()) {
       // Build a helpful info message for the user to inform them that a default is being used
       infoMessage = "Using default value for optional field '" + utils::string::join(",", field_name) + "'";
@@ -902,9 +983,20 @@ std::string StructuredConfiguration::getOptionalField(const Node& node, const st
       infoMessage += default_value;
     }
     logger_->log_info("{}", infoMessage);
+  };
+  auto result = node[field_name];
+  if (!result) {
+    logInfoMessage();
     return default_value;
   }
 
+  if (result.isSequence()) {
+    if (result.empty()) {
+      logInfoMessage();
+      return default_value;
+    }
+    return (*result.begin()).getString().value();
+  }
   return result.getString().value();
 }
 
@@ -917,7 +1009,7 @@ void StructuredConfiguration::addNewId(const std::string& uuid) {
 
 std::string StructuredConfiguration::serialize(const core::ProcessGroup& process_group) {
   gsl_Expects(flow_serializer_);
-  return flow_serializer_->serialize(process_group, schema_, sensitive_properties_encryptor_, {});
+  return flow_serializer_->serialize(process_group, schema_, sensitive_values_encryptor_, {});
 }
 
 }  // namespace org::apache::nifi::minifi::core::flow
