@@ -99,9 +99,10 @@ void LogMetricsPublisher::loadMetricNodes() {
     metric_classes_str = configuration_->get(minifi::Configuration::nifi_metrics_publisher_metrics);
   }
   if (metric_classes_str && !metric_classes_str->empty()) {
-    auto metric_classes = utils::string::split(*metric_classes_str, ",");
+    auto metric_classes = utils::string::splitAndTrimRemovingEmpty(*metric_classes_str, ",");
+    std::unordered_set<std::string> unique_metric_classes{metric_classes.begin(), metric_classes.end()};
     std::lock_guard<std::mutex> lock(response_nodes_mutex_);
-    for (const std::string& clazz : metric_classes) {
+    for (const std::string& clazz : unique_metric_classes) {
       auto loaded_response_nodes = response_node_loader_->loadResponseNodes(clazz);
       if (loaded_response_nodes.empty()) {
         logger_->log_warn("Metric class '{}' could not be loaded.", clazz);
