@@ -18,20 +18,27 @@
 
 #include "core/state/nodes/BuildInformation.h"
 #include "core/Resource.h"
+#include "agent/agent_version.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace state {
-namespace response {
+namespace org::apache::nifi::minifi::state::response {
+
+std::vector<SerializedResponseNode> BuildInformation::serialize() {
+  return {
+    {.name = "build_version", .value = AgentBuild::VERSION},
+    {.name = "build_rev", .value = AgentBuild::BUILD_REV},
+    {.name = "build_date", .value = AgentBuild::BUILD_DATE},
+    {
+      .name = "compiler",
+      .children = {
+        {.name = "compiler_command", .value = AgentBuild::COMPILER},
+        {.name = "compiler_version", .value = AgentBuild::COMPILER_VERSION},
+        {.name = "compiler_flags", .value = AgentBuild::COMPILER_FLAGS},
+      }
+    },
+    {.name = "device_id", .value = AgentBuild::BUILD_IDENTIFIER}
+  };
+}
 
 REGISTER_RESOURCE(BuildInformation, DescriptionOnly);
 
-}  // namespace response
-}  // namespace state
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-
+}  // namespace org::apache::nifi::minifi::state::response
