@@ -25,6 +25,7 @@
 #include "core/state/nodes/QueueMetrics.h"
 #include "core/state/nodes/AgentInformation.h"
 #include "core/state/nodes/ConfigurationChecksums.h"
+#include "core/state/nodes/AssetInformation.h"
 #include "utils/gsl.h"
 #include "utils/RegexUtils.h"
 #include "utils/StringUtils.h"
@@ -33,13 +34,18 @@
 namespace org::apache::nifi::minifi::state::response {
 
 ResponseNodeLoader::ResponseNodeLoader(std::shared_ptr<Configure> configuration, std::vector<std::shared_ptr<core::RepositoryMetricsSource>> repository_metric_sources,
-  std::shared_ptr<core::FlowConfiguration> flow_configuration)
+  std::shared_ptr<core::FlowConfiguration> flow_configuration, utils::file::AssetManager* asset_manager)
     : configuration_(std::move(configuration)),
       repository_metric_sources_(std::move(repository_metric_sources)),
-      flow_configuration_(std::move(flow_configuration)) {
+      flow_configuration_(std::move(flow_configuration)),
+      asset_manager_(asset_manager) {
 }
 
 void ResponseNodeLoader::clearConfigRoot() {
+  {
+    std::lock_guard<std::mutex> guard(initialization_mutex_);
+    initialized_metrics_.clear();
+  }
   {
     std::lock_guard<std::mutex> guard(system_metrics_mutex_);
     system_metrics_.clear();
@@ -165,7 +171,13 @@ void ResponseNodeLoader::initializeAgentMonitor(const SharedResponseNode& respon
 void ResponseNodeLoader::initializeAgentNode(const SharedResponseNode& response_node) const {
   auto agent_node = dynamic_cast<state::response::AgentNode*>(response_node.get());
   if (agent_node != nullptr && controller_ != nullptr) {
-    agent_node->setUpdatePolicyController(std::static_pointer_cast<controllers::UpdatePolicyControllerService>(controller_->getControllerService(c2::UPDATE_NAME)).get());
+    if (auto service = controller_->getControllerService(c2::UPDATE_NAME)) {
+      if (auto update_service = std::dynamic_pointer_cast<controllers::UpdatePolicyControllerService>(service)) {
+        agent_node->setUpdatePolicyController(update_service.get());
+      } else {
+        logger_->log_warn("Found controller service with name '{}', but it is not an UpdatePolicyControllerService", c2::UPDATE_NAME);
+      }
+    }
   }
   if (agent_node != nullptr) {
     agent_node->setConfigurationReader([this](const std::string& key){
@@ -194,9 +206,16 @@ void ResponseNodeLoader::initializeConfigurationChecksums(const SharedResponseNo
   }
 }
 
-void ResponseNodeLoader::initializeFlowMonitor(const SharedResponseNode& response_node) const {
-  auto flowMonitor = dynamic_cast<state::response::FlowMonitor*>(response_node.get());
-  if (flowMonitor == nullptr) {
+void ResponseNodeLoader::initializeAssetInformation(const SharedResponseNode& response_node) const {
+  auto asset_info = dynamic_cast<state::response::AssetInformation*>(response_node.get());
+  if (asset_info) {
+    asset_info->setAssetManager(asset_manager_);
+  }
+}
+
+void ResponseNodeLoader::initializeFlowInformation(const SharedResponseNode& response_node) const {
+  auto flow_information = dynamic_cast<state::response::FlowInformation*>(response_node.get());
+  if (flow_information == nullptr) {
     return;
   }
 
@@ -207,11 +226,17 @@ void ResponseNodeLoader::initializeFlowMonitor(const SharedResponseNode& respons
   }
 
   for (auto &con : connections) {
-    flowMonitor->updateConnection(con.second);
+    flow_information->updateConnection(con.second);
   }
-  flowMonitor->setStateMonitor(update_sink_);
+  flow_information->setStateMonitor(update_sink_);
   if (flow_configuration_) {
-    flowMonitor->setFlowVersion(flow_configuration_->getFlowVersion());
+    flow_information->setFlowVersion(flow_configuration_->getFlowVersion());
+  }
+
+  if (root_) {
+    std::vector<core::Processor*> processors;
+    root_->getAllProcessors(processors);
+    flow_information->setProcessors(processors);
   }
 }
 
@@ -222,7 +247,11 @@ std::vector<SharedResponseNode> ResponseNodeLoader::loadResponseNodes(const std:
     return {};
   }
 
+  std::lock_guard<std::mutex> guard(initialization_mutex_);
   for (const auto& response_node : response_nodes) {
+    if (initialized_metrics_.contains(response_node->getName())) {
+      continue;
+    }
     initializeRepositoryMetrics(response_node);
     initializeQueueMetrics(response_node);
     initializeAgentIdentifier(response_node);
@@ -230,7 +259,9 @@ std::vector<SharedResponseNode> ResponseNodeLoader::loadResponseNodes(const std:
     initializeAgentNode(response_node);
     initializeAgentStatus(response_node);
     initializeConfigurationChecksums(response_node);
-    initializeFlowMonitor(response_node);
+    initializeFlowInformation(response_node);
+    initializeAssetInformation(response_node);
+    initialized_metrics_.insert(response_node->getName());
   }
   return response_nodes;
 }
@@ -275,7 +306,13 @@ void ResponseNodeLoader::setStateMonitor(state::StateMonitor* update_sink) {
 state::response::NodeReporter::ReportedNode ResponseNodeLoader::getAgentManifest() const {
   state::response::AgentInformation agentInfo("agentInfo");
   if (controller_) {
-    agentInfo.setUpdatePolicyController(std::static_pointer_cast<controllers::UpdatePolicyControllerService>(controller_->getControllerService(c2::UPDATE_NAME)).get());
+    if (auto service = controller_->getControllerService(c2::UPDATE_NAME)) {
+      if (auto update_service = std::dynamic_pointer_cast<controllers::UpdatePolicyControllerService>(service)) {
+        agentInfo.setUpdatePolicyController(update_service.get());
+      } else {
+        logger_->log_warn("Found controller service with name '{}', but it is not an UpdatePolicyControllerService", c2::UPDATE_NAME);
+      }
+    }
   }
   agentInfo.setAgentIdentificationProvider(configuration_);
   agentInfo.setConfigurationReader([this](const std::string& key){
