@@ -37,20 +37,20 @@ namespace org::apache::nifi::minifi::provenance {
 std::shared_ptr<utils::IdGenerator> ProvenanceEventRecord::id_generator_ = utils::IdGenerator::getIdGenerator();
 std::shared_ptr<core::logging::Logger> ProvenanceEventRecord::logger_ = core::logging::LoggerFactory<ProvenanceEventRecord>::getLogger();
 
-const char *ProvenanceEventRecord::ProvenanceEventTypeStr[REPLAY + 1] = { "CREATE", "RECEIVE", "FETCH", "SEND", "DOWNLOAD", "DROP", "EXPIRE", "FORK", "JOIN", "CLONE", "CONTENT_MODIFIED",
-    "ATTRIBUTES_MODIFIED", "ROUTE", "ADDINFO", "REPLAY" };
+const char *ProvenanceEventRecord::ProvenanceEventTypeStr[REPLAY + 1] = { "CREATE", "RECEIVE", "FETCH", "SEND", "DOWNLOAD",  // NOLINT(cppcoreguidelines-avoid-c-arrays)
+    "DROP", "EXPIRE", "FORK", "JOIN", "CLONE", "CONTENT_MODIFIED", "ATTRIBUTES_MODIFIED", "ROUTE", "ADDINFO", "REPLAY" };
 
 ProvenanceEventRecord::ProvenanceEventRecord(ProvenanceEventRecord::ProvenanceEventType event, std::string componentId, std::string componentType)
     : core::SerializableComponent(core::className<ProvenanceEventRecord>()),
       _eventType(event),
+      _eventTime(std::chrono::system_clock::now()),
       _componentId(std::move(componentId)),
-      _componentType(std::move(componentType)),
-      _eventTime(std::chrono::system_clock::now()) {
+      _componentType(std::move(componentType)) {
 }
 
 bool ProvenanceEventRecord::loadFromRepository(const std::shared_ptr<core::Repository> &repo) {
   std::string value;
-  bool ret;
+  bool ret = false;
 
   if (nullptr == repo || uuid_.isNil()) {
     logger_->log_error("Repo could not be assigned");
@@ -59,10 +59,10 @@ bool ProvenanceEventRecord::loadFromRepository(const std::shared_ptr<core::Repos
   ret = repo->Get(getUUIDStr(), value);
 
   if (!ret) {
-    logger_->log_error("NiFi Provenance Store event %s can not be found", getUUIDStr());
+    logger_->log_error("NiFi Provenance Store event {} can not be found", getUUIDStr());
     return false;
   } else {
-    logger_->log_debug("NiFi Provenance Read event %s", getUUIDStr());
+    logger_->log_debug("NiFi Provenance Read event {}", getUUIDStr());
   }
 
   org::apache::nifi::minifi::io::BufferStream stream(value);
@@ -70,9 +70,9 @@ bool ProvenanceEventRecord::loadFromRepository(const std::shared_ptr<core::Repos
   ret = deserialize(stream);
 
   if (ret) {
-    logger_->log_debug("NiFi Provenance retrieve event %s size %llu eventType %d success", getUUIDStr(), stream.size(), _eventType);
+    logger_->log_debug("NiFi Provenance retrieve event {} size {} eventType {} success", getUUIDStr(), stream.size(), magic_enum::enum_name(_eventType));
   } else {
-    logger_->log_debug("NiFi Provenance retrieve event %s size %llu eventType %d fail", getUUIDStr(), stream.size(), _eventType);
+    logger_->log_debug("NiFi Provenance retrieve event {} size {} eventType {} fail", getUUIDStr(), stream.size(), magic_enum::enum_name(_eventType));
   }
 
   return ret;
@@ -249,7 +249,7 @@ bool ProvenanceEventRecord::deserialize(io::InputStream &input_stream) {
     }
   }
 
-  uint32_t eventType;
+  uint32_t eventType = 0;
   {
     const auto ret = input_stream.read(eventType);
     if (ret != 4) {
@@ -257,9 +257,14 @@ bool ProvenanceEventRecord::deserialize(io::InputStream &input_stream) {
     }
   }
 
-  this->_eventType = (ProvenanceEventRecord::ProvenanceEventType) eventType;
+  if (auto event_type_opt = magic_enum::enum_cast<ProvenanceEventRecord::ProvenanceEventType>(eventType)) {
+    _eventType = *event_type_opt;
+  } else {
+    return false;
+  }
+
   {
-    uint64_t event_time_in_ms;
+    uint64_t event_time_in_ms = 0;
     const auto ret = input_stream.read(event_time_in_ms);
     if (ret != 8) {
       return false;
@@ -268,7 +273,7 @@ bool ProvenanceEventRecord::deserialize(io::InputStream &input_stream) {
   }
 
   {
-    uint64_t entry_date_in_ms;
+    uint64_t entry_date_in_ms = 0;
     const auto ret = input_stream.read(entry_date_in_ms);
     if (ret != 8) {
       return false;
@@ -277,7 +282,7 @@ bool ProvenanceEventRecord::deserialize(io::InputStream &input_stream) {
   }
 
   {
-    uint64_t event_duration_ms;
+    uint64_t event_duration_ms = 0;
     const auto ret = input_stream.read(event_duration_ms);
     if (ret != 8) {
       return false;
@@ -286,7 +291,7 @@ bool ProvenanceEventRecord::deserialize(io::InputStream &input_stream) {
   }
 
   {
-    uint64_t lineage_start_date_in_ms;
+    uint64_t lineage_start_date_in_ms = 0;
     const auto ret = input_stream.read(lineage_start_date_in_ms);
     if (ret != 8) {
       return false;
@@ -460,8 +465,8 @@ void ProvenanceReporter::commit() {
   repo_->MultiPut(flowData);
 }
 
-void ProvenanceReporter::create(const std::shared_ptr<core::FlowFile>& flow, const std::string& detail) {
-  auto event = allocate(ProvenanceEventRecord::CREATE, flow);
+void ProvenanceReporter::create(const core::FlowFile& flow_file, const std::string& detail) {
+  auto event = allocate(ProvenanceEventRecord::CREATE, flow_file);
 
   if (event) {
     event->setDetails(detail);
@@ -469,8 +474,8 @@ void ProvenanceReporter::create(const std::shared_ptr<core::FlowFile>& flow, con
   }
 }
 
-void ProvenanceReporter::route(const std::shared_ptr<core::FlowFile>& flow, const core::Relationship& relation, const std::string& detail, std::chrono::milliseconds processingDuration) {
-  auto event = allocate(ProvenanceEventRecord::ROUTE, flow);
+void ProvenanceReporter::route(const core::FlowFile& flow_file, const core::Relationship& relation, const std::string& detail, std::chrono::milliseconds processingDuration) {
+  auto event = allocate(ProvenanceEventRecord::ROUTE, flow_file);
 
   if (event) {
     event->setDetails(detail);
@@ -480,8 +485,8 @@ void ProvenanceReporter::route(const std::shared_ptr<core::FlowFile>& flow, cons
   }
 }
 
-void ProvenanceReporter::modifyAttributes(const std::shared_ptr<core::FlowFile>& flow, const std::string& detail) {
-  auto event = allocate(ProvenanceEventRecord::ATTRIBUTES_MODIFIED, flow);
+void ProvenanceReporter::modifyAttributes(const core::FlowFile& flow_file, const std::string& detail) {
+  auto event = allocate(ProvenanceEventRecord::ATTRIBUTES_MODIFIED, flow_file);
 
   if (event) {
     event->setDetails(detail);
@@ -489,8 +494,8 @@ void ProvenanceReporter::modifyAttributes(const std::shared_ptr<core::FlowFile>&
   }
 }
 
-void ProvenanceReporter::modifyContent(const std::shared_ptr<core::FlowFile>& flow, const std::string& detail, std::chrono::milliseconds processingDuration) {
-  auto event = allocate(ProvenanceEventRecord::CONTENT_MODIFIED, flow);
+void ProvenanceReporter::modifyContent(const core::FlowFile& flow_file, const std::string& detail, std::chrono::milliseconds processingDuration) {
+  auto event = allocate(ProvenanceEventRecord::CONTENT_MODIFIED, flow_file);
 
   if (event) {
     event->setDetails(detail);
@@ -499,7 +504,7 @@ void ProvenanceReporter::modifyContent(const std::shared_ptr<core::FlowFile>& fl
   }
 }
 
-void ProvenanceReporter::clone(const std::shared_ptr<core::FlowFile>& parent, const std::shared_ptr<core::FlowFile>& child) {
+void ProvenanceReporter::clone(const core::FlowFile& parent, const core::FlowFile& child) {
   auto event = allocate(ProvenanceEventRecord::CLONE, parent);
 
   if (event) {
@@ -509,38 +514,8 @@ void ProvenanceReporter::clone(const std::shared_ptr<core::FlowFile>& parent, co
   }
 }
 
-void ProvenanceReporter::join(const std::vector<std::shared_ptr<core::FlowFile>>& parents, const std::shared_ptr<core::FlowFile>& child,
-    const std::string& detail, std::chrono::milliseconds processingDuration) {
-  auto event = allocate(ProvenanceEventRecord::JOIN, child);
-
-  if (event) {
-    event->addChildFlowFile(child);
-    for (const auto& parent : parents) {
-      event->addParentFlowFile(parent);
-    }
-    event->setDetails(detail);
-    event->setEventDuration(processingDuration);
-    add(event);
-  }
-}
-
-void ProvenanceReporter::fork(const std::vector<std::shared_ptr<core::FlowFile>>& children, const std::shared_ptr<core::FlowFile>& parent,
-    const std::string& detail, std::chrono::milliseconds processingDuration) {
-  auto event = allocate(ProvenanceEventRecord::FORK, parent);
-
-  if (event) {
-    event->addParentFlowFile(parent);
-    for (const auto& child : children) {
-      event->addChildFlowFile(child);
-    }
-    event->setDetails(detail);
-    event->setEventDuration(processingDuration);
-    add(event);
-  }
-}
-
-void ProvenanceReporter::expire(const std::shared_ptr<core::FlowFile>& flow, const std::string& detail) {
-  auto event = allocate(ProvenanceEventRecord::EXPIRE, flow);
+void ProvenanceReporter::expire(const core::FlowFile& flow_file, const std::string& detail) {
+  auto event = allocate(ProvenanceEventRecord::EXPIRE, flow_file);
 
   if (event) {
     event->setDetails(detail);
@@ -548,8 +523,8 @@ void ProvenanceReporter::expire(const std::shared_ptr<core::FlowFile>& flow, con
   }
 }
 
-void ProvenanceReporter::drop(const std::shared_ptr<core::FlowFile>& flow, const std::string& reason) {
-  auto event = allocate(ProvenanceEventRecord::DROP, flow);
+void ProvenanceReporter::drop(const core::FlowFile& flow_file, const std::string& reason) {
+  auto event = allocate(ProvenanceEventRecord::DROP, flow_file);
 
   if (event) {
     std::string dropReason = "Discard reason: " + reason;
@@ -558,8 +533,8 @@ void ProvenanceReporter::drop(const std::shared_ptr<core::FlowFile>& flow, const
   }
 }
 
-void ProvenanceReporter::send(const std::shared_ptr<core::FlowFile>& flow, const std::string& transitUri, const std::string& detail, std::chrono::milliseconds processingDuration, bool force) {
-  auto event = allocate(ProvenanceEventRecord::SEND, flow);
+void ProvenanceReporter::send(const core::FlowFile& flow_file, const std::string& transitUri, const std::string& detail, std::chrono::milliseconds processingDuration, bool force) {
+  auto event = allocate(ProvenanceEventRecord::SEND, flow_file);
 
   if (event) {
     event->setTransitUri(transitUri);
@@ -574,12 +549,12 @@ void ProvenanceReporter::send(const std::shared_ptr<core::FlowFile>& flow, const
   }
 }
 
-void ProvenanceReporter::receive(const std::shared_ptr<core::FlowFile>& flow,
+void ProvenanceReporter::receive(const core::FlowFile& flow_file,
                                  const std::string& transitUri,
                                  const std::string& sourceSystemFlowFileIdentifier,
                                  const std::string& detail,
                                  std::chrono::milliseconds processingDuration) {
-  auto event = allocate(ProvenanceEventRecord::RECEIVE, flow);
+  auto event = allocate(ProvenanceEventRecord::RECEIVE, flow_file);
 
   if (event) {
     event->setTransitUri(transitUri);
@@ -590,8 +565,8 @@ void ProvenanceReporter::receive(const std::shared_ptr<core::FlowFile>& flow,
   }
 }
 
-void ProvenanceReporter::fetch(const std::shared_ptr<core::FlowFile>& flow, const std::string& transitUri, const std::string& detail, std::chrono::milliseconds processingDuration) {
-  auto event = allocate(ProvenanceEventRecord::FETCH, flow);
+void ProvenanceReporter::fetch(const core::FlowFile& flow_file, const std::string& transitUri, const std::string& detail, std::chrono::milliseconds processingDuration) {
+  auto event = allocate(ProvenanceEventRecord::FETCH, flow_file);
 
   if (event) {
     event->setTransitUri(transitUri);
