@@ -24,9 +24,8 @@ namespace apache {
 namespace nifi {
 namespace minifi {
 
-int PayloadSerializer::serialize(const std::shared_ptr<core::FlowFile>& flowFile, const std::shared_ptr<io::OutputStream>& out) {
-  InputStreamPipe pipe(out);
-  return reader_(flowFile, &pipe);
+int64_t PayloadSerializer::serialize(const std::shared_ptr<core::FlowFile>& flowFile, const std::shared_ptr<io::OutputStream>& out) {
+  return reader_(flowFile, InputStreamPipe{*out});
 }
 
 } /* namespace minifi */
