@@ -18,11 +18,10 @@
 #include "utils/net/Socket.h"
 #include "core/logging/LoggerConfiguration.h"
 #ifdef WIN32
-#include <Windows.h>
-#include <winsock2.h>
 #include <iphlpapi.h>
-#include <WS2tcpip.h>
 #pragma comment(lib, "IPHLPAPI.lib")
+#include "utils/OsUtils.h"
+#include "utils/UnicodeConversion.h"
 #else
 #include <unistd.h>
 #include <netinet/in.h>
@@ -37,19 +36,11 @@ namespace org::apache::nifi::minifi::utils {
 std::shared_ptr<core::logging::Logger> NetworkInterfaceInfo::logger_ = core::logging::LoggerFactory<NetworkInterfaceInfo>::getLogger();
 
 #ifdef WIN32
-namespace {
-std::string utf8_encode(const std::wstring& wstr) {
-  if (wstr.empty())
-    return std::string();
-  int size_needed = WideCharToMultiByte(CP_UTF8, 0, wstr.c_str(), -1, nullptr, 0, nullptr, nullptr);
-  std::string result_string(size_needed, 0);
-  WideCharToMultiByte(CP_UTF8, 0, wstr.c_str(), -1, result_string.data(), size_needed, nullptr, nullptr);
-  return result_string;
-}
-}
 
-NetworkInterfaceInfo::NetworkInterfaceInfo(const IP_ADAPTER_ADDRESSES* adapter) {
-  name_ = utf8_encode(adapter->FriendlyName);
+NetworkInterfaceInfo::NetworkInterfaceInfo(const IP_ADAPTER_ADDRESSES* adapter)
+    : name_(to_string(adapter->FriendlyName)),
+      running_(adapter->OperStatus == IfOperStatusUp),
+      loopback_(adapter->IfType == IF_TYPE_SOFTWARE_LOOPBACK) {
   for (auto unicast_address = adapter->FirstUnicastAddress; unicast_address != nullptr; unicast_address = unicast_address->Next) {
     if (unicast_address->Address.lpSockaddr->sa_family == AF_INET) {
       ip_v4_addresses_.push_back(net::sockaddr_ntop(unicast_address->Address.lpSockaddr));
@@ -57,19 +48,17 @@ NetworkInterfaceInfo::NetworkInterfaceInfo(const IP_ADAPTER_ADDRESSES* adapter)
       ip_v6_addresses_.push_back(net::sockaddr_ntop(unicast_address->Address.lpSockaddr));
     }
   }
-  running_ = adapter->OperStatus == IfOperStatusUp;
-  loopback_ = adapter->IfType == IF_TYPE_SOFTWARE_LOOPBACK;
 }
 #else
-NetworkInterfaceInfo::NetworkInterfaceInfo(const struct ifaddrs* ifa) {
-  name_ = ifa->ifa_name;
+NetworkInterfaceInfo::NetworkInterfaceInfo(const struct ifaddrs* ifa)
+    : name_(ifa->ifa_name),
+      running_(ifa->ifa_flags & IFF_RUNNING),
+      loopback_(ifa->ifa_flags & IFF_LOOPBACK) {
   if (ifa->ifa_addr->sa_family == AF_INET) {
     ip_v4_addresses_.push_back(net::sockaddr_ntop(ifa->ifa_addr));
   } else if (ifa->ifa_addr->sa_family == AF_INET6) {
     ip_v6_addresses_.push_back(net::sockaddr_ntop(ifa->ifa_addr));
   }
-  running_ = (ifa->ifa_flags & IFF_RUNNING);
-  loopback_ = (ifa->ifa_flags & IFF_LOOPBACK);
 }
 #endif
 
@@ -90,14 +79,14 @@ std::vector<NetworkInterfaceInfo> NetworkInterfaceInfo::getNetworkInterfaceInfos
   ULONG buffer_length = sizeof(IP_ADAPTER_ADDRESSES);
   auto get_adapters_err = GetAdaptersAddresses(0, 0, nullptr, nullptr, &buffer_length);
   if (ERROR_BUFFER_OVERFLOW != get_adapters_err) {
-    logger_->log_error("GetAdaptersAddresses failed: %lu", get_adapters_err);
+    logger_->log_error("GetAdaptersAddresses failed: {}", get_adapters_err);
     return network_adapters;
   }
   std::vector<char> bytes(buffer_length, 0);
-  IP_ADAPTER_ADDRESSES* adapter = reinterpret_cast<IP_ADAPTER_ADDRESSES*>(bytes.data());
+  auto* adapter = reinterpret_cast<IP_ADAPTER_ADDRESSES*>(bytes.data());
   get_adapters_err = GetAdaptersAddresses(0, 0, nullptr, adapter, &buffer_length);
   if (NO_ERROR != get_adapters_err) {
-    logger_->log_error("GetAdaptersAddresses failed: %lu", get_adapters_err);
+    logger_->log_error("GetAdaptersAddresses failed: {}", get_adapters_err);
     return network_adapters;
   }
   while (adapter != nullptr) {
@@ -118,7 +107,7 @@ std::vector<NetworkInterfaceInfo> NetworkInterfaceInfo::getNetworkInterfaceInfos
   struct ifaddrs* interface_addresses = nullptr;
   auto cleanup = gsl::finally([&interface_addresses] { freeifaddrs(interface_addresses); });
   if (getifaddrs(&interface_addresses) == -1) {
-    logger_->log_error("getifaddrs failed: %s", std::strerror(errno));
+    logger_->log_error("getifaddrs failed: {}", std::strerror(errno));
     return network_adapters;
   }
 
