@@ -15,27 +15,27 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
-#undef NDEBUG
-#include <cassert>
-#include "IntegrationBase.h"
+#include "integration/IntegrationBase.h"
 #include "core/logging/Logger.h"
 #include "core/Scheduling.h"
 #include "core/state/ProcessorController.h"
-#include "../TestBase.h"
+#include "unit/TestBase.h"
 #include "../../../extensions/test-processors/KamikazeProcessor.h"
 #include "utils/StringUtils.h"
-#include "utils/IntegrationTestUtils.h"
+#include "unit/TestUtils.h"
+#include "unit/Catch.h"
+
+namespace org::apache::nifi::minifi::test {
 
 /*Verify behavior in case exceptions are thrown in onSchedule or onTrigger functions
  * KamikazeProcessor is a test processor to trigger errors in these functions */
 class KamikazeErrorHandlingTests : public IntegrationBase {
  public:
   void runAssertions() override {
-    using org::apache::nifi::minifi::utils::verifyEventHappenedInPollTime;
-    assert(verifyEventHappenedInPollTime(wait_time_, [&] {
+    using minifi::test::utils::verifyEventHappenedInPollTime;
+    REQUIRE(verifyEventHappenedInPollTime(wait_time_, [&] {
       const std::string logs = LogTestController::getInstance().getLogs();
-      const auto result = utils::string::countOccurrences(logs, minifi::processors::KamikazeProcessor::OnScheduleExceptionStr);
+      const auto result = minifi::utils::string::countOccurrences(logs, minifi::processors::KamikazeProcessor::OnScheduleExceptionStr);
       const int occurrences = result.second;
       return 1 < occurrences;
     }));
@@ -48,7 +48,7 @@ class KamikazeErrorHandlingTests : public IntegrationBase {
 
     const bool test_success = verifyEventHappenedInPollTime(std::chrono::milliseconds(wait_time_), [&] {
       const std::string logs = LogTestController::getInstance().getLogs();
-      const auto result = utils::string::countOccurrences(logs, minifi::processors::KamikazeProcessor::OnScheduleExceptionStr);
+      const auto result = minifi::utils::string::countOccurrences(logs, minifi::processors::KamikazeProcessor::OnScheduleExceptionStr);
       size_t last_pos = result.first;
       for (const std::string& msg : must_appear_byorder_msgs) {
         last_pos = logs.find(msg, last_pos);
@@ -58,9 +58,9 @@ class KamikazeErrorHandlingTests : public IntegrationBase {
       }
       return true;
     });
-    assert(test_success);
+    REQUIRE(test_success);
 
-    assert(LogTestController::getInstance().getLogs().find(minifi::processors::KamikazeProcessor::OnTriggerLogStr) == std::string::npos);
+    REQUIRE(LogTestController::getInstance().getLogs().find(minifi::processors::KamikazeProcessor::OnTriggerLogStr) == std::string::npos);
   }
 
   void testSetup() override {
@@ -84,28 +84,28 @@ class EventDriverScheduleErrorHandlingTests: public IntegrationBase {
      * that most probably means a breaking change. */
     size_t controllerVecIdx = 0;
 
-    fc.executeOnAllComponents([&controllerVecIdx](org::apache::nifi::minifi::state::StateController& component){
+    fc.executeOnAllComponents([&controllerVecIdx](minifi::state::StateController& component){
       if (controllerVecIdx == 1) {
-        assert(component.getComponentName() == "FlowController");
+        REQUIRE(component.getComponentName() == "FlowController");
       } else if (controllerVecIdx == 0) {
-        assert(component.getComponentName() == "kamikaze");
+        REQUIRE(component.getComponentName() == "kamikaze");
 
-        auto process_controller = dynamic_cast<org::apache::nifi::minifi::state::ProcessorController*>(&component);
-        assert(process_controller != nullptr);
+        auto process_controller = dynamic_cast<minifi::state::ProcessorController*>(&component);
+        REQUIRE(process_controller != nullptr);
 
-        process_controller->getProcessor().setSchedulingStrategy(org::apache::nifi::minifi::core::SchedulingStrategy::EVENT_DRIVEN);
+        process_controller->getProcessor().setSchedulingStrategy(minifi::core::SchedulingStrategy::EVENT_DRIVEN);
       }
 
       ++controllerVecIdx;
     });
 
     // check controller vector size
-    assert(controllerVecIdx == 2);
+    REQUIRE(controllerVecIdx == 2);
   }
 
   void runAssertions() override {
     std::string logs = LogTestController::getInstance().getLogs();
-    assert(logs.find("EventDrivenSchedulingAgent cannot schedule processor without incoming connection!") != std::string::npos);
+    REQUIRE(logs.find("EventDrivenSchedulingAgent cannot schedule processor without incoming connection!") != std::string::npos);
   }
 
   void testSetup() override {
@@ -114,19 +114,18 @@ class EventDriverScheduleErrorHandlingTests: public IntegrationBase {
   }
 };
 
-int main(int argc, char **argv) {
-  std::string test_file_location;
-  std::string url;
-  if (argc > 1) {
-    test_file_location = argv[1];
-  }
-
+TEST_CASE("KamikazeErrorHandlingTests", "[OnScheduleErrorHandlingTests]") {
   KamikazeErrorHandlingTests harness_kamikaze;
 
+  const auto test_file_location = std::filesystem::path(TEST_RESOURCES) / "TestOnScheduleRetry.yml";
   harness_kamikaze.run(test_file_location);
-
-  EventDriverScheduleErrorHandlingTests harness_eventdrivenerror;
-  harness_eventdrivenerror.run(test_file_location);
-
-  return 0;
 }
+
+TEST_CASE("EventDriverScheduleErrorHandlingTests", "[OnScheduleErrorHandlingTests]") {
+  EventDriverScheduleErrorHandlingTests harness_eventdrivenerror;
+
+  const auto test_file_location = std::filesystem::path(TEST_RESOURCES) / "TestOnScheduleRetry.yml";
+  harness_eventdrivenerror.run(test_file_location);
+}
+
+}  // namespace org::apache::nifi::minifi::test
