@@ -27,19 +27,19 @@
 #include "FlowFileRecord.h"
 #include "FlowFileRepository.h"
 #include "properties/Configure.h"
-#include "../unit/ProvenanceTestHelper.h"
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/ProvenanceTestHelper.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "catch2/matchers/catch_matchers_string.hpp"
 #include "../../extensions/libarchive/MergeContent.h"
 #include "core/repository/VolatileFlowFileRepository.h"
 #include "../../extensions/rocksdb-repos/DatabaseContentRepository.h"
-#include "utils/IntegrationTestUtils.h"
+#include "unit/TestUtils.h"
 
 using Connection = minifi::Connection;
 using MergeContent = minifi::processors::MergeContent;
 
-using minifi::utils::verifyEventHappenedInPollTime;
+using minifi::test::utils::verifyEventHappenedInPollTime;
 
 namespace {
 
@@ -188,7 +188,7 @@ TEST_CASE("Processors Can Store FlowFiles", "[TestP1]") {
       .configuration = config,
       .path = "",
       .filesystem = std::make_shared<utils::file::FileSystem>(),
-      .sensitive_properties_encryptor = utils::crypto::EncryptionProvider{utils::crypto::XSalsa20Cipher{utils::crypto::XSalsa20Cipher::generateKey()}}
+      .sensitive_values_encryptor = utils::crypto::EncryptionProvider{utils::crypto::XSalsa20Cipher{utils::crypto::XSalsa20Cipher::generateKey()}}
   });
   auto flowController = std::make_shared<minifi::FlowController>(prov_repo, ff_repository, config, std::move(flowConfig), content_repo);
 
@@ -315,7 +315,7 @@ TEST_CASE("Persisted flowFiles are updated on modification", "[TestP1]") {
       .configuration = config,
       .path = "",
       .filesystem = std::make_shared<utils::file::FileSystem>(),
-      .sensitive_properties_encryptor = utils::crypto::EncryptionProvider{utils::crypto::XSalsa20Cipher{utils::crypto::XSalsa20Cipher::generateKey()}}
+      .sensitive_values_encryptor = utils::crypto::EncryptionProvider{utils::crypto::XSalsa20Cipher{utils::crypto::XSalsa20Cipher::generateKey()}}
   });
   auto flowController = std::make_shared<minifi::FlowController>(prov_repo, ff_repository, config, std::move(flowConfig), content_repo);
 
