@@ -21,8 +21,8 @@
 #include <thread>
 #include "utils/SystemCpuUsageTracker.h"
 #include "utils/ProcessCpuUsageTracker.h"
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 
 using namespace std::literals::chrono_literals;
 using steady_clock = std::chrono::steady_clock;
