@@ -20,8 +20,8 @@
 #include <iterator>
 #include <optional>
 #include <string>
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "utils/file/FileSystem.h"
 
 using utils::crypto::EncryptionProvider;
