@@ -18,12 +18,12 @@
 #include <memory>
 #include <thread>
 
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "core/state/LogMetricsPublisher.h"
 #include "core/state/nodes/ResponseNodeLoader.h"
 #include "core/RepositoryFactory.h"
-#include "utils/IntegrationTestUtils.h"
+#include "unit/TestUtils.h"
 #include "utils/file/FileUtils.h"
 
 using namespace std::literals::chrono_literals;
@@ -70,7 +70,7 @@ TEST_CASE_METHOD(LogPublisherTestFixture, "Logging interval property is mandator
   }
   SECTION("Logging interval is set to 2 seconds") {
     configuration_->set(minifi::Configuration::nifi_metrics_publisher_log_metrics_logging_interval, "2s");
-    using org::apache::nifi::minifi::utils::verifyLogLinePresenceInPollTime;
+    using org::apache::nifi::minifi::test::utils::verifyLogLinePresenceInPollTime;
     publisher_.initialize(configuration_, response_node_loader_);
     REQUIRE(verifyLogLinePresenceInPollTime(5s, "Metric logging interval is set to 2000ms"));
   }
@@ -85,7 +85,7 @@ TEST_CASE_METHOD(LogPublisherTestFixture, "Verify empty metrics if no valid metr
   }
   publisher_.initialize(configuration_, response_node_loader_);
   publisher_.loadMetricNodes();
-  using org::apache::nifi::minifi::utils::verifyLogLinePresenceInPollTime;
+  using org::apache::nifi::minifi::test::utils::verifyLogLinePresenceInPollTime;
   REQUIRE(verifyLogLinePresenceInPollTime(5s, "LogMetricsPublisher is configured without any valid metrics!"));
 }
 
@@ -95,10 +95,10 @@ TEST_CASE_METHOD(LogPublisherTestFixture, "Verify multiple metric nodes in logs"
   configuration_->set(Configure::nifi_metrics_publisher_metrics, "RepositoryMetrics,DeviceInfoNode");
   publisher_.initialize(configuration_, response_node_loader_);
   publisher_.loadMetricNodes();
-  using org::apache::nifi::minifi::utils::verifyLogLinePresenceInPollTime;
-  std::string expected_log = R"([info] {
-    "LogMetrics": {
-        "RepositoryMetrics": {
+  using org::apache::nifi::minifi::test::utils::verifyLogLinePresenceInPollTime;
+  std::string expected_log_1 = R"([info] {
+    "LogMetrics": {)";
+  std::string expected_log_2 = R"("RepositoryMetrics": {
             "provenancerepository": {
                 "running": "false",
                 "full": "false",
@@ -117,10 +117,12 @@ TEST_CASE_METHOD(LogPublisherTestFixture, "Verify multiple metric nodes in logs"
                 "rocksDbTableReadersSize": "0",
                 "rocksDbAllMemoryTablesSize": "2048"
             }
-        },
-        "deviceInfo": {
+        })";
+  std::string expected_log_3 = R"("deviceInfo": {
             "identifier":)";
-  REQUIRE(verifyLogLinePresenceInPollTime(5s, expected_log));
+  REQUIRE(verifyLogLinePresenceInPollTime(5s, expected_log_1));
+  REQUIRE(verifyLogLinePresenceInPollTime(5s, expected_log_2));
+  REQUIRE(verifyLogLinePresenceInPollTime(5s, expected_log_3));
 }
 
 TEST_CASE_METHOD(LogPublisherTestFixture, "Verify reloading different metrics", "[LogMetricsPublisher]") {
@@ -129,7 +131,7 @@ TEST_CASE_METHOD(LogPublisherTestFixture, "Verify reloading different metrics",
   configuration_->set(Configure::nifi_metrics_publisher_metrics, "RepositoryMetrics");
   publisher_.initialize(configuration_, response_node_loader_);
   publisher_.loadMetricNodes();
-  using org::apache::nifi::minifi::utils::verifyLogLinePresenceInPollTime;
+  using org::apache::nifi::minifi::test::utils::verifyLogLinePresenceInPollTime;
   std::string expected_log = R"([info] {
     "LogMetrics": {
         "RepositoryMetrics": {
@@ -182,7 +184,7 @@ TEST_CASE_METHOD(LogPublisherTestFixture, "Verify generic and publisher specific
   }
   publisher_.initialize(configuration_, response_node_loader_);
   publisher_.loadMetricNodes();
-  using org::apache::nifi::minifi::utils::verifyLogLinePresenceInPollTime;
+  using org::apache::nifi::minifi::test::utils::verifyLogLinePresenceInPollTime;
   std::string expected_log = R"([info] {
     "LogMetrics": {
         "RepositoryMetrics": {
@@ -217,8 +219,8 @@ TEST_CASE_METHOD(LogPublisherTestFixture, "Verify changing log level property fo
   configuration_->set(Configure::nifi_metrics_publisher_metrics, "RepositoryMetrics");
   publisher_.initialize(configuration_, response_node_loader_);
   publisher_.loadMetricNodes();
-  using org::apache::nifi::minifi::utils::verifyLogLinePresenceInPollTime;
-  std::string expected_log = R"([debug] {
+  using org::apache::nifi::minifi::test::utils::verifyLogLinePresenceInPollTime;
+  std::string expected_log = R"([info] {
     "LogMetrics": {
         "RepositoryMetrics": {
             "provenancerepository": {
