@@ -21,12 +21,12 @@
 #include <vector>
 #include <ctime>
 #include <random>
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "core/logging/LoggerConfiguration.h"
 #include "io/ZlibStream.h"
 #include "StreamPipe.h"
-#include "utils/IntegrationTestUtils.h"
+#include "unit/TestUtils.h"
 #include "utils/span.h"
 #include "utils/net/AsioSocketUtils.h"
 
@@ -220,7 +220,7 @@ class LoggerTestAccessor {
   }
   static bool waitForCompressionToHappen(logging::LoggerConfiguration& log_config) {
     auto sink = log_config.compression_manager_.getSink();
-    return !sink || utils::verifyEventHappenedInPollTime(1s, [&]{ return sink->cached_logs_.itemCount() == 0; });
+    return !sink || minifi::test::utils::verifyEventHappenedInPollTime(1s, [&]{ return sink->cached_logs_.itemCount() == 0; });
   }
   static auto getCompressedLogs(logging::LoggerConfiguration& log_config) {
     return log_config.compression_manager_.getCompressedLogs(std::chrono::milliseconds{0});
@@ -265,7 +265,7 @@ TEST_CASE("Test Compression cache overflow is discarded intermittently", "[ttl10
   for (size_t idx = 0; idx < 10000; ++idx) {
     logger->log_error("Hi there");
   }
-  bool cache_shrunk = utils::verifyEventHappenedInPollTime(std::chrono::seconds{1}, [&] {
+  bool cache_shrunk = minifi::test::utils::verifyEventHappenedInPollTime(std::chrono::seconds{1}, [&] {
     return LoggerTestAccessor::getUncompressedSize(*log_config) <= 10_KiB;
   });
   REQUIRE(cache_shrunk);
@@ -380,7 +380,9 @@ TEST_CASE("Setting max log entry length to unlimited results in unlimited log en
 TEST_CASE("fmt formatting works with the logger") {
   LogTestController::getInstance().setTrace<logging::Logger>();
   std::shared_ptr<logging::Logger> logger = logging::LoggerFactory<logging::Logger>::getLogger();
-  logger->log_critical("{} equals to {}", 1min, 60s);
+  std::chrono::minutes duration{1};
+  std::string formatted_min_duration = fmt::format("{0}m", duration.count());
+  logger->log_critical("{} equals to {}", formatted_min_duration, 60s);
   logger->log_critical("{} in hex is {:#x}", 13, 13);
   logger->log_critical("Unix epoch: {}", std::chrono::system_clock::time_point());
   logger->log_critical("{:%Q %q} equals to {:%Q %q}", 2h, std::chrono::duration_cast<std::chrono::seconds>(2h));
