@@ -16,8 +16,8 @@
  * limitations under the License.
  */
 
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "utils/OptionalUtils.h"
 
 namespace utils = org::apache::nifi::minifi::utils;
