@@ -15,8 +15,8 @@
  * limitations under the License.
  */
 
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "core/ConfigurableComponent.h"
 #include "core/PropertyDefinitionBuilder.h"
 #include "utils/PropertyErrors.h"
