@@ -22,8 +22,8 @@
 #include <random>
 #include <string>
 #include <vector>
-#include "../TestBase.h"
-#include "../Catch.h"
+#include "unit/TestBase.h"
+#include "unit/Catch.h"
 #include "core/Core.h"
 #include "utils/StringUtils.h"
 #include "utils/Environment.h"
